Class: Avo::BaseAction

Inherits:
Object
  • Object
show all
Includes:
Concerns::HasActionStimulusControllers, Concerns::HasItems, Concerns::Hydration
Defined in:
lib/avo/base_action.rb

Direct Known Subclasses

Divider

Constant Summary collapse

DATA_ATTRIBUTES =
{turbo_frame: Avo::MODAL_FRAME_ID}

Instance Attribute Summary collapse

Attributes included from Concerns::HasItems

#items_holder

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Concerns::Hydration

#hydrate

Methods included from Concerns::HasActionStimulusControllers

#get_stimulus_controllers

Methods included from Concerns::HasItems

#get_field, #get_field_definitions, #get_fields, #get_items, #get_preview_fields, #invalid_fields, #is_empty?, #items, #items_with_standalone_fields_wrapped_in_cards, #only_fields, #tab_groups, #visible_items

Constructor Details

#initialize(record: nil, resource: nil, user: nil, view: nil, arguments: {}, icon: "tabler/outline/player-play", query: nil, index_query: nil) ⇒ BaseAction

Returns a new instance of BaseAction.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/avo/base_action.rb', line 136

def initialize(record: nil, resource: nil, user: nil, view: nil, arguments: {}, icon: "tabler/outline/player-play", query: nil, index_query: nil)
  @record = record
  @resource = resource
  @user = user
  @view = Avo::ViewInquirer.new(view)
  @icon = icon
  @arguments = Avo::ExecutionContext.new(
    target: arguments,
    resource: resource,
    record: record
  ).handle.with_indifferent_access
  @query = query
  @index_query = index_query

  self.items_holder = Avo::Resources::Items::Holder.new

  @response ||= {}
  @response[:messages] = []
end

Instance Attribute Details

#appended_turbo_streamsObject (readonly)

Returns the value of attribute appended_turbo_streams.



37
38
39
# File 'lib/avo/base_action.rb', line 37

def appended_turbo_streams
  @appended_turbo_streams
end

#argumentsObject (readonly)

Returns the value of attribute arguments.



35
36
37
# File 'lib/avo/base_action.rb', line 35

def arguments
  @arguments
end

#iconObject (readonly)

Returns the value of attribute icon.



36
37
38
# File 'lib/avo/base_action.rb', line 36

def icon
  @icon
end

#queryObject (readonly)

Returns the value of attribute query.



39
40
41
# File 'lib/avo/base_action.rb', line 39

def query
  @query
end

#recordObject

Returns the value of attribute record.



32
33
34
# File 'lib/avo/base_action.rb', line 32

def record
  @record
end

#records_to_reloadObject (readonly)

Returns the value of attribute records_to_reload.



38
39
40
# File 'lib/avo/base_action.rb', line 38

def records_to_reload
  @records_to_reload
end

#resourceObject

Returns the value of attribute resource.



33
34
35
# File 'lib/avo/base_action.rb', line 33

def resource
  @resource
end

#responseObject

Returns the value of attribute response.



31
32
33
# File 'lib/avo/base_action.rb', line 31

def response
  @response
end

#userObject

Returns the value of attribute user.



34
35
36
# File 'lib/avo/base_action.rb', line 34

def user
  @user
end

#viewObject

Returns the value of attribute view.



30
31
32
# File 'lib/avo/base_action.rb', line 30

def view
  @view
end

Class Method Details

.class_nameObject



68
69
70
# File 'lib/avo/base_action.rb', line 68

def class_name
  to_s.delete_prefix("Avo::Actions::")
end

.decode_arguments(arguments) ⇒ Object



108
109
110
111
112
113
114
115
# File 'lib/avo/base_action.rb', line 108

def decode_arguments(arguments)
  return if arguments.blank?

  Avo::Services::EncryptionService.decrypt(
    message: Base64.decode64(arguments),
    purpose: :action_arguments
  )
end

.encode_arguments(arguments) ⇒ Object

Encrypt the arguments so we can pass sensible data as a query param. EncryptionService can generate special characters that can break the URL. We use Base64 to encode the encrypted string so we can safely pass it as a query param and don't break the URL.



99
100
101
102
103
104
105
106
# File 'lib/avo/base_action.rb', line 99

def encode_arguments(arguments)
  return if arguments.blank?

  Base64.encode64 Avo::Services::EncryptionService.encrypt(
    message: arguments,
    purpose: :action_arguments
  )
end

.form_data_attributesObject



57
58
59
60
61
62
# File 'lib/avo/base_action.rb', line 57

def form_data_attributes
  {
    turbo: turbo,
    turbo_frame: :_top
  }.compact
end


92
93
94
# File 'lib/avo/base_action.rb', line 92

def link_arguments(resource:, arguments: {}, **args)
  [path(resource:, arguments:, **args), DATA_ATTRIBUTES]
end

.path(resource:, arguments: {}, **args) ⇒ Object



77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/avo/base_action.rb', line 77

def path(resource:, arguments: {}, **args)
  Avo::Services::URIService.parse(resource.record&.to_param.present? ? resource.record_path : resource.records_path)
    .append_paths("actions")
    .append_query(
      **{
        action_id: to_param,
        arguments: encode_arguments(arguments),
        resource_view: resource.view,
        view_type: resource.view_type,
        **args
      }.compact
    )
    .to_s
end

.to_paramObject



64
65
66
# File 'lib/avo/base_action.rb', line 64

def to_param
  to_s
end

.translation_keyObject



72
73
74
# File 'lib/avo/base_action.rb', line 72

def translation_key
  custom_translation_key || "avo.action_translations.#{class_name.underscore}"
end

Instance Method Details

#action_nameObject



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/avo/base_action.rb', line 118

def action_name
  translated = translated_option(:name)
  return translated if translated.present?

  if name.present?
    return Avo::ExecutionContext.new(
      target: name,
      resource: @resource,
      record: @record,
      view: @view,
      arguments: @arguments,
      query: @query
    ).handle
  end

  self.class.to_s.demodulize.underscore.humanize(keep_id_suffix: true)
end

#append_to_response(turbo_stream) ⇒ Object



333
334
335
# File 'lib/avo/base_action.rb', line 333

def append_to_response(turbo_stream)
  @appended_turbo_streams = turbo_stream
end

#authorized?Boolean

Returns:

  • (Boolean)


323
324
325
326
327
328
329
330
331
# File 'lib/avo/base_action.rb', line 323

def authorized?
  Avo::ExecutionContext.new(
    target: authorize,
    action: self,
    resource: @resource,
    view: @view,
    arguments: arguments
  ).handle
end

#cancel_button_labelObject



168
169
170
# File 'lib/avo/base_action.rb', line 168

def cancel_button_label
  resolve_option(:cancel_button_label)
end

#close_modalObject Also known as: do_nothing



255
256
257
258
259
# File 'lib/avo/base_action.rb', line 255

def close_modal
  response[:type] = :close_modal

  self
end

#confirm_button_labelObject



172
173
174
# File 'lib/avo/base_action.rb', line 172

def confirm_button_label
  resolve_option(:confirm_button_label)
end

#confirmation?Boolean

Returns:

  • (Boolean)


345
346
347
348
349
350
351
352
353
# File 'lib/avo/base_action.rb', line 345

def confirmation?
  Avo::ExecutionContext.new(
    target: confirmation,
    action: self,
    resource: @resource,
    view: @view,
    arguments:
  ).handle
end

#current_userObject



43
44
45
# File 'lib/avo/base_action.rb', line 43

def current_user
  Avo::Current.user
end

#disabled?Boolean

Returns:

  • (Boolean)


341
342
343
# File 'lib/avo/base_action.rb', line 341

def disabled?
  !enabled?
end

#download(path, filename) ⇒ Object



315
316
317
318
319
320
321
# File 'lib/avo/base_action.rb', line 315

def download(path, filename)
  response[:type] = :download
  response[:path] = path
  response[:filename] = filename

  self
end

#enabled?Boolean

Returns:

  • (Boolean)


337
338
339
# File 'lib/avo/base_action.rb', line 337

def enabled?
  self.class.standalone || @record&.to_param.present?
end

#error(text, timeout: nil) ⇒ Object



231
232
233
234
235
# File 'lib/avo/base_action.rb', line 231

def error(text, timeout: nil)
  add_message text, :error, timeout: timeout

  self
end

#fieldsObject

Blank method



157
158
# File 'lib/avo/base_action.rb', line 157

def fields
end

#get_descriptionObject



160
161
162
# File 'lib/avo/base_action.rb', line 160

def get_description
  resolve_option(:description)
end

#get_messageObject



164
165
166
# File 'lib/avo/base_action.rb', line 164

def get_message
  resolve_option(:message)
end

#handle_action(**args) ⇒ Object



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/avo/base_action.rb', line 176

def handle_action(**args)
  processed_fields = if args[:fields].present?
    # Fetching the field definitions and not the actual fields (get_fields) because they will break if the user uses a `visible` block and adds a condition using the `params` variable. The params are different in the show method and the handle method.
    action_fields = get_field_definitions.map do |field|
      field.hydrate(resource: @resource)

      [field.id, field]
    end.to_h

    # For some fields, like belongs_to, the id and database_id differ (user vs user_id).
    # That's why we need to fetch the database_id for when we process the action.
    action_fields_by_database_id = action_fields.map do |id, value|
      [value.database_id.to_sym, value]
    end.to_h

    args[:fields].to_unsafe_h.map do |name, value|
      field = action_fields_by_database_id[name.to_sym]

      next if field.blank?

      [name, field.resolve_attribute(value)]
    end.reject(&:blank?).to_h
  else
    {}
  end

  handle(
    fields: processed_fields.with_indifferent_access,
    current_user: args[:current_user],
    resource: args[:resource],
    records: args[:query],
    query: args[:query],
    request: args[:request]
  )

  self
end

#inform(text, timeout: nil) ⇒ Object



237
238
239
240
241
# File 'lib/avo/base_action.rb', line 237

def inform(text, timeout: nil)
  add_message text, :info, timeout: timeout

  self
end

#keep_modal_openObject



249
250
251
252
253
# File 'lib/avo/base_action.rb', line 249

def keep_modal_open
  response[:type] = :keep_modal_open

  self
end


307
308
309
310
311
312
313
# File 'lib/avo/base_action.rb', line 307

def navigate_to_action(action, **kwargs)
  response[:type] = :navigate_to_action
  response[:action] = action
  response[:navigate_to_action_args] = kwargs

  self
end

#redirect_to(path = nil, **args, &block) ⇒ Object



271
272
273
274
275
276
277
278
279
280
281
# File 'lib/avo/base_action.rb', line 271

def redirect_to(path = nil, **args, &block)
  response[:type] = :redirect
  response[:redirect_args] = args
  response[:path] = if block.present?
    block
  else
    path
  end

  self
end

#reloadObject



283
284
285
286
287
# File 'lib/avo/base_action.rb', line 283

def reload
  response[:type] = :reload

  self
end

#reload_record(records) ⇒ Object Also known as: reload_records



289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/avo/base_action.rb', line 289

def reload_record(records)
  # Force close modal to avoid default redirect to
  # Redirect is 100% not wanted when using reload_record
  close_modal

  @records_to_reload = Array(records)

  case @resource.view_type.to_sym
  when :table, :map
    reload_row_items
  when :grid
    reload_grid_items
  end
end

#silentObject

Add a placeholder silent message from when a user wants to do a redirect action or something similar



265
266
267
268
269
# File 'lib/avo/base_action.rb', line 265

def silent
  add_message nil, :silent

  self
end

#succeed(text, timeout: nil) ⇒ Object



225
226
227
228
229
# File 'lib/avo/base_action.rb', line 225

def succeed(text, timeout: nil)
  add_message text, :success, timeout: timeout

  self
end

#visible_in_view(parent_resource: nil) ⇒ Object



214
215
216
217
218
219
220
221
222
223
# File 'lib/avo/base_action.rb', line 214

def visible_in_view(parent_resource: nil)
  Avo::ExecutionContext.new(
    target: visible,
    params: params,
    parent_resource: parent_resource,
    resource: @resource,
    view: @view,
    arguments: arguments
  ).handle && authorized?
end

#warn(text, timeout: nil) ⇒ Object



243
244
245
246
247
# File 'lib/avo/base_action.rb', line 243

def warn(text, timeout: nil)
  add_message text, :warning, timeout: timeout

  self
end