Module: Avo::Fields::Concerns::IsSearchable
- Extended by:
- ActiveSupport::Concern
- Included in:
- BelongsToField, ManyFrameBaseField
- Defined in:
- lib/avo/fields/concerns/is_searchable.rb
Instance Method Summary collapse
-
#is_searchable? ⇒ Boolean
Don’t remove, avo-pro hooks into this method to check if the field is searchable.
Instance Method Details
#is_searchable? ⇒ Boolean
Don’t remove, avo-pro hooks into this method to check if the field is searchable.
8 |
# File 'lib/avo/fields/concerns/is_searchable.rb', line 8 def is_searchable? = false |