Class: Avo::Fields::HeadingField
- Defined in:
- lib/avo/fields/heading_field.rb
Defined Under Namespace
Classes: EditComponent, ShowComponent
Instance Attribute Summary collapse
-
#as_html ⇒ Object
readonly
Returns the value of attribute as_html.
-
#empty ⇒ Object
readonly
Returns the value of attribute empty.
Attributes inherited from BaseField
#action, #as_avatar, #as_description, #as_label, #block, #computable, #computed, #computed_value, #default, #format_using, #help, #index_text_align, #model, #null_values, #nullable, #panel_name, #readonly, #required, #resource, #sortable, #stacked, #updatable, #user, #view, #visible
Attributes included from Concerns::HasHTMLAttributes
Attributes included from FieldExtensions::VisibleInDifferentViews
#show_on_edit, #show_on_index, #show_on_new, #show_on_show
Instance Method Summary collapse
- #id ⇒ Object
-
#initialize(content, **args, &block) ⇒ HeadingField
constructor
A new instance of HeadingField.
-
#value ⇒ Object
Override the value method if the field is empty.
Methods inherited from BaseField
#component_for_view, #custom?, #custom_name?, #database_id, #default_name, #fill_field, #has_own_panel?, #hidden_in_reflection?, #hydrate, #model_errors, #name, #placeholder, #plural_name, #resolve_attribute, #to_permitted_param, #translation_key, #type, #view_component_name, #visible?, #visible_in_reflection?
Methods included from FieldExtensions::HasFieldName
Methods included from Concerns::HasDefault
Methods included from Concerns::IsReadonly
Methods included from Concerns::IsRequired
Methods included from Concerns::HasHTMLAttributes
Methods included from FieldExtensions::VisibleInDifferentViews
#except_on, #hide_on, #only_on, #show_on, #show_on_create, #show_on_update, #visible_on?
Methods included from Concerns::IsResourceItem
#is_field?, #is_main_panel?, #is_panel?, #is_sidebar?, #is_tab?, #is_tab_group?, #is_tool?
Constructor Details
#initialize(content, **args, &block) ⇒ HeadingField
Returns a new instance of HeadingField.
9 10 11 12 13 14 15 16 17 18 19 20 21 22 |
# File 'lib/avo/fields/heading_field.rb', line 9 def initialize(content, **args, &block) # Mark the field as empty if there's no content passed @empty = content.blank? # Add dummy content content ||= SecureRandom.hex args[:updatable] = false super(content, **args, &block) hide_on :index @as_html = args[:as_html].present? ? args[:as_html] : false end |
Instance Attribute Details
#as_html ⇒ Object (readonly)
Returns the value of attribute as_html.
6 7 8 |
# File 'lib/avo/fields/heading_field.rb', line 6 def as_html @as_html end |
#empty ⇒ Object (readonly)
Returns the value of attribute empty.
7 8 9 |
# File 'lib/avo/fields/heading_field.rb', line 7 def empty @empty end |
Instance Method Details
#id ⇒ Object
24 25 26 |
# File 'lib/avo/fields/heading_field.rb', line 24 def id "heading_#{name.to_s.parameterize.underscore}" end |
#value ⇒ Object
Override the value method if the field is empty
29 30 31 32 33 |
# File 'lib/avo/fields/heading_field.rb', line 29 def value return nil if empty super end |