Class: Avo::UI::DropdownComponent
- Inherits:
-
BaseComponent
- Object
- ViewComponent::Base
- BaseComponent
- Avo::UI::DropdownComponent
- Defined in:
- app/components/avo/u_i/dropdown_component.rb
Constant Summary
Constants included from Concerns::FindAssociationField
Concerns::FindAssociationField::ASSOCIATIONS
Instance Method Summary collapse
-
#action ⇒ Object
this is used to trigger the dropdown menu from trigger element data: component.action => click->dropdown-menu#toggle.
- #data ⇒ Object
Methods inherited from BaseComponent
Methods included from ApplicationHelper
#a_button, #a_link, #body_classes, #button_classes, #chart_color, #container_classes, #d, #decode_filter_params, #e, #editor_file_path, #editor_url, #empty_state, #encode_filter_params, #frame_id, #get_model_class, #input_classes, #mount_path, #number_to_social, #possibly_rails_authentication?, #render_license_warning, #root_path_without_url, #rtl?, #text_direction, #ui, #wrap_in_modal
Methods included from ResourcesHelper
#field_wrapper, #filter_wrapper, #index_field_wrapper, #item_selector_data_attributes, #record_path, #record_title, #resource_for_record, #resource_grid, #resource_show_path, #resource_table
Methods included from Concerns::FindAssociationField
Instance Method Details
#action ⇒ Object
this is used to trigger the dropdown menu from trigger element data: component.action => click->dropdown-menu#toggle
15 16 17 |
# File 'app/components/avo/u_i/dropdown_component.rb', line 15 def action @action ||= "click->dropdown-menu#toggle" end |
#data ⇒ Object
19 20 21 22 23 24 25 |
# File 'app/components/avo/u_i/dropdown_component.rb', line 19 def data return {} if items.blank? { controller: "dropdown-menu", }.merge(@wrapper_data) end |