Class: Avo::BaseAction
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
#fields, #get_field, #get_field_definitions, #get_fields, #get_items, #get_tabs, #tab_groups, #tools
Constructor Details
#initialize(model: nil, resource: nil, user: nil, view: nil, arguments: {}) ⇒ BaseAction
Returns a new instance of BaseAction.
60
61
62
63
64
65
66
67
68
69
70
71
72
73
|
# File 'lib/avo/base_action.rb', line 60
def initialize(model: nil, resource: nil, user: nil, view: nil, arguments: {})
self.class.model = model if model.present?
self.class.resource = resource if resource.present?
self.class.user = user if user.present?
self.class.view = view if view.present?
@arguments = arguments
self.class.message ||= I18n.t("avo.are_you_sure_you_want_to_run_this_option")
self.class.confirm_button_label ||= I18n.t("avo.run")
self.class.cancel_button_label ||= I18n.t("avo.cancel")
@response ||= {}
@response[:messages] = []
end
|
Instance Attribute Details
#arguments ⇒ Object
Returns the value of attribute arguments.
22
23
24
|
# File 'lib/avo/base_action.rb', line 22
def arguments
@arguments
end
|
#model ⇒ Object
Returns the value of attribute model.
19
20
21
|
# File 'lib/avo/base_action.rb', line 19
def model
@model
end
|
#resource ⇒ Object
Returns the value of attribute resource.
20
21
22
|
# File 'lib/avo/base_action.rb', line 20
def resource
@resource
end
|
#response ⇒ Object
Returns the value of attribute response.
18
19
20
|
# File 'lib/avo/base_action.rb', line 18
def response
@response
end
|
#user ⇒ Object
Returns the value of attribute user.
21
22
23
|
# File 'lib/avo/base_action.rb', line 21
def user
@user
end
|
Class Method Details
35
36
37
38
39
40
41
42
|
# File 'lib/avo/base_action.rb', line 35
def form_data_attributes
if may_download_file
{turbo: false, remote: false, action_target: :form}
else
{turbo_frame: :_top, action_target: :form}
end
end
|
We can't respond with a file download from Turbo se we disable close the modal manually after a while (it's a hack, we know)
45
46
47
48
49
50
51
|
# File 'lib/avo/base_action.rb', line 45
def submit_button_data_attributes
if may_download_file
{action: "click->modal#delayedClose"}
else
{}
end
end
|
Instance Method Details
#action_name ⇒ Object
54
55
56
57
58
|
# File 'lib/avo/base_action.rb', line 54
def action_name
return name if name.present?
self.class.to_s.demodulize.underscore.humanize(keep_id_suffix: true)
end
|
#download(path, filename) ⇒ Object
205
206
207
208
209
210
211
|
# File 'lib/avo/base_action.rb', line 205
def download(path, filename)
response[:type] = :download
response[:path] = path
response[:filename] = filename
self
end
|
#error(text) ⇒ Object
157
158
159
160
161
|
# File 'lib/avo/base_action.rb', line 157
def error(text)
add_message text, :error
self
end
|
#fail(text) ⇒ Object
151
152
153
154
155
|
# File 'lib/avo/base_action.rb', line 151
def fail(text)
Rails.logger.warn "DEPRECATION WARNING: Action fail method is deprecated in favor of error method and will be removed from Avo version 3.0.0"
error text
end
|
#get_attributes_for_action ⇒ Object
75
76
77
78
79
|
# File 'lib/avo/base_action.rb', line 75
def get_attributes_for_action
get_fields.map do |field|
[field.id, field.value || field.default]
end.to_h
end
|
#handle_action(**args) ⇒ Object
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
|
# File 'lib/avo/base_action.rb', line 81
def handle_action(**args)
models, fields, current_user, resource = args.values_at(:models, :fields, :current_user, :resource)
action_fields = get_field_definitions.map { |field| [field.id, field] }.to_h
action_fields_by_database_id = action_fields.map do |id, value|
[value.database_id.to_sym, value]
end.to_h
if fields.present?
processed_fields = fields.to_unsafe_h.map do |name, value|
field = action_fields_by_database_id[name.to_sym]
next if field.blank?
[name, field.resolve_attribute(value)]
end
processed_fields = processed_fields.reject(&:blank?).to_h
else
processed_fields = {}
end
args = {
fields: processed_fields.with_indifferent_access,
current_user: current_user,
resource: resource
}
args[:models] = models unless standalone
handle(**args)
self
end
|
#hydrate_fields(model: nil, view: nil) ⇒ Object
We're overriding this method to hydrate with the proper resource attribute.
214
215
216
217
218
219
220
|
# File 'lib/avo/base_action.rb', line 214
def hydrate_fields(model: nil, view: nil)
fields.map do |field|
field.hydrate(model: @model, view: @view, resource: resource)
end
self
end
|
163
164
165
166
167
|
# File 'lib/avo/base_action.rb', line 163
def inform(text)
add_message text, :info
self
end
|
#keep_modal_open ⇒ Object
175
176
177
178
179
|
# File 'lib/avo/base_action.rb', line 175
def keep_modal_open
response[:keep_modal_open] = true
self
end
|
#param_id ⇒ Object
141
142
143
|
# File 'lib/avo/base_action.rb', line 141
def param_id
self.class.to_s.demodulize.underscore.tr "/", "_"
end
|
#redirect_to(path = nil, &block) ⇒ Object
188
189
190
191
192
193
194
195
196
197
|
# File 'lib/avo/base_action.rb', line 188
def redirect_to(path = nil, &block)
response[:type] = :redirect
response[:path] = if block.present?
block
else
path
end
self
end
|
#reload ⇒ Object
199
200
201
202
203
|
# File 'lib/avo/base_action.rb', line 199
def reload
response[:type] = :reload
self
end
|
#silent ⇒ Object
Add a placeholder silent message from when a user wants to do a redirect action or something similar
182
183
184
185
186
|
# File 'lib/avo/base_action.rb', line 182
def silent
add_message nil, :silent
self
end
|
#succeed(text) ⇒ Object
145
146
147
148
149
|
# File 'lib/avo/base_action.rb', line 145
def succeed(text)
add_message text, :success
self
end
|
#visible_in_view(parent_model: nil, parent_resource: nil) ⇒ Object
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
|
# File 'lib/avo/base_action.rb', line 119
def visible_in_view(parent_model: nil, parent_resource: nil)
if visible.blank?
return false if view == :new
return true
end
Avo::Hosts::VisibilityHost.new(
block: visible,
model: self.class.model,
params: params,
parent_model: parent_model,
parent_resource: parent_resource,
resource: self.class.resource,
view: self.class.view,
arguments: arguments
).handle
end
|
#warn(text) ⇒ Object
169
170
171
172
173
|
# File 'lib/avo/base_action.rb', line 169
def warn(text)
add_message text, :warning
self
end
|