Class: Avo::BaseResource

Inherits:
Object
  • Object
show all
Extended by:
ActiveSupport::DescendantsTracker
Includes:
ActionView::Helpers::UrlHelper, Concerns::CanReplaceFields, Concerns::HasEditableControls, Concerns::HasFields, Concerns::HasStimulusControllers, Concerns::ModelClassConstantized
Defined in:
lib/avo/base_resource.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Concerns::HasStimulusControllers

#get_stimulus_controllers, #stimulus_data_attributes

Methods included from Concerns::HasEditableControls

#has_show_controls?, #render_show_controls

Methods included from Concerns::CanReplaceFields

#with_new_items

Methods included from Concerns::HasFields

#fields, #get_field, #get_field_definitions, #get_fields, #get_items, #get_tabs, #hydrate_fields, #tab_groups, #tools

Constructor Details

#initializeBaseResource

Returns a new instance of BaseResource.



142
143
144
145
146
147
148
# File 'lib/avo/base_resource.rb', line 142

def initialize
  unless self.class.model_class.present?
    if model_class.present? && model_class.respond_to?(:base_class)
      self.class.model_class = model_class.base_class
    end
  end
end

Instance Attribute Details

#paramsObject

Returns the value of attribute params.



26
27
28
# File 'lib/avo/base_resource.rb', line 26

def params
  @params
end

#reflectionObject

Returns the value of attribute reflection.



24
25
26
# File 'lib/avo/base_resource.rb', line 24

def reflection
  @reflection
end

#userObject

Returns the value of attribute user.



25
26
27
# File 'lib/avo/base_resource.rb', line 25

def user
  @user
end

#viewObject

Returns the value of attribute view.



23
24
25
# File 'lib/avo/base_resource.rb', line 23

def view
  @view
end

Class Method Details

.action(action_class, arguments: {}) ⇒ Object



70
71
72
73
74
75
# File 'lib/avo/base_resource.rb', line 70

def action(action_class, arguments: {})
  self.actions_loader ||= Avo::Loaders::Loader.new

  action = { class: action_class, arguments: arguments }
  self.actions_loader.use action
end

.authorizationObject



104
105
106
# File 'lib/avo/base_resource.rb', line 104

def authorization
  Avo::Services::AuthorizationService.new Avo::App.current_user, model_class, policy_class: authorization_policy
end

.filter(filter_class, arguments: {}) ⇒ Object



77
78
79
80
81
82
# File 'lib/avo/base_resource.rb', line 77

def filter(filter_class, arguments: {})
  self.filters_loader ||= Avo::Loaders::Loader.new

  filter = { class: filter_class , arguments: arguments }
  self.filters_loader.use filter
end

.find_scopeObject

This resolves the scope when finding records (not “where” queries)



98
99
100
101
102
# File 'lib/avo/base_resource.rb', line 98

def find_scope
  final_scope = resolve_find_scope.present? ? resolve_find_scope.call(model_class: model_class) : model_class

  authorization.apply_policy final_scope
end

.get_available_modelsObject



131
132
133
# File 'lib/avo/base_resource.rb', line 131

def get_available_models
  ApplicationRecord.descendants
end

.get_record_associations(record) ⇒ Object



114
115
116
# File 'lib/avo/base_resource.rb', line 114

def get_record_associations(record)
  record._reflections
end

.grid(&block) ⇒ Object



63
64
65
66
67
68
# File 'lib/avo/base_resource.rb', line 63

def grid(&block)
  grid_collector = GridCollector.new
  grid_collector.instance_eval(&block)

  self.grid_loader = grid_collector
end

.order_actionsObject



108
109
110
111
112
# File 'lib/avo/base_resource.rb', line 108

def order_actions
  return {} if ordering.blank?

  ordering.dig(:actions) || {}
end

.query_scopeObject

This resolves the scope when doing “where” queries (not find queries)



91
92
93
94
95
# File 'lib/avo/base_resource.rb', line 91

def query_scope
  final_scope = resolve_query_scope.present? ? resolve_query_scope.call(model_class: model_class) : model_class

  authorization.apply_policy final_scope
end

.scopeObject

This is the search_query scope This should be removed and passed to the search block



86
87
88
# File 'lib/avo/base_resource.rb', line 86

def scope
  query_scope
end

.valid_association_name(record, association_name) ⇒ Object



118
119
120
121
122
# File 'lib/avo/base_resource.rb', line 118

def valid_association_name(record, association_name)
  get_record_associations(record).keys.find do |name|
    name == association_name
  end
end

.valid_attachment_name(record, association_name) ⇒ Object



124
125
126
127
128
129
# File 'lib/avo/base_resource.rb', line 124

def valid_attachment_name(record, association_name)
  association_exists = get_record_associations(record).keys.any? do |name|
    name == "#{association_name}_attachment" || name == "#{association_name}_attachments"
  end
  return association_name if association_exists
end

.valid_model_class(model_class) ⇒ Object



135
136
137
138
139
# File 'lib/avo/base_resource.rb', line 135

def valid_model_class(model_class)
  get_available_models.find do |m|
    m.to_s == model_class.to_s
  end
end

Instance Method Details

#attached_file_fieldsObject



302
303
304
305
306
# File 'lib/avo/base_resource.rb', line 302

def attached_file_fields
  get_field_definitions.select do |field|
    [Avo::Fields::FileField, Avo::Fields::FilesField].include? field.class
  end
end

#authorization(user: nil) ⇒ Object



337
338
339
340
# File 'lib/avo/base_resource.rb', line 337

def authorization(user: nil)
  current_user = user || Avo::App.current_user
  Avo::Services::AuthorizationService.new(current_user, model || model_class, policy_class: authorization_policy)
end

#available_view_typesObject



294
295
296
297
298
299
300
# File 'lib/avo/base_resource.rb', line 294

def available_view_types
  view_types = [:table]

  view_types << :grid if get_grid_fields.present?

  view_types
end

#avatarObject



461
462
463
464
465
466
467
468
469
# File 'lib/avo/base_resource.rb', line 461

def avatar
  return avatar_field.to_image if avatar_field.respond_to? :to_image

  return avatar_field.value.variant(resize_to_limit: [480, 480]) if avatar_field.type == "file"

  avatar_field.value
rescue
  nil
end

#avatar_fieldObject



453
454
455
456
457
458
459
# File 'lib/avo/base_resource.rb', line 453

def avatar_field
  get_field_definitions.find do |field|
    field.as_avatar.present?
  end
rescue
  nil
end

#avatar_typeObject



471
472
473
474
475
# File 'lib/avo/base_resource.rb', line 471

def avatar_type
  avatar_field.as_avatar
rescue
  nil
end

#cache_hash(parent_model) ⇒ Object



360
361
362
363
364
365
366
# File 'lib/avo/base_resource.rb', line 360

def cache_hash(parent_model)
  if parent_model.present?
    [model, file_hash, parent_model]
  else
    [model, file_hash]
  end
end

#class_name_without_resourceObject



212
213
214
# File 'lib/avo/base_resource.rb', line 212

def class_name_without_resource
  self.class.name.demodulize.delete_suffix("Resource")
end

#default_panel_nameObject



199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/avo/base_resource.rb', line 199

def default_panel_name
  return @params[:related_name].capitalize if @params.present? && @params[:related_name].present?

  case @view
  when :show
    model_title
  when :edit
    model_title
  when :new
    t("avo.create_new_item", item: name.downcase).upcase_first
  end
end

#descriptionObject



485
486
487
# File 'lib/avo/base_resource.rb', line 485

def description
  description_field&.value
end

#description_fieldObject



477
478
479
480
481
482
483
# File 'lib/avo/base_resource.rb', line 477

def description_field
  get_field_definitions.find do |field|
    field.as_description.present?
  end
rescue
  nil
end

#file_hashObject



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/avo/base_resource.rb', line 342

def file_hash
  content_to_be_hashed = ""

  # resource file hash
  resource_path = Rails.root.join("app", "avo", "resources", "#{self.class.name.underscore}.rb").to_s
  if File.file? resource_path
    content_to_be_hashed += File.read(resource_path)
  end

  # policy file hash
  policy_path = Rails.root.join("app", "policies", "#{self.class.name.underscore.gsub("_resource", "")}_policy.rb").to_s
  if File.file? policy_path
    content_to_be_hashed += File.read(policy_path)
  end

  Digest::MD5.hexdigest(content_to_be_hashed)
end

#fill_model(model, params, extra_params: []) ⇒ Object



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/avo/base_resource.rb', line 308

def fill_model(model, params, extra_params: [])
  # Map the received params to their actual fields
  fields_by_database_id = get_field_definitions
    .reject do |field|
      field.computed
    end
    .map do |field|
      [field.database_id.to_s, field]
    end
    .to_h

  # Write the field values
  params.each do |key, value|
    field = fields_by_database_id[key]

    next unless field.present?

    model = field.fill_field model, key, value, params
  end

  # Write the user configured extra params to the model
  if extra_params.present?
    # Let Rails fill in the rest of the params
    model.assign_attributes params.permit(extra_params)
  end

  model
end

#find_record(id, query: nil, params: nil) ⇒ Object



501
502
503
504
505
# File 'lib/avo/base_resource.rb', line 501

def find_record(id, query: nil, params: nil)
  query ||= self.class.find_scope

  self.class.find_record_method.call(model_class: query, id: id, params: params)
end

#form_scopeObject



489
490
491
# File 'lib/avo/base_resource.rb', line 489

def form_scope
  model_class.base_class.to_s.underscore.downcase
end

#get_action_arguments(action_class) ⇒ Object



193
194
195
196
197
# File 'lib/avo/base_resource.rb', line 193

def get_action_arguments(action_class)
  action = get_actions.find { |action| action[:class].to_s == action_class.to_s }

  action[:arguments]
end

#get_actionsObject



187
188
189
190
191
# File 'lib/avo/base_resource.rb', line 187

def get_actions
  return [] if self.class.actions_loader.blank?

  self.class.actions_loader.bag
end

#get_filter_arguments(filter_class) ⇒ Object



181
182
183
184
185
# File 'lib/avo/base_resource.rb', line 181

def get_filter_arguments(filter_class)
  filter = get_filters.find { |filter| filter[:class] == filter_class.constantize }

  filter[:arguments]
end

#get_filtersObject



175
176
177
178
179
# File 'lib/avo/base_resource.rb', line 175

def get_filters
  return [] if self.class.filters_loader.blank?

  self.class.filters_loader.bag
end

#get_grid_fieldsObject



169
170
171
172
173
# File 'lib/avo/base_resource.rb', line 169

def get_grid_fields
  return if self.class.grid_loader.blank?

  self.class.grid_loader.hydrate(model: @model, view: @view, resource: self)
end

#has_model_id?Boolean

Returns:

  • (Boolean)


497
498
499
# File 'lib/avo/base_resource.rb', line 497

def has_model_id?
  model.present? && model.id.present?
end

#hydrate(model: nil, view: nil, user: nil, params: nil) ⇒ Object



155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/avo/base_resource.rb', line 155

def hydrate(model: nil, view: nil, user: nil, params: nil)
  @view = view if view.present?
  @user = user if user.present?
  @params = params if params.present?

  if model.present?
    @model = model

    hydrate_model_with_default_values if @view == :new
  end

  self
end

#hydrate_model_with_default_valuesObject

We will not overwrite any attributes that come pre-filled in the model.



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/avo/base_resource.rb', line 369

def hydrate_model_with_default_values
  default_values = get_fields
    .select do |field|
      !field.computed
    end
    .map do |field|
      id = field.id
      value = field.value

      if field.type == "belongs_to"
        id = field.foreign_key.to_sym

        reflection = @model._reflections[@params[:via_relation]]

        if field.polymorphic_as.present? && field.types.map(&:to_s).include?(@params[:via_relation_class])
          # set the value to the actual record
          value = @params[:via_relation_class].safe_constantize.find(@params[:via_resource_id])
        elsif reflection.present? && reflection.foreign_key.present? && field.id.to_s == @params[:via_relation].to_s
          resource = Avo::App.get_resource_by_model_name params[:via_relation_class]
          model = resource.find_record @params[:via_resource_id], params: params
          id_param = reflection.options[:primary_key] || :id

          value = model.send(id_param)
        end
      end

      [id, value]
    end
    .to_h
    .select do |id, value|
      value.present?
    end

  default_values.each do |id, value|
    if @model.send(id).nil?
      @model.send("#{id}=", value)
    end
  end
end

#labelObject



449
450
451
# File 'lib/avo/base_resource.rb', line 449

def label
  label_field&.value || model_title
end

#label_fieldObject



441
442
443
444
445
446
447
# File 'lib/avo/base_resource.rb', line 441

def label_field
  get_field_definitions.find do |field|
    field.as_label.present?
  end
rescue
  nil
end

#model_classObject



216
217
218
219
220
221
222
223
224
225
# File 'lib/avo/base_resource.rb', line 216

def model_class
  # get the model class off of the static property
  return self.class.model_class if self.class.model_class.present?

  # get the model class off of the model
  return @model.base_class if @model.present?

  # generate a model class
  class_name_without_resource.safe_constantize
end

#model_idObject



227
228
229
# File 'lib/avo/base_resource.rb', line 227

def model_id
  @model.send id
end

#model_keyObject

This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish



421
422
423
# File 'lib/avo/base_resource.rb', line 421

def model_key
  model_class.model_name.plural
end

#model_nameObject



425
426
427
# File 'lib/avo/base_resource.rb', line 425

def model_name
  model_class.model_name
end

#model_titleObject



231
232
233
234
235
236
237
238
239
240
# File 'lib/avo/base_resource.rb', line 231

def model_title
  return name if @model.nil?

  the_title = @model.send title
  return the_title if the_title.present?

  model_id
rescue
  name
end

#nameObject



258
259
260
261
262
263
264
265
266
267
268
# File 'lib/avo/base_resource.rb', line 258

def name
  default = class_name_without_resource.to_s.gsub('::', ' ').underscore.humanize

  return @name if @name.present?

  if translation_key && ::Avo::App.translation_enabled
    t(translation_key, count: 1, default: default).capitalize
  else
    default
  end
end


290
291
292
# File 'lib/avo/base_resource.rb', line 290

def navigation_label
  plural_name.humanize
end

#ordering_host(**args) ⇒ Object



493
494
495
# File 'lib/avo/base_resource.rb', line 493

def ordering_host(**args)
  Avo::Hosts::Ordering.new resource: self, options: self.class.ordering, **args
end

#plural_nameObject



274
275
276
277
278
279
280
281
282
# File 'lib/avo/base_resource.rb', line 274

def plural_name
  default = name.pluralize

  if translation_key && ::Avo::App.translation_enabled
    t(translation_key, count: 2, default: default).capitalize
  else
    default
  end
end

#recordObject Also known as: model



150
151
152
# File 'lib/avo/base_resource.rb', line 150

def record
  @model
end

#record_pathObject



433
434
435
# File 'lib/avo/base_resource.rb', line 433

def record_path
  resource_path(model: model, resource: self)
end

#records_pathObject



437
438
439
# File 'lib/avo/base_resource.rb', line 437

def records_path
  resources_path(resource: self)
end

#resource_descriptionObject



242
243
244
245
246
247
248
249
250
# File 'lib/avo/base_resource.rb', line 242

def resource_description
  return instance_exec(&self.class.description) if self.class.description.respond_to? :call

  # Show the description only on the resource index view.
  # If the user wants to conditionally it on all pages, they should use a block.
  if view == :index
    return self.class.description if self.class.description.is_a? String
  end
end

#route_keyObject



409
410
411
# File 'lib/avo/base_resource.rb', line 409

def route_key
  class_name_without_resource.underscore.pluralize
end

#singular_model_keyObject



429
430
431
# File 'lib/avo/base_resource.rb', line 429

def singular_model_key
  model_class.model_name.singular
end

#singular_nameObject



270
271
272
# File 'lib/avo/base_resource.rb', line 270

def singular_name
  name
end

#singular_route_keyObject



413
414
415
# File 'lib/avo/base_resource.rb', line 413

def singular_route_key
  route_key.singularize
end

#translation_keyObject



252
253
254
255
256
# File 'lib/avo/base_resource.rb', line 252

def translation_key
  return "avo.resource_translations.#{class_name_without_resource.underscore}" if ::Avo::App.translation_enabled

  self.class.translation_key
end

#underscore_nameObject



284
285
286
287
288
# File 'lib/avo/base_resource.rb', line 284

def underscore_name
  return @name if @name.present?

  self.class.name.demodulize.underscore
end