Class: Avo::BaseResource
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
#get_stimulus_controllers, #stimulus_data_attributes
#has_show_controls?, #render_show_controls
#with_new_items
#fields, #get_field, #get_field_definitions, #get_fields, #get_items, #get_tabs, #hydrate_fields, #tab_groups, #tools
Constructor Details
Returns a new instance of BaseResource.
141
142
143
144
145
146
147
|
# File 'lib/avo/base_resource.rb', line 141
def initialize
unless self.class.model_class.present?
if model_class.present? && model_class.respond_to?(:base_class)
self.class.model_class = model_class.base_class
end
end
end
|
Instance Attribute Details
#params ⇒ Object
Returns the value of attribute params.
26
27
28
|
# File 'lib/avo/base_resource.rb', line 26
def params
@params
end
|
#reflection ⇒ Object
Returns the value of attribute reflection.
24
25
26
|
# File 'lib/avo/base_resource.rb', line 24
def reflection
@reflection
end
|
#user ⇒ Object
Returns the value of attribute user.
25
26
27
|
# File 'lib/avo/base_resource.rb', line 25
def user
@user
end
|
#view ⇒ Object
Returns the value of attribute view.
23
24
25
|
# File 'lib/avo/base_resource.rb', line 23
def view
@view
end
|
Class Method Details
.action(action_class, arguments: {}) ⇒ Object
69
70
71
72
73
74
|
# File 'lib/avo/base_resource.rb', line 69
def action(action_class, arguments: {})
self.actions_loader ||= Avo::Loaders::Loader.new
action = { class: action_class, arguments: arguments }
self.actions_loader.use action
end
|
.filter(filter_class, arguments: {}) ⇒ Object
76
77
78
79
80
81
|
# File 'lib/avo/base_resource.rb', line 76
def filter(filter_class, arguments: {})
self.filters_loader ||= Avo::Loaders::Loader.new
filter = { class: filter_class , arguments: arguments }
self.filters_loader.use filter
end
|
.find_scope ⇒ Object
This resolves the scope when finding records (not “where” queries)
97
98
99
100
101
|
# File 'lib/avo/base_resource.rb', line 97
def find_scope
final_scope = resolve_find_scope.present? ? resolve_find_scope.call(model_class: model_class) : model_class
authorization.apply_policy final_scope
end
|
.get_available_models ⇒ Object
130
131
132
|
# File 'lib/avo/base_resource.rb', line 130
def get_available_models
ApplicationRecord.descendants
end
|
.get_record_associations(record) ⇒ Object
113
114
115
|
# File 'lib/avo/base_resource.rb', line 113
def get_record_associations(record)
record._reflections
end
|
.grid(&block) ⇒ Object
62
63
64
65
66
67
|
# File 'lib/avo/base_resource.rb', line 62
def grid(&block)
grid_collector = GridCollector.new
grid_collector.instance_eval(&block)
self.grid_loader = grid_collector
end
|
.order_actions ⇒ Object
107
108
109
110
111
|
# File 'lib/avo/base_resource.rb', line 107
def order_actions
return {} if ordering.blank?
ordering.dig(:actions) || {}
end
|
.query_scope ⇒ Object
This resolves the scope when doing “where” queries (not find queries)
90
91
92
93
94
|
# File 'lib/avo/base_resource.rb', line 90
def query_scope
final_scope = resolve_query_scope.present? ? resolve_query_scope.call(model_class: model_class) : model_class
authorization.apply_policy final_scope
end
|
.scope ⇒ Object
This is the search_query scope This should be removed and passed to the search block
85
86
87
|
# File 'lib/avo/base_resource.rb', line 85
def scope
query_scope
end
|
.valid_association_name(record, association_name) ⇒ Object
117
118
119
120
121
|
# File 'lib/avo/base_resource.rb', line 117
def valid_association_name(record, association_name)
get_record_associations(record).keys.find do |name|
name == association_name
end
end
|
.valid_attachment_name(record, association_name) ⇒ Object
123
124
125
126
127
128
|
# File 'lib/avo/base_resource.rb', line 123
def valid_attachment_name(record, association_name)
association_exists = get_record_associations(record).keys.any? do |name|
name == "#{association_name}_attachment" || name == "#{association_name}_attachments"
end
return association_name if association_exists
end
|
.valid_model_class(model_class) ⇒ Object
134
135
136
137
138
|
# File 'lib/avo/base_resource.rb', line 134
def valid_model_class(model_class)
get_available_models.find do |m|
m.to_s == model_class.to_s
end
end
|
Instance Method Details
#attached_file_fields ⇒ Object
301
302
303
304
305
|
# File 'lib/avo/base_resource.rb', line 301
def attached_file_fields
get_field_definitions.select do |field|
[Avo::Fields::FileField, Avo::Fields::FilesField].include? field.class
end
end
|
#authorization(user: nil) ⇒ Object
336
337
338
339
|
# File 'lib/avo/base_resource.rb', line 336
def authorization(user: nil)
current_user = user || Avo::App.current_user
Avo::Services::AuthorizationService.new(current_user, model || model_class, policy_class: authorization_policy)
end
|
#available_view_types ⇒ Object
293
294
295
296
297
298
299
|
# File 'lib/avo/base_resource.rb', line 293
def available_view_types
view_types = [:table]
view_types << :grid if get_grid_fields.present?
view_types
end
|
#avatar ⇒ Object
460
461
462
463
464
465
466
467
468
|
# File 'lib/avo/base_resource.rb', line 460
def avatar
return avatar_field.to_image if avatar_field.respond_to? :to_image
return avatar_field.value.variant(resize_to_limit: [480, 480]) if avatar_field.type == "file"
avatar_field.value
rescue
nil
end
|
#avatar_field ⇒ Object
452
453
454
455
456
457
458
|
# File 'lib/avo/base_resource.rb', line 452
def avatar_field
get_field_definitions.find do |field|
field.as_avatar.present?
end
rescue
nil
end
|
#avatar_type ⇒ Object
470
471
472
473
474
|
# File 'lib/avo/base_resource.rb', line 470
def avatar_type
avatar_field.as_avatar
rescue
nil
end
|
#cache_hash(parent_model) ⇒ Object
359
360
361
362
363
364
365
|
# File 'lib/avo/base_resource.rb', line 359
def cache_hash(parent_model)
if parent_model.present?
[model, file_hash, parent_model]
else
[model, file_hash]
end
end
|
#class_name_without_resource ⇒ Object
211
212
213
|
# File 'lib/avo/base_resource.rb', line 211
def class_name_without_resource
self.class.name.demodulize.delete_suffix("Resource")
end
|
#default_panel_name ⇒ Object
198
199
200
201
202
203
204
205
206
207
208
209
|
# File 'lib/avo/base_resource.rb', line 198
def default_panel_name
return @params[:related_name].capitalize if @params.present? && @params[:related_name].present?
case @view
when :show
model_title
when :edit
model_title
when :new
t("avo.create_new_item", item: name.downcase).upcase_first
end
end
|
#description ⇒ Object
484
485
486
|
# File 'lib/avo/base_resource.rb', line 484
def description
description_field&.value
end
|
#description_field ⇒ Object
476
477
478
479
480
481
482
|
# File 'lib/avo/base_resource.rb', line 476
def description_field
get_field_definitions.find do |field|
field.as_description.present?
end
rescue
nil
end
|
#file_hash ⇒ Object
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
|
# File 'lib/avo/base_resource.rb', line 341
def file_hash
content_to_be_hashed = ""
resource_path = Rails.root.join("app", "avo", "resources", "#{self.class.name.underscore}.rb").to_s
if File.file? resource_path
content_to_be_hashed += File.read(resource_path)
end
policy_path = Rails.root.join("app", "policies", "#{self.class.name.underscore.gsub("_resource", "")}_policy.rb").to_s
if File.file? policy_path
content_to_be_hashed += File.read(policy_path)
end
Digest::MD5.hexdigest(content_to_be_hashed)
end
|
#fill_model(model, params, extra_params: []) ⇒ Object
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
|
# File 'lib/avo/base_resource.rb', line 307
def fill_model(model, params, extra_params: [])
fields_by_database_id = get_field_definitions
.reject do |field|
field.computed
end
.map do |field|
[field.database_id.to_s, field]
end
.to_h
params.each do |key, value|
field = fields_by_database_id[key]
next unless field.present?
model = field.fill_field model, key, value, params
end
if .present?
model.assign_attributes params.permit()
end
model
end
|
#find_record(id, query: nil, params: nil) ⇒ Object
500
501
502
503
504
|
# File 'lib/avo/base_resource.rb', line 500
def find_record(id, query: nil, params: nil)
query ||= self.class.find_scope
self.class.find_record_method.call(model_class: query, id: id, params: params)
end
|
488
489
490
|
# File 'lib/avo/base_resource.rb', line 488
def form_scope
model_class.base_class.to_s.underscore.downcase
end
|
#get_action_arguments(action_class) ⇒ Object
192
193
194
195
196
|
# File 'lib/avo/base_resource.rb', line 192
def get_action_arguments(action_class)
action = get_actions.find { |action| action[:class].to_s == action_class.to_s }
action[:arguments]
end
|
#get_actions ⇒ Object
186
187
188
189
190
|
# File 'lib/avo/base_resource.rb', line 186
def get_actions
return [] if self.class.actions_loader.blank?
self.class.actions_loader.bag
end
|
#get_filter_arguments(filter_class) ⇒ Object
180
181
182
183
184
|
# File 'lib/avo/base_resource.rb', line 180
def get_filter_arguments(filter_class)
filter = get_filters.find { |filter| filter[:class] == filter_class.constantize }
filter[:arguments]
end
|
#get_filters ⇒ Object
174
175
176
177
178
|
# File 'lib/avo/base_resource.rb', line 174
def get_filters
return [] if self.class.filters_loader.blank?
self.class.filters_loader.bag
end
|
#get_grid_fields ⇒ Object
168
169
170
171
172
|
# File 'lib/avo/base_resource.rb', line 168
def get_grid_fields
return if self.class.grid_loader.blank?
self.class.grid_loader.hydrate(model: @model, view: @view, resource: self)
end
|
#has_model_id? ⇒ Boolean
496
497
498
|
# File 'lib/avo/base_resource.rb', line 496
def has_model_id?
model.present? && model.id.present?
end
|
#hydrate(model: nil, view: nil, user: nil, params: nil) ⇒ Object
154
155
156
157
158
159
160
161
162
163
164
165
166
|
# File 'lib/avo/base_resource.rb', line 154
def hydrate(model: nil, view: nil, user: nil, params: nil)
@view = view if view.present?
@user = user if user.present?
@params = params if params.present?
if model.present?
@model = model
hydrate_model_with_default_values if @view == :new
end
self
end
|
#hydrate_model_with_default_values ⇒ Object
We will not overwrite any attributes that come pre-filled in the model.
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
|
# File 'lib/avo/base_resource.rb', line 368
def hydrate_model_with_default_values
default_values = get_fields
.select do |field|
!field.computed
end
.map do |field|
id = field.id
value = field.value
if field.type == "belongs_to"
id = field.foreign_key.to_sym
reflection = @model._reflections[@params[:via_relation]]
if field.polymorphic_as.present? && field.types.map(&:to_s).include?(@params[:via_relation_class])
value = @params[:via_relation_class].safe_constantize.find(@params[:via_resource_id])
elsif reflection.present? && reflection.foreign_key.present? && field.id.to_s == @params[:via_relation].to_s
resource = Avo::App.get_resource_by_model_name params[:via_relation_class]
model = resource.find_record @params[:via_resource_id], params: params
id_param = reflection.options[:primary_key] || :id
value = model.send(id_param)
end
end
[id, value]
end
.to_h
.select do |id, value|
value.present?
end
default_values.each do |id, value|
if @model.send(id).nil?
@model.send("#{id}=", value)
end
end
end
|
#label ⇒ Object
448
449
450
|
# File 'lib/avo/base_resource.rb', line 448
def label
label_field&.value || model_title
end
|
#label_field ⇒ Object
440
441
442
443
444
445
446
|
# File 'lib/avo/base_resource.rb', line 440
def label_field
get_field_definitions.find do |field|
field.as_label.present?
end
rescue
nil
end
|
#model_class ⇒ Object
215
216
217
218
219
220
221
222
223
224
|
# File 'lib/avo/base_resource.rb', line 215
def model_class
return self.class.model_class if self.class.model_class.present?
return @model.base_class if @model.present?
class_name_without_resource.safe_constantize
end
|
#model_id ⇒ Object
226
227
228
|
# File 'lib/avo/base_resource.rb', line 226
def model_id
@model.send id
end
|
#model_key ⇒ Object
This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish
420
421
422
|
# File 'lib/avo/base_resource.rb', line 420
def model_key
model_class.model_name.plural
end
|
#model_name ⇒ Object
424
425
426
|
# File 'lib/avo/base_resource.rb', line 424
def model_name
model_class.model_name
end
|
#model_title ⇒ Object
230
231
232
233
234
235
236
237
238
239
|
# File 'lib/avo/base_resource.rb', line 230
def model_title
return name if @model.nil?
the_title = @model.send title
return the_title if the_title.present?
model_id
rescue
name
end
|
#name ⇒ Object
257
258
259
260
261
262
263
264
265
266
267
|
# File 'lib/avo/base_resource.rb', line 257
def name
default = class_name_without_resource.to_s.gsub('::', ' ').underscore.humanize
return @name if @name.present?
if translation_key && ::Avo::App.translation_enabled
t(translation_key, count: 1, default: default).capitalize
else
default
end
end
|
#navigation_label ⇒ Object
289
290
291
|
# File 'lib/avo/base_resource.rb', line 289
def navigation_label
plural_name.humanize
end
|
#ordering_host(**args) ⇒ Object
492
493
494
|
# File 'lib/avo/base_resource.rb', line 492
def ordering_host(**args)
Avo::Hosts::Ordering.new resource: self, options: self.class.ordering, **args
end
|
#plural_name ⇒ Object
273
274
275
276
277
278
279
280
281
|
# File 'lib/avo/base_resource.rb', line 273
def plural_name
default = name.pluralize
if translation_key && ::Avo::App.translation_enabled
t(translation_key, count: 2, default: default).capitalize
else
default
end
end
|
#record ⇒ Object
Also known as:
model
149
150
151
|
# File 'lib/avo/base_resource.rb', line 149
def record
@model
end
|
#record_path ⇒ Object
432
433
434
|
# File 'lib/avo/base_resource.rb', line 432
def record_path
resource_path(model: model, resource: self)
end
|
#records_path ⇒ Object
436
437
438
|
# File 'lib/avo/base_resource.rb', line 436
def records_path
resources_path(resource: self)
end
|
#resource_description ⇒ Object
241
242
243
244
245
246
247
248
249
|
# File 'lib/avo/base_resource.rb', line 241
def resource_description
return instance_exec(&self.class.description) if self.class.description.respond_to? :call
if view == :index
return self.class.description if self.class.description.is_a? String
end
end
|
#route_key ⇒ Object
408
409
410
|
# File 'lib/avo/base_resource.rb', line 408
def route_key
class_name_without_resource.underscore.pluralize
end
|
#singular_model_key ⇒ Object
428
429
430
|
# File 'lib/avo/base_resource.rb', line 428
def singular_model_key
model_class.model_name.singular
end
|
#singular_name ⇒ Object
269
270
271
|
# File 'lib/avo/base_resource.rb', line 269
def singular_name
name
end
|
#singular_route_key ⇒ Object
412
413
414
|
# File 'lib/avo/base_resource.rb', line 412
def singular_route_key
route_key.singularize
end
|
#translation_key ⇒ Object
251
252
253
254
255
|
# File 'lib/avo/base_resource.rb', line 251
def translation_key
return "avo.resource_translations.#{class_name_without_resource.underscore}" if ::Avo::App.translation_enabled
self.class.translation_key
end
|
#underscore_name ⇒ Object
283
284
285
286
287
|
# File 'lib/avo/base_resource.rb', line 283
def underscore_name
return @name if @name.present?
self.class.name.demodulize.underscore
end
|