Class: Avo::BaseResource

Inherits:
Object
  • Object
show all
Extended by:
ActiveSupport::DescendantsTracker
Includes:
ActionView::Helpers::UrlHelper, Concerns::CanReplaceFields, Concerns::HasEditableControls, Concerns::HasFields, Concerns::HasStimulusControllers, Concerns::ModelClassConstantized
Defined in:
lib/avo/base_resource.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Concerns::HasStimulusControllers

#get_stimulus_controllers, #stimulus_data_attributes

Methods included from Concerns::HasEditableControls

#has_show_controls?, #render_show_controls

Methods included from Concerns::CanReplaceFields

#with_new_items

Methods included from Concerns::HasFields

#fields, #get_field, #get_field_definitions, #get_fields, #get_items, #get_tabs, #hydrate_fields, #tab_groups, #tools

Constructor Details

#initializeBaseResource

Returns a new instance of BaseResource.



140
141
142
143
144
145
146
# File 'lib/avo/base_resource.rb', line 140

def initialize
  unless self.class.model_class.present?
    if model_class.present? && model_class.respond_to?(:base_class)
      self.class.model_class = model_class.base_class
    end
  end
end

Instance Attribute Details

#paramsObject

Returns the value of attribute params.



26
27
28
# File 'lib/avo/base_resource.rb', line 26

def params
  @params
end

#reflectionObject

Returns the value of attribute reflection.



24
25
26
# File 'lib/avo/base_resource.rb', line 24

def reflection
  @reflection
end

#userObject

Returns the value of attribute user.



25
26
27
# File 'lib/avo/base_resource.rb', line 25

def user
  @user
end

#viewObject

Returns the value of attribute view.



23
24
25
# File 'lib/avo/base_resource.rb', line 23

def view
  @view
end

Class Method Details

.action(action_class, arguments: {}) ⇒ Object



68
69
70
71
72
73
# File 'lib/avo/base_resource.rb', line 68

def action(action_class, arguments: {})
  self.actions_loader ||= Avo::Loaders::Loader.new

  action = { class: action_class, arguments: arguments }
  self.actions_loader.use action
end

.authorizationObject



102
103
104
# File 'lib/avo/base_resource.rb', line 102

def authorization
  Avo::Services::AuthorizationService.new Avo::App.current_user, model_class, policy_class: authorization_policy
end

.filter(filter_class, arguments: {}) ⇒ Object



75
76
77
78
79
80
# File 'lib/avo/base_resource.rb', line 75

def filter(filter_class, arguments: {})
  self.filters_loader ||= Avo::Loaders::Loader.new

  filter = { class: filter_class , arguments: arguments }
  self.filters_loader.use filter
end

.find_scopeObject

This resolves the scope when finding records (not “where” queries)



96
97
98
99
100
# File 'lib/avo/base_resource.rb', line 96

def find_scope
  final_scope = resolve_find_scope.present? ? resolve_find_scope.call(model_class: model_class) : model_class

  authorization.apply_policy final_scope
end

.get_available_modelsObject



129
130
131
# File 'lib/avo/base_resource.rb', line 129

def get_available_models
  ApplicationRecord.descendants
end

.get_record_associations(record) ⇒ Object



112
113
114
# File 'lib/avo/base_resource.rb', line 112

def get_record_associations(record)
  record._reflections
end

.grid(&block) ⇒ Object



61
62
63
64
65
66
# File 'lib/avo/base_resource.rb', line 61

def grid(&block)
  grid_collector = GridCollector.new
  grid_collector.instance_eval(&block)

  self.grid_loader = grid_collector
end

.order_actionsObject



106
107
108
109
110
# File 'lib/avo/base_resource.rb', line 106

def order_actions
  return {} if ordering.blank?

  ordering.dig(:actions) || {}
end

.query_scopeObject

This resolves the scope when doing “where” queries (not find queries)



89
90
91
92
93
# File 'lib/avo/base_resource.rb', line 89

def query_scope
  final_scope = resolve_query_scope.present? ? resolve_query_scope.call(model_class: model_class) : model_class

  authorization.apply_policy final_scope
end

.scopeObject

This is the search_query scope This should be removed and passed to the search block



84
85
86
# File 'lib/avo/base_resource.rb', line 84

def scope
  query_scope
end

.valid_association_name(record, association_name) ⇒ Object



116
117
118
119
120
# File 'lib/avo/base_resource.rb', line 116

def valid_association_name(record, association_name)
  get_record_associations(record).keys.find do |name|
    name == association_name
  end
end

.valid_attachment_name(record, association_name) ⇒ Object



122
123
124
125
126
127
# File 'lib/avo/base_resource.rb', line 122

def valid_attachment_name(record, association_name)
  association_exists = get_record_associations(record).keys.any? do |name|
    name == "#{association_name}_attachment" || name == "#{association_name}_attachments"
  end
  return association_name if association_exists
end

.valid_model_class(model_class) ⇒ Object



133
134
135
136
137
# File 'lib/avo/base_resource.rb', line 133

def valid_model_class(model_class)
  get_available_models.find do |m|
    m.to_s == model_class.to_s
  end
end

Instance Method Details

#attached_file_fieldsObject



300
301
302
303
304
# File 'lib/avo/base_resource.rb', line 300

def attached_file_fields
  get_field_definitions.select do |field|
    [Avo::Fields::FileField, Avo::Fields::FilesField].include? field.class
  end
end

#authorization(user: nil) ⇒ Object



335
336
337
338
# File 'lib/avo/base_resource.rb', line 335

def authorization(user: nil)
  current_user = user || Avo::App.current_user
  Avo::Services::AuthorizationService.new(current_user, model || model_class, policy_class: authorization_policy)
end

#available_view_typesObject



292
293
294
295
296
297
298
# File 'lib/avo/base_resource.rb', line 292

def available_view_types
  view_types = [:table]

  view_types << :grid if get_grid_fields.present?

  view_types
end

#avatarObject



459
460
461
462
463
464
465
466
467
# File 'lib/avo/base_resource.rb', line 459

def avatar
  return avatar_field.to_image if avatar_field.respond_to? :to_image

  return avatar_field.value.variant(resize_to_limit: [480, 480]) if avatar_field.type == "file"

  avatar_field.value
rescue
  nil
end

#avatar_fieldObject



451
452
453
454
455
456
457
# File 'lib/avo/base_resource.rb', line 451

def avatar_field
  get_field_definitions.find do |field|
    field.as_avatar.present?
  end
rescue
  nil
end

#avatar_typeObject



469
470
471
472
473
# File 'lib/avo/base_resource.rb', line 469

def avatar_type
  avatar_field.as_avatar
rescue
  nil
end

#cache_hash(parent_model) ⇒ Object



358
359
360
361
362
363
364
# File 'lib/avo/base_resource.rb', line 358

def cache_hash(parent_model)
  if parent_model.present?
    [model, file_hash, parent_model]
  else
    [model, file_hash]
  end
end

#class_name_without_resourceObject



210
211
212
# File 'lib/avo/base_resource.rb', line 210

def class_name_without_resource
  self.class.name.demodulize.delete_suffix("Resource")
end

#default_panel_nameObject



197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/avo/base_resource.rb', line 197

def default_panel_name
  return @params[:related_name].capitalize if @params.present? && @params[:related_name].present?

  case @view
  when :show
    model_title
  when :edit
    model_title
  when :new
    t("avo.create_new_item", item: name.downcase).upcase_first
  end
end

#descriptionObject



483
484
485
# File 'lib/avo/base_resource.rb', line 483

def description
  description_field&.value
end

#description_fieldObject



475
476
477
478
479
480
481
# File 'lib/avo/base_resource.rb', line 475

def description_field
  get_field_definitions.find do |field|
    field.as_description.present?
  end
rescue
  nil
end

#file_hashObject



340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/avo/base_resource.rb', line 340

def file_hash
  content_to_be_hashed = ""

  # resource file hash
  resource_path = Rails.root.join("app", "avo", "resources", "#{self.class.name.underscore}.rb").to_s
  if File.file? resource_path
    content_to_be_hashed += File.read(resource_path)
  end

  # policy file hash
  policy_path = Rails.root.join("app", "policies", "#{self.class.name.underscore.gsub("_resource", "")}_policy.rb").to_s
  if File.file? policy_path
    content_to_be_hashed += File.read(policy_path)
  end

  Digest::MD5.hexdigest(content_to_be_hashed)
end

#fill_model(model, params, extra_params: []) ⇒ Object



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/avo/base_resource.rb', line 306

def fill_model(model, params, extra_params: [])
  # Map the received params to their actual fields
  fields_by_database_id = get_field_definitions
    .reject do |field|
      field.computed
    end
    .map do |field|
      [field.database_id.to_s, field]
    end
    .to_h

  # Write the field values
  params.each do |key, value|
    field = fields_by_database_id[key]

    next unless field.present?

    model = field.fill_field model, key, value, params
  end

  # Write the user configured extra params to the model
  if extra_params.present?
    # Let Rails fill in the rest of the params
    model.assign_attributes params.permit(extra_params)
  end

  model
end

#find_record(id, query: nil) ⇒ Object



499
500
501
502
503
# File 'lib/avo/base_resource.rb', line 499

def find_record(id, query: nil)
  query ||= self.class.find_scope

  self.class.find_record_method.call(model_class: query, id: id)
end

#form_scopeObject



487
488
489
# File 'lib/avo/base_resource.rb', line 487

def form_scope
  model_class.base_class.to_s.underscore.downcase
end

#get_action_arguments(action_class) ⇒ Object



191
192
193
194
195
# File 'lib/avo/base_resource.rb', line 191

def get_action_arguments(action_class)
  action = get_actions.find { |action| action[:class].to_s == action_class.to_s }

  action[:arguments]
end

#get_actionsObject



185
186
187
188
189
# File 'lib/avo/base_resource.rb', line 185

def get_actions
  return [] if self.class.actions_loader.blank?

  self.class.actions_loader.bag
end

#get_filter_arguments(filter_class) ⇒ Object



179
180
181
182
183
# File 'lib/avo/base_resource.rb', line 179

def get_filter_arguments(filter_class)
  filter = get_filters.find { |filter| filter[:class] == filter_class.constantize }

  filter[:arguments]
end

#get_filtersObject



173
174
175
176
177
# File 'lib/avo/base_resource.rb', line 173

def get_filters
  return [] if self.class.filters_loader.blank?

  self.class.filters_loader.bag
end

#get_grid_fieldsObject



167
168
169
170
171
# File 'lib/avo/base_resource.rb', line 167

def get_grid_fields
  return if self.class.grid_loader.blank?

  self.class.grid_loader.hydrate(model: @model, view: @view, resource: self)
end

#has_model_id?Boolean

Returns:

  • (Boolean)


495
496
497
# File 'lib/avo/base_resource.rb', line 495

def has_model_id?
  model.present? && model.id.present?
end

#hydrate(model: nil, view: nil, user: nil, params: nil) ⇒ Object



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/avo/base_resource.rb', line 153

def hydrate(model: nil, view: nil, user: nil, params: nil)
  @view = view if view.present?
  @user = user if user.present?
  @params = params if params.present?

  if model.present?
    @model = model

    hydrate_model_with_default_values if @view == :new
  end

  self
end

#hydrate_model_with_default_valuesObject

We will not overwrite any attributes that come pre-filled in the model.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/avo/base_resource.rb', line 367

def hydrate_model_with_default_values
  default_values = get_fields
    .select do |field|
      !field.computed
    end
    .map do |field|
      id = field.id
      value = field.value

      if field.type == "belongs_to"
        id = field.foreign_key.to_sym

        reflection = @model._reflections[@params[:via_relation]]

        if field.polymorphic_as.present? && field.types.map(&:to_s).include?(@params[:via_relation_class])
          # set the value to the actual record
          value = @params[:via_relation_class].safe_constantize.find(@params[:via_resource_id])
        elsif reflection.present? && reflection.foreign_key.present? && field.id.to_s == @params[:via_relation].to_s
          resource = Avo::App.get_resource_by_model_name params[:via_relation_class]
          model = resource.find_record @params[:via_resource_id]
          id_param = reflection.options[:primary_key] || :id

          value = model.send(id_param)
        end
      end

      [id, value]
    end
    .to_h
    .select do |id, value|
      value.present?
    end

  default_values.each do |id, value|
    if @model.send(id).nil?
      @model.send("#{id}=", value)
    end
  end
end

#labelObject



447
448
449
# File 'lib/avo/base_resource.rb', line 447

def label
  label_field&.value || model_title
end

#label_fieldObject



439
440
441
442
443
444
445
# File 'lib/avo/base_resource.rb', line 439

def label_field
  get_field_definitions.find do |field|
    field.as_label.present?
  end
rescue
  nil
end

#model_classObject



214
215
216
217
218
219
220
221
222
223
# File 'lib/avo/base_resource.rb', line 214

def model_class
  # get the model class off of the static property
  return self.class.model_class if self.class.model_class.present?

  # get the model class off of the model
  return @model.base_class if @model.present?

  # generate a model class
  class_name_without_resource.safe_constantize
end

#model_idObject



225
226
227
# File 'lib/avo/base_resource.rb', line 225

def model_id
  @model.send id
end

#model_keyObject

This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish



419
420
421
# File 'lib/avo/base_resource.rb', line 419

def model_key
  model_class.model_name.plural
end

#model_nameObject



423
424
425
# File 'lib/avo/base_resource.rb', line 423

def model_name
  model_class.model_name
end

#model_titleObject



229
230
231
232
233
234
235
236
237
238
# File 'lib/avo/base_resource.rb', line 229

def model_title
  return name if @model.nil?

  the_title = @model.send title
  return the_title if the_title.present?

  model_id
rescue
  name
end

#nameObject



256
257
258
259
260
261
262
263
264
265
266
# File 'lib/avo/base_resource.rb', line 256

def name
  default = class_name_without_resource.to_s.gsub('::', ' ').underscore.humanize

  return @name if @name.present?

  if translation_key && ::Avo::App.translation_enabled
    t(translation_key, count: 1, default: default).capitalize
  else
    default
  end
end


288
289
290
# File 'lib/avo/base_resource.rb', line 288

def navigation_label
  plural_name.humanize
end

#ordering_host(**args) ⇒ Object



491
492
493
# File 'lib/avo/base_resource.rb', line 491

def ordering_host(**args)
  Avo::Hosts::Ordering.new resource: self, options: self.class.ordering, **args
end

#plural_nameObject



272
273
274
275
276
277
278
279
280
# File 'lib/avo/base_resource.rb', line 272

def plural_name
  default = name.pluralize

  if translation_key && ::Avo::App.translation_enabled
    t(translation_key, count: 2, default: default).capitalize
  else
    default
  end
end

#recordObject Also known as: model



148
149
150
# File 'lib/avo/base_resource.rb', line 148

def record
  @model
end

#record_pathObject



431
432
433
# File 'lib/avo/base_resource.rb', line 431

def record_path
  resource_path(model: model, resource: self)
end

#records_pathObject



435
436
437
# File 'lib/avo/base_resource.rb', line 435

def records_path
  resources_path(resource: self)
end

#resource_descriptionObject



240
241
242
243
244
245
246
247
248
# File 'lib/avo/base_resource.rb', line 240

def resource_description
  return instance_exec(&self.class.description) if self.class.description.respond_to? :call

  # Show the description only on the resource index view.
  # If the user wants to conditionally it on all pages, they should use a block.
  if view == :index
    return self.class.description if self.class.description.is_a? String
  end
end

#route_keyObject



407
408
409
# File 'lib/avo/base_resource.rb', line 407

def route_key
  class_name_without_resource.underscore.pluralize
end

#singular_model_keyObject



427
428
429
# File 'lib/avo/base_resource.rb', line 427

def singular_model_key
  model_class.model_name.singular
end

#singular_nameObject



268
269
270
# File 'lib/avo/base_resource.rb', line 268

def singular_name
  name
end

#singular_route_keyObject



411
412
413
# File 'lib/avo/base_resource.rb', line 411

def singular_route_key
  route_key.singularize
end

#translation_keyObject



250
251
252
253
254
# File 'lib/avo/base_resource.rb', line 250

def translation_key
  return "avo.resource_translations.#{class_name_without_resource.underscore}" if ::Avo::App.translation_enabled

  self.class.translation_key
end

#underscore_nameObject



282
283
284
285
286
# File 'lib/avo/base_resource.rb', line 282

def underscore_name
  return @name if @name.present?

  self.class.name.demodulize.underscore
end