Class: Avo::BaseResource
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
#get_stimulus_controllers, #stimulus_data_attributes
#has_show_controls?, #render_show_controls
#with_new_items
#fields, #get_field, #get_field_definitions, #get_fields, #get_items, #get_tabs, #hydrate_fields, #tab_groups, #tools
Constructor Details
Returns a new instance of BaseResource.
137
138
139
140
141
142
143
|
# File 'lib/avo/base_resource.rb', line 137
def initialize
unless self.class.model_class.present?
if model_class.present? && model_class.respond_to?(:base_class)
self.class.model_class = model_class.base_class
end
end
end
|
Instance Attribute Details
#params ⇒ Object
Returns the value of attribute params.
26
27
28
|
# File 'lib/avo/base_resource.rb', line 26
def params
@params
end
|
#reflection ⇒ Object
Returns the value of attribute reflection.
24
25
26
|
# File 'lib/avo/base_resource.rb', line 24
def reflection
@reflection
end
|
#user ⇒ Object
Returns the value of attribute user.
25
26
27
|
# File 'lib/avo/base_resource.rb', line 25
def user
@user
end
|
#view ⇒ Object
Returns the value of attribute view.
23
24
25
|
# File 'lib/avo/base_resource.rb', line 23
def view
@view
end
|
Class Method Details
.action(action_class, arguments: {}) ⇒ Object
65
66
67
68
69
70
|
# File 'lib/avo/base_resource.rb', line 65
def action(action_class, arguments: {})
self.actions_loader ||= Avo::Loaders::Loader.new
action = { class: action_class, arguments: arguments }
self.actions_loader.use action
end
|
.filter(filter_class, arguments: {}) ⇒ Object
72
73
74
75
76
77
|
# File 'lib/avo/base_resource.rb', line 72
def filter(filter_class, arguments: {})
self.filters_loader ||= Avo::Loaders::Loader.new
filter = { class: filter_class , arguments: arguments }
self.filters_loader.use filter
end
|
.find_scope ⇒ Object
This resolves the scope when finding records (not “where” queries)
93
94
95
96
97
|
# File 'lib/avo/base_resource.rb', line 93
def find_scope
final_scope = resolve_find_scope.present? ? resolve_find_scope.call(model_class: model_class) : model_class
authorization.apply_policy final_scope
end
|
.get_available_models ⇒ Object
126
127
128
|
# File 'lib/avo/base_resource.rb', line 126
def get_available_models
ApplicationRecord.descendants
end
|
.get_record_associations(record) ⇒ Object
109
110
111
|
# File 'lib/avo/base_resource.rb', line 109
def get_record_associations(record)
record._reflections
end
|
.grid(&block) ⇒ Object
58
59
60
61
62
63
|
# File 'lib/avo/base_resource.rb', line 58
def grid(&block)
grid_collector = GridCollector.new
grid_collector.instance_eval(&block)
self.grid_loader = grid_collector
end
|
.order_actions ⇒ Object
103
104
105
106
107
|
# File 'lib/avo/base_resource.rb', line 103
def order_actions
return {} if ordering.blank?
ordering.dig(:actions) || {}
end
|
.query_scope ⇒ Object
This resolves the scope when doing “where” queries (not find queries)
86
87
88
89
90
|
# File 'lib/avo/base_resource.rb', line 86
def query_scope
final_scope = resolve_query_scope.present? ? resolve_query_scope.call(model_class: model_class) : model_class
authorization.apply_policy final_scope
end
|
.scope ⇒ Object
This is the search_query scope This should be removed and passed to the search block
81
82
83
|
# File 'lib/avo/base_resource.rb', line 81
def scope
query_scope
end
|
.valid_association_name(record, association_name) ⇒ Object
113
114
115
116
117
|
# File 'lib/avo/base_resource.rb', line 113
def valid_association_name(record, association_name)
get_record_associations(record).keys.find do |name|
name == association_name
end
end
|
.valid_attachment_name(record, association_name) ⇒ Object
119
120
121
122
123
124
|
# File 'lib/avo/base_resource.rb', line 119
def valid_attachment_name(record, association_name)
association_exists = get_record_associations(record).keys.any? do |name|
name == "#{association_name}_attachment" || name == "#{association_name}_attachments"
end
return association_name if association_exists
end
|
.valid_model_class(model_class) ⇒ Object
130
131
132
133
134
|
# File 'lib/avo/base_resource.rb', line 130
def valid_model_class(model_class)
get_available_models.find do |m|
m.to_s == model_class.to_s
end
end
|
Instance Method Details
#attached_file_fields ⇒ Object
297
298
299
300
301
|
# File 'lib/avo/base_resource.rb', line 297
def attached_file_fields
get_field_definitions.select do |field|
[Avo::Fields::FileField, Avo::Fields::FilesField].include? field.class
end
end
|
#authorization(user: nil) ⇒ Object
332
333
334
335
|
# File 'lib/avo/base_resource.rb', line 332
def authorization(user: nil)
current_user = user || Avo::App.current_user
Avo::Services::AuthorizationService.new(current_user, model || model_class, policy_class: authorization_policy)
end
|
#available_view_types ⇒ Object
289
290
291
292
293
294
295
|
# File 'lib/avo/base_resource.rb', line 289
def available_view_types
view_types = [:table]
view_types << :grid if get_grid_fields.present?
view_types
end
|
#avatar ⇒ Object
452
453
454
455
456
457
458
459
460
|
# File 'lib/avo/base_resource.rb', line 452
def avatar
return avatar_field.to_image if avatar_field.respond_to? :to_image
return avatar_field.value.variant(resize_to_limit: [480, 480]) if avatar_field.type == "file"
avatar_field.value
rescue
nil
end
|
#avatar_field ⇒ Object
444
445
446
447
448
449
450
|
# File 'lib/avo/base_resource.rb', line 444
def avatar_field
get_field_definitions.find do |field|
field.as_avatar.present?
end
rescue
nil
end
|
#avatar_type ⇒ Object
462
463
464
465
466
|
# File 'lib/avo/base_resource.rb', line 462
def avatar_type
avatar_field.as_avatar
rescue
nil
end
|
#cache_hash(parent_model) ⇒ Object
355
356
357
358
359
360
361
|
# File 'lib/avo/base_resource.rb', line 355
def cache_hash(parent_model)
if parent_model.present?
[model, file_hash, parent_model]
else
[model, file_hash]
end
end
|
#class_name_without_resource ⇒ Object
207
208
209
|
# File 'lib/avo/base_resource.rb', line 207
def class_name_without_resource
self.class.name.demodulize.delete_suffix("Resource")
end
|
#default_panel_name ⇒ Object
194
195
196
197
198
199
200
201
202
203
204
205
|
# File 'lib/avo/base_resource.rb', line 194
def default_panel_name
return @params[:related_name].capitalize if @params.present? && @params[:related_name].present?
case @view
when :show
model_title
when :edit
model_title
when :new
t("avo.create_new_item", item: name.downcase).upcase_first
end
end
|
#description ⇒ Object
476
477
478
|
# File 'lib/avo/base_resource.rb', line 476
def description
description_field&.value
end
|
#description_field ⇒ Object
468
469
470
471
472
473
474
|
# File 'lib/avo/base_resource.rb', line 468
def description_field
get_field_definitions.find do |field|
field.as_description.present?
end
rescue
nil
end
|
#file_hash ⇒ Object
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
|
# File 'lib/avo/base_resource.rb', line 337
def file_hash
content_to_be_hashed = ""
resource_path = Rails.root.join("app", "avo", "resources", "#{self.class.name.underscore}.rb").to_s
if File.file? resource_path
content_to_be_hashed += File.read(resource_path)
end
policy_path = Rails.root.join("app", "policies", "#{self.class.name.underscore.gsub("_resource", "")}_policy.rb").to_s
if File.file? policy_path
content_to_be_hashed += File.read(policy_path)
end
Digest::MD5.hexdigest(content_to_be_hashed)
end
|
#fill_model(model, params, extra_params: []) ⇒ Object
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
|
# File 'lib/avo/base_resource.rb', line 303
def fill_model(model, params, extra_params: [])
fields_by_database_id = get_field_definitions
.reject do |field|
field.computed
end
.map do |field|
[field.database_id.to_s, field]
end
.to_h
params.each do |key, value|
field = fields_by_database_id[key]
next unless field.present?
model = field.fill_field model, key, value, params
end
if .present?
model.assign_attributes params.permit()
end
model
end
|
480
481
482
|
# File 'lib/avo/base_resource.rb', line 480
def form_scope
model_class.base_class.to_s.underscore.downcase
end
|
#get_action_arguments(action_class) ⇒ Object
188
189
190
191
192
|
# File 'lib/avo/base_resource.rb', line 188
def get_action_arguments(action_class)
action = get_actions.find { |action| action[:class].to_s == action_class.to_s }
action[:arguments]
end
|
#get_actions ⇒ Object
182
183
184
185
186
|
# File 'lib/avo/base_resource.rb', line 182
def get_actions
return [] if self.class.actions_loader.blank?
self.class.actions_loader.bag
end
|
#get_filter_arguments(filter_class) ⇒ Object
176
177
178
179
180
|
# File 'lib/avo/base_resource.rb', line 176
def get_filter_arguments(filter_class)
filter = get_filters.find { |filter| filter[:class] == filter_class.constantize }
filter[:arguments]
end
|
#get_filters ⇒ Object
170
171
172
173
174
|
# File 'lib/avo/base_resource.rb', line 170
def get_filters
return [] if self.class.filters_loader.blank?
self.class.filters_loader.bag
end
|
#get_grid_fields ⇒ Object
164
165
166
167
168
|
# File 'lib/avo/base_resource.rb', line 164
def get_grid_fields
return if self.class.grid_loader.blank?
self.class.grid_loader.hydrate(model: @model, view: @view, resource: self)
end
|
#has_model_id? ⇒ Boolean
488
489
490
|
# File 'lib/avo/base_resource.rb', line 488
def has_model_id?
model.present? && model.id.present?
end
|
#hydrate(model: nil, view: nil, user: nil, params: nil) ⇒ Object
150
151
152
153
154
155
156
157
158
159
160
161
162
|
# File 'lib/avo/base_resource.rb', line 150
def hydrate(model: nil, view: nil, user: nil, params: nil)
@view = view if view.present?
@user = user if user.present?
@params = params if params.present?
if model.present?
@model = model
hydrate_model_with_default_values if @view == :new
end
self
end
|
#hydrate_model_with_default_values ⇒ Object
We will not overwrite any attributes that come pre-filled in the model.
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
|
# File 'lib/avo/base_resource.rb', line 364
def hydrate_model_with_default_values
default_values = get_fields
.select do |field|
!field.computed
end
.map do |field|
id = field.id
value = field.value
if field.type == "belongs_to"
id = field.foreign_key.to_sym
reflection = @model._reflections[@params[:via_relation]]
if field.polymorphic_as.present? && field.types.map(&:to_s).include?(@params[:via_relation_class])
value = @params[:via_relation_class].safe_constantize.find(@params[:via_resource_id])
elsif reflection.present? && reflection.foreign_key.present? && field.id.to_s == @params[:via_relation].to_s
value = @params[:via_resource_id]
end
end
[id, value]
end
.to_h
.select do |id, value|
value.present?
end
default_values.each do |id, value|
if @model.send(id).nil?
@model.send("#{id}=", value)
end
end
end
|
#label ⇒ Object
440
441
442
|
# File 'lib/avo/base_resource.rb', line 440
def label
label_field&.value || model_title
end
|
#label_field ⇒ Object
432
433
434
435
436
437
438
|
# File 'lib/avo/base_resource.rb', line 432
def label_field
get_field_definitions.find do |field|
field.as_label.present?
end
rescue
nil
end
|
#model_class ⇒ Object
211
212
213
214
215
216
217
218
219
220
|
# File 'lib/avo/base_resource.rb', line 211
def model_class
return self.class.model_class if self.class.model_class.present?
return @model.base_class if @model.present?
class_name_without_resource.safe_constantize
end
|
#model_id ⇒ Object
222
223
224
|
# File 'lib/avo/base_resource.rb', line 222
def model_id
@model.send id
end
|
#model_key ⇒ Object
This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish
412
413
414
|
# File 'lib/avo/base_resource.rb', line 412
def model_key
model_class.model_name.plural
end
|
#model_name ⇒ Object
416
417
418
|
# File 'lib/avo/base_resource.rb', line 416
def model_name
model_class.model_name
end
|
#model_title ⇒ Object
226
227
228
229
230
231
232
233
234
235
|
# File 'lib/avo/base_resource.rb', line 226
def model_title
return name if @model.nil?
the_title = @model.send title
return the_title if the_title.present?
model_id
rescue
name
end
|
#name ⇒ Object
253
254
255
256
257
258
259
260
261
262
263
|
# File 'lib/avo/base_resource.rb', line 253
def name
default = class_name_without_resource.to_s.gsub('::', ' ').underscore.humanize
return @name if @name.present?
if translation_key && ::Avo::App.translation_enabled
t(translation_key, count: 1, default: default).capitalize
else
default
end
end
|
#navigation_label ⇒ Object
285
286
287
|
# File 'lib/avo/base_resource.rb', line 285
def navigation_label
plural_name.humanize
end
|
#ordering_host(**args) ⇒ Object
484
485
486
|
# File 'lib/avo/base_resource.rb', line 484
def ordering_host(**args)
Avo::Hosts::Ordering.new resource: self, options: self.class.ordering, **args
end
|
#plural_name ⇒ Object
269
270
271
272
273
274
275
276
277
|
# File 'lib/avo/base_resource.rb', line 269
def plural_name
default = name.pluralize
if translation_key && ::Avo::App.translation_enabled
t(translation_key, count: 2, default: default).capitalize
else
default
end
end
|
#record ⇒ Object
Also known as:
model
145
146
147
|
# File 'lib/avo/base_resource.rb', line 145
def record
@model
end
|
#record_path ⇒ Object
424
425
426
|
# File 'lib/avo/base_resource.rb', line 424
def record_path
resource_path(model: model, resource: self)
end
|
#records_path ⇒ Object
428
429
430
|
# File 'lib/avo/base_resource.rb', line 428
def records_path
resources_path(resource: self)
end
|
#resource_description ⇒ Object
237
238
239
240
241
242
243
244
245
|
# File 'lib/avo/base_resource.rb', line 237
def resource_description
return instance_exec(&self.class.description) if self.class.description.respond_to? :call
if view == :index
return self.class.description if self.class.description.is_a? String
end
end
|
#route_key ⇒ Object
400
401
402
|
# File 'lib/avo/base_resource.rb', line 400
def route_key
class_name_without_resource.underscore.pluralize
end
|
#singular_model_key ⇒ Object
420
421
422
|
# File 'lib/avo/base_resource.rb', line 420
def singular_model_key
model_class.model_name.singular
end
|
#singular_name ⇒ Object
265
266
267
|
# File 'lib/avo/base_resource.rb', line 265
def singular_name
name
end
|
#singular_route_key ⇒ Object
404
405
406
|
# File 'lib/avo/base_resource.rb', line 404
def singular_route_key
route_key.singularize
end
|
#translation_key ⇒ Object
247
248
249
250
251
|
# File 'lib/avo/base_resource.rb', line 247
def translation_key
return "avo.resource_translations.#{class_name_without_resource.underscore}" if ::Avo::App.translation_enabled
self.class.translation_key
end
|
#underscore_name ⇒ Object
279
280
281
282
283
|
# File 'lib/avo/base_resource.rb', line 279
def underscore_name
return @name if @name.present?
self.class.name.demodulize.underscore
end
|