Class: Avo::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/avo/configuration.rb

Defined Under Namespace

Classes: Branding

Constant Summary collapse

CONTAINER_WIDTH_DEFAULTS =
{
  index: :large,
  show: :small,
  new: :small,
  edit: :small,
  create: :small,
  update: :small
}.freeze
VALID_CONTAINER_WIDTHS =
%i[full large small].freeze
CONTAINER_WIDTH_GROUPS =
{
  forms: %i[new edit create update],
  display: %i[index show],
  single: %i[show new edit create update]
}.freeze
RESOURCE_ROW_CONTROLS_CONFIG_DEFAULTS =
{
  placement: :right,
  float: false,
  show_on_hover: false
}.freeze
HOTKEYS_DEFAULTS =
{
  enabled: true,
  show_key_badges: true
}.freeze
RTL_LOCALES =

Known RTL (Right-to-Left) locale codes

%w[ar he fa ur yi ps sd ku ckb ug dv].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeConfiguration

Returns a new instance of Configuration.



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/avo/configuration.rb', line 118

def initialize
  @root_path = "/avo"
  @app_name = ::Rails.application.class.to_s.split("::").first.underscore.humanize(keep_id_suffix: true)
  @timezone = "UTC"
  @per_page = 24
  @per_page_steps = [12, 24, 48, 72]
  @via_per_page = 8
  @locale = nil
  @currency = "USD"
  @default_view_type = :table
  @license_key = nil
  @current_user = proc {}
  @authenticate = proc {}
  @explicit_authorization = false
  @authorization_methods = {
    index: "index?",
    show: "show?",
    edit: "edit?",
    new: "new?",
    update: "update?",
    create: "create?",
    destroy: "destroy?"
  }
  @id_links_to_resource = false
  @cache_resources_on_index_view = Avo::PACKED
  @persistence = {
    driver: nil
  }
  @context = proc {}
  @initial_breadcrumbs = proc {
    add_breadcrumb title: I18n.t("avo.home").humanize, path: avo.root_path, icon: "tabler/outline/home"
  }
  @hide_layout_when_printing = false
  @home_path = nil
  @search_debounce = 300
  @view_component_path = "app/components"
  @display_license_request_timeout_error = true
  @current_user_resource_name = "user"
  @raise_error_on_missing_policy = false
  @buttons_on_form_footers = false
  @main_menu = nil
  @profile_menu = nil
  @model_resource_mapping = {}
  @resource_default_view = Avo::ViewInquirer.new("show")
  @authorization_client = :pundit
  @field_wrapper_layout = :inline
  @resources = nil
  @resource_parent_controller = "Avo::ResourcesController"
  @cache_store = computed_cache_store
  @logger = default_logger
  @turbo = default_turbo
  @default_url_options = []
  @pagination = {}
  @click_row_to_view_record = true
  @alert_dismiss_time = 5000
  @is_admin_method = :is_admin?
  @is_developer_method = :is_developer?
  @search_results_count = 8
  @first_sorting_option = :desc # :desc or :asc
  @associations_lookup_list_limit = 1000
  @exclude_from_status = []
  @column_names_mapping = {}
  @column_types_mapping = {}
  @resource_row_controls_config = {}
  @hotkeys = {}
  @global_search = {
    enabled: true,
    navigation_section: true
  }
  @model_generator_hook = true
  @send_metadata = true
  @use_stacked_fields = false
  @default_editor_url = "cursor://file/%{path}"
  @sidebar_toggle_visible = true
  @body_classes = []
end

Instance Attribute Details

#alert_dismiss_timeObject

Returns the value of attribute alert_dismiss_time.



51
52
53
# File 'lib/avo/configuration.rb', line 51

def alert_dismiss_time
  @alert_dismiss_time
end

#app_nameObject



262
263
264
# File 'lib/avo/configuration.rb', line 262

def app_name
  Avo::ExecutionContext.new(target: @app_name).handle
end

#associations_lookup_list_limitObject

Returns the value of attribute associations_lookup_list_limit.



56
57
58
# File 'lib/avo/configuration.rb', line 56

def associations_lookup_list_limit
  @associations_lookup_list_limit
end

#authenticateObject

Returns the value of attribute authenticate.



24
25
26
# File 'lib/avo/configuration.rb', line 24

def authenticate
  @authenticate
end

#authorization_clientObject

Returns the value of attribute authorization_client.



43
44
45
# File 'lib/avo/configuration.rb', line 43

def authorization_client
  @authorization_client
end

#authorization_methodsObject

Returns the value of attribute authorization_methods.



23
24
25
# File 'lib/avo/configuration.rb', line 23

def authorization_methods
  @authorization_methods
end

#body_classesObject



362
363
364
# File 'lib/avo/configuration.rb', line 362

def body_classes
  Avo::ExecutionContext.new(target: @body_classes).handle
end

#brandingObject



258
259
260
# File 'lib/avo/configuration.rb', line 258

def branding
  Avo::Configuration::Branding.new(**@branding || {})
end

#buttons_on_form_footersObject

Returns the value of attribute buttons_on_form_footers.



38
39
40
# File 'lib/avo/configuration.rb', line 38

def buttons_on_form_footers
  @buttons_on_form_footers
end

#cache_resources_on_index_viewObject

Returns the value of attribute cache_resources_on_index_view.



27
28
29
# File 'lib/avo/configuration.rb', line 27

def cache_resources_on_index_view
  @cache_resources_on_index_view
end

#cache_storeObject



270
271
272
273
274
275
# File 'lib/avo/configuration.rb', line 270

def cache_store
  Avo::ExecutionContext.new(
    target: @cache_store,
    production_rejected_cache_stores: %w[ActiveSupport::Cache::MemoryStore ActiveSupport::Cache::NullStore]
  ).handle
end

#click_row_to_view_recordObject

Returns the value of attribute click_row_to_view_record.



50
51
52
# File 'lib/avo/configuration.rb', line 50

def click_row_to_view_record
  @click_row_to_view_record
end

#column_names_mappingObject

Returns the value of attribute column_names_mapping.



57
58
59
# File 'lib/avo/configuration.rb', line 57

def column_names_mapping
  @column_names_mapping
end

#column_types_mappingObject

Returns the value of attribute column_types_mapping.



58
59
60
# File 'lib/avo/configuration.rb', line 58

def column_types_mapping
  @column_types_mapping
end

#contextObject

Returns the value of attribute context.



28
29
30
# File 'lib/avo/configuration.rb', line 28

def context
  @context
end

#currencyObject

Returns the value of attribute currency.



20
21
22
# File 'lib/avo/configuration.rb', line 20

def currency
  @currency
end

#current_userObject

Returns the value of attribute current_user.



25
26
27
# File 'lib/avo/configuration.rb', line 25

def current_user
  @current_user
end

#current_user_resource_nameObject

Returns the value of attribute current_user_resource_name.



35
36
37
# File 'lib/avo/configuration.rb', line 35

def current_user_resource_name
  @current_user_resource_name
end

#default_editor_urlObject

Returns the value of attribute default_editor_url.



62
63
64
# File 'lib/avo/configuration.rb', line 62

def default_editor_url
  @default_editor_url
end

#default_url_optionsObject

Returns the value of attribute default_url_options.



49
50
51
# File 'lib/avo/configuration.rb', line 49

def default_url_options
  @default_url_options
end

#default_view_typeObject

Returns the value of attribute default_view_type.



21
22
23
# File 'lib/avo/configuration.rb', line 21

def default_view_type
  @default_view_type
end

#display_license_request_timeout_errorObject

Returns the value of attribute display_license_request_timeout_error.



34
35
36
# File 'lib/avo/configuration.rb', line 34

def display_license_request_timeout_error
  @display_license_request_timeout_error
end

#exclude_from_statusObject



320
321
322
# File 'lib/avo/configuration.rb', line 320

def exclude_from_status
  Avo::ExecutionContext.new(target: @exclude_from_status).handle
end

#explicit_authorizationObject



358
359
360
# File 'lib/avo/configuration.rb', line 358

def explicit_authorization
  Avo::ExecutionContext.new(target: @explicit_authorization).handle
end

#field_wrapper_layoutObject

Returns the value of attribute field_wrapper_layout.



44
45
46
# File 'lib/avo/configuration.rb', line 44

def field_wrapper_layout
  @field_wrapper_layout
end

#first_sorting_optionObject

Returns the value of attribute first_sorting_option.



55
56
57
# File 'lib/avo/configuration.rb', line 55

def first_sorting_option
  @first_sorting_option
end

#global_searchObject

Returns the value of attribute global_search.



37
38
39
# File 'lib/avo/configuration.rb', line 37

def global_search
  @global_search
end

#hide_layout_when_printingObject

Returns the value of attribute hide_layout_when_printing.



29
30
31
# File 'lib/avo/configuration.rb', line 29

def hide_layout_when_printing
  @hide_layout_when_printing
end

#home_pathObject

Returns the value of attribute home_path.



31
32
33
# File 'lib/avo/configuration.rb', line 31

def home_path
  @home_path
end

#hotkeysObject



214
215
216
# File 'lib/avo/configuration.rb', line 214

def hotkeys
  HOTKEYS_DEFAULTS.merge @hotkeys
end

Returns the value of attribute id_links_to_resource.



26
27
28
# File 'lib/avo/configuration.rb', line 26

def id_links_to_resource
  @id_links_to_resource
end

#initial_breadcrumbsObject

Returns the value of attribute initial_breadcrumbs.



30
31
32
# File 'lib/avo/configuration.rb', line 30

def initial_breadcrumbs
  @initial_breadcrumbs
end

#is_admin_methodObject

Returns the value of attribute is_admin_method.



52
53
54
# File 'lib/avo/configuration.rb', line 52

def is_admin_method
  @is_admin_method
end

#is_developer_methodObject

Returns the value of attribute is_developer_method.



53
54
55
# File 'lib/avo/configuration.rb', line 53

def is_developer_method
  @is_developer_method
end

#license_keyObject

Returns the value of attribute license_key.



22
23
24
# File 'lib/avo/configuration.rb', line 22

def license_key
  @license_key
end

#localeObject

Returns the value of attribute locale.



19
20
21
# File 'lib/avo/configuration.rb', line 19

def locale
  @locale
end

#loggerObject



297
298
299
# File 'lib/avo/configuration.rb', line 297

def logger
  Avo::ExecutionContext.new(target: @logger).handle
end

Returns the value of attribute main_menu.



39
40
41
# File 'lib/avo/configuration.rb', line 39

def main_menu
  @main_menu
end

#model_generator_hookObject

Returns the value of attribute model_generator_hook.



59
60
61
# File 'lib/avo/configuration.rb', line 59

def model_generator_hook
  @model_generator_hook
end

#model_resource_mappingObject

Returns the value of attribute model_resource_mapping.



41
42
43
# File 'lib/avo/configuration.rb', line 41

def model_resource_mapping
  @model_resource_mapping
end

#paginationObject



332
333
334
# File 'lib/avo/configuration.rb', line 332

def pagination
  Avo::ExecutionContext.new(target: @pagination).handle
end

#per_pageObject

Returns the value of attribute per_page.



16
17
18
# File 'lib/avo/configuration.rb', line 16

def per_page
  @per_page
end

#per_page_stepsObject

Returns the value of attribute per_page_steps.



17
18
19
# File 'lib/avo/configuration.rb', line 17

def per_page_steps
  @per_page_steps
end

#persistenceObject



366
367
368
# File 'lib/avo/configuration.rb', line 366

def persistence
  Avo::ExecutionContext.new(target: @persistence).handle
end

#prefix_pathObject

Returns the value of attribute prefix_path.



47
48
49
# File 'lib/avo/configuration.rb', line 47

def prefix_path
  @prefix_path
end

#profile_menuObject

Returns the value of attribute profile_menu.



40
41
42
# File 'lib/avo/configuration.rb', line 40

def profile_menu
  @profile_menu
end

#raise_error_on_missing_policyObject

Returns the value of attribute raise_error_on_missing_policy.



36
37
38
# File 'lib/avo/configuration.rb', line 36

def raise_error_on_missing_policy
  @raise_error_on_missing_policy
end

#resource_default_viewObject

Returns the value of attribute resource_default_view.



42
43
44
# File 'lib/avo/configuration.rb', line 42

def resource_default_view
  @resource_default_view
end

#resource_parent_controllerObject

Returns the value of attribute resource_parent_controller.



48
49
50
# File 'lib/avo/configuration.rb', line 48

def resource_parent_controller
  @resource_parent_controller
end

#resource_row_controls_configObject



210
211
212
# File 'lib/avo/configuration.rb', line 210

def resource_row_controls_config
  RESOURCE_ROW_CONTROLS_CONFIG_DEFAULTS.merge @resource_row_controls_config
end

#resourcesObject

Returns the value of attribute resources.



46
47
48
# File 'lib/avo/configuration.rb', line 46

def resources
  @resources
end

#root_pathObject



252
253
254
255
256
# File 'lib/avo/configuration.rb', line 252

def root_path
  return "" if @root_path === "/"

  @root_path
end

#search_debounceObject

Returns the value of attribute search_debounce.



32
33
34
# File 'lib/avo/configuration.rb', line 32

def search_debounce
  @search_debounce
end

#search_results_countObject

Returns the value of attribute search_results_count.



54
55
56
# File 'lib/avo/configuration.rb', line 54

def search_results_count
  @search_results_count
end

#send_metadataObject

Returns the value of attribute send_metadata.



60
61
62
# File 'lib/avo/configuration.rb', line 60

def 
  @send_metadata
end

Returns the value of attribute sidebar_toggle_visible.



64
65
66
# File 'lib/avo/configuration.rb', line 64

def sidebar_toggle_visible
  @sidebar_toggle_visible
end

#sign_out_path_nameObject

Returns the value of attribute sign_out_path_name.



45
46
47
# File 'lib/avo/configuration.rb', line 45

def sign_out_path_name
  @sign_out_path_name
end

#timezoneObject

Returns the value of attribute timezone.



15
16
17
# File 'lib/avo/configuration.rb', line 15

def timezone
  @timezone
end

#turboObject



316
317
318
# File 'lib/avo/configuration.rb', line 316

def turbo
  Avo::ExecutionContext.new(target: @turbo).handle
end

#use_stacked_fieldsObject

Returns the value of attribute use_stacked_fields.



61
62
63
# File 'lib/avo/configuration.rb', line 61

def use_stacked_fields
  @use_stacked_fields
end

#via_per_pageObject

Returns the value of attribute via_per_page.



18
19
20
# File 'lib/avo/configuration.rb', line 18

def via_per_page
  @via_per_page
end

#view_component_pathObject

Returns the value of attribute view_component_path.



33
34
35
# File 'lib/avo/configuration.rb', line 33

def view_component_path
  @view_component_path
end

Class Method Details

.rtl_locale?(locale = I18n.locale) ⇒ Boolean

Check if the given locale is RTL

Returns:

  • (Boolean)


344
345
346
# File 'lib/avo/configuration.rb', line 344

def self.rtl_locale?(locale = I18n.locale)
  RTL_LOCALES.include?(locale.to_s.split("-").first.downcase)
end

Instance Method Details

#authenticate_with(&block) ⇒ Object



232
233
234
# File 'lib/avo/configuration.rb', line 232

def authenticate_with(&block)
  @authenticate = block if block.present?
end

#authorization_enabled?Boolean

Authorization is enabled when: (avo-pro gem is installed) AND (authorization_client is NOT nil)

Returns:

  • (Boolean)


220
221
222
# File 'lib/avo/configuration.rb', line 220

def authorization_enabled?
  @authorization_enabled ||= Avo.plugin_manager.installed?("avo-pro") && !authorization_client.nil?
end

#computed_cache_storeObject

When not in production we’ll just use the FileStore which is good enough. When running in production we’ll use Rails.cache if it’s not ActiveSupport::Cache::MemoryStore or ActiveSupport::Cache::NullStore. If it’s one of rejected cache stores, we’ll use the FileStore. We decided against the MemoryStore in production because it will not be shared between multiple processes (when using Puma).



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/avo/configuration.rb', line 281

def computed_cache_store
  file_store_instance = ActiveSupport::Cache.lookup_store(:file_store, Rails.root.join("tmp", "cache"))

  -> {
    if Rails.env.production?
      if Rails.cache.class.to_s.in?(production_rejected_cache_stores)
        file_store_instance
      else
        Rails.cache
      end
    else
      file_store_instance
    end
  }
end

#container_widthObject



114
115
116
# File 'lib/avo/configuration.rb', line 114

def container_width
  @container_width || CONTAINER_WIDTH_DEFAULTS
end

#container_width=(value) ⇒ Object



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/avo/configuration.rb', line 85

def container_width=(value)
  case value
  when NilClass
    @container_width = nil
  when Symbol
    raise ArgumentError, "Invalid container width: #{value}. Must be one of #{VALID_CONTAINER_WIDTHS}" unless VALID_CONTAINER_WIDTHS.include?(value)
    @container_width = CONTAINER_WIDTH_DEFAULTS.transform_values { value }
  when Hash
    valid_keys = CONTAINER_WIDTH_DEFAULTS.keys + CONTAINER_WIDTH_GROUPS.keys
    invalid_keys = value.keys.reject { |k| valid_keys.include?(k) }
    raise ArgumentError, "Invalid container width keys: #{invalid_keys}. Valid keys: #{valid_keys}" if invalid_keys.any?

    invalid_values = value.values.reject { |v| VALID_CONTAINER_WIDTHS.include?(v) }
    raise ArgumentError, "Invalid container widths: #{invalid_values}" if invalid_values.any?

    # Expand group aliases first
    expanded_aliases = value
      .select { |k, _| CONTAINER_WIDTH_GROUPS.key?(k) }
      .each_with_object({}) do |(alias_key, width), result|
        CONTAINER_WIDTH_GROUPS[alias_key].each { |view| result[view] = width }
      end

    # Specific keys win over group aliases
    specific_keys = value.reject { |k, _| CONTAINER_WIDTH_GROUPS.key?(k) }

    @container_width = CONTAINER_WIDTH_DEFAULTS.merge(expanded_aliases).merge(specific_keys)
  end
end

#current_user_method(&block) ⇒ Object



224
225
226
# File 'lib/avo/configuration.rb', line 224

def current_user_method(&block)
  @current_user = block if block.present?
end

#current_user_method=(method) ⇒ Object



228
229
230
# File 'lib/avo/configuration.rb', line 228

def current_user_method=(method)
  @current_user = method if method.present?
end

#default_localeObject



336
337
338
# File 'lib/avo/configuration.rb', line 336

def default_locale
  @locale || I18n.default_locale
end

#default_loggerObject



301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/avo/configuration.rb', line 301

def default_logger
  -> {
    file_logger = ActiveSupport::Logger.new(Rails.root.join("log", "avo.log"))

    file_logger.datetime_format = "%Y-%m-%d %H:%M:%S"
    file_logger.formatter = proc do |severity, time, progname, msg|
      "[Avo->] #{time}: #{msg}\n".tap do |i|
        puts i
      end
    end

    file_logger
  }
end

#default_turboObject



324
325
326
327
328
329
330
# File 'lib/avo/configuration.rb', line 324

def default_turbo
  -> do
    {
      instant_click: true
    }
  end
end

#mount_avo_engines=Object



374
375
376
377
378
# File 'lib/avo/configuration.rb', line 374

def mount_avo_engines=(...)
  raise "'mount_avo_engines' option is now obsolete. \n" \
    "Please refer to the upgrade guide for details on the new mounting point: \n" \
    "https://docs.avohq.io/3.0/upgrade.html#Avo's%20mounting%20point%20update"
end

#namespaceObject



244
245
246
247
248
249
250
# File 'lib/avo/configuration.rb', line 244

def namespace
  if Avo.configuration.root_path.present?
    Avo.configuration.root_path.delete "/"
  else
    root_path.delete "/"
  end
end

#rtl?Boolean

Check if the current locale is RTL

Returns:

  • (Boolean)


349
350
351
# File 'lib/avo/configuration.rb', line 349

def rtl?
  self.class.rtl_locale?(I18n.locale)
end

#session_persistence_enabled?Boolean

Returns:

  • (Boolean)


370
371
372
# File 'lib/avo/configuration.rb', line 370

def session_persistence_enabled?
  persistence[:driver] == :session
end

#set_context(&block) ⇒ Object



236
237
238
# File 'lib/avo/configuration.rb', line 236

def set_context(&block)
  @context = block if block.present?
end

#set_initial_breadcrumbs(&block) ⇒ Object



240
241
242
# File 'lib/avo/configuration.rb', line 240

def set_initial_breadcrumbs(&block)
  @initial_breadcrumbs = block if block.present?
end

#text_directionObject

Returns “rtl” or “ltr” based on current locale



354
355
356
# File 'lib/avo/configuration.rb', line 354

def text_direction
  rtl? ? "rtl" : "ltr"
end