Class: Avo::Configuration
- Inherits:
-
Object
- Object
- Avo::Configuration
- Includes:
- ResourceConfiguration
- Defined in:
- lib/avo/configuration.rb,
lib/avo/configuration/resource_configuration.rb
Defined Under Namespace
Modules: ResourceConfiguration Classes: Branding
Instance Attribute Summary collapse
- #app_name ⇒ Object
-
#authenticate ⇒ Object
Returns the value of attribute authenticate.
-
#authorization_client ⇒ Object
Returns the value of attribute authorization_client.
-
#authorization_methods ⇒ Object
Returns the value of attribute authorization_methods.
- #branding ⇒ Object
-
#buttons_on_form_footers ⇒ Object
Returns the value of attribute buttons_on_form_footers.
-
#cache_resource_filters ⇒ Object
Returns the value of attribute cache_resource_filters.
-
#cache_resources_on_index_view ⇒ Object
Returns the value of attribute cache_resources_on_index_view.
- #cache_store ⇒ Object
-
#context ⇒ Object
Returns the value of attribute context.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#current_user ⇒ Object
Returns the value of attribute current_user.
-
#current_user_resource_name ⇒ Object
Returns the value of attribute current_user_resource_name.
-
#default_view_type ⇒ Object
Returns the value of attribute default_view_type.
-
#disabled_features ⇒ Object
Returns the value of attribute disabled_features.
-
#display_breadcrumbs ⇒ Object
Returns the value of attribute display_breadcrumbs.
-
#display_license_request_timeout_error ⇒ Object
Returns the value of attribute display_license_request_timeout_error.
-
#field_wrapper_layout ⇒ Object
Returns the value of attribute field_wrapper_layout.
-
#full_width_container ⇒ Object
Returns the value of attribute full_width_container.
-
#full_width_index_view ⇒ Object
Returns the value of attribute full_width_index_view.
-
#hide_layout_when_printing ⇒ Object
Returns the value of attribute hide_layout_when_printing.
-
#home_path ⇒ Object
Returns the value of attribute home_path.
-
#id_links_to_resource ⇒ Object
Returns the value of attribute id_links_to_resource.
-
#initial_breadcrumbs ⇒ Object
Returns the value of attribute initial_breadcrumbs.
-
#license_key ⇒ Object
Returns the value of attribute license_key.
-
#locale ⇒ Object
Returns the value of attribute locale.
-
#main_menu ⇒ Object
Returns the value of attribute main_menu.
-
#model_resource_mapping ⇒ Object
Returns the value of attribute model_resource_mapping.
-
#mount_avo_engines ⇒ Object
Returns the value of attribute mount_avo_engines.
-
#per_page ⇒ Object
Returns the value of attribute per_page.
-
#per_page_steps ⇒ Object
Returns the value of attribute per_page_steps.
-
#prefix_path ⇒ Object
Returns the value of attribute prefix_path.
-
#profile_menu ⇒ Object
Returns the value of attribute profile_menu.
-
#raise_error_on_missing_policy ⇒ Object
Returns the value of attribute raise_error_on_missing_policy.
-
#resource_default_view ⇒ Object
Returns the value of attribute resource_default_view.
-
#resource_parent_controller ⇒ Object
Returns the value of attribute resource_parent_controller.
-
#resources ⇒ Object
Returns the value of attribute resources.
- #root_path ⇒ Object
-
#search_debounce ⇒ Object
Returns the value of attribute search_debounce.
-
#sign_out_path_name ⇒ Object
Returns the value of attribute sign_out_path_name.
-
#timezone ⇒ Object
Returns the value of attribute timezone.
-
#via_per_page ⇒ Object
Returns the value of attribute via_per_page.
-
#view_component_path ⇒ Object
Returns the value of attribute view_component_path.
Instance Method Summary collapse
- #authenticate_with(&block) ⇒ Object
-
#computed_cache_store ⇒ Object
When not in production or test we’ll just use the MemoryStore which is good enough.
- #current_user_method(&block) ⇒ Object
- #current_user_method=(method) ⇒ Object
- #feature_enabled?(feature) ⇒ Boolean
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
- #license ⇒ Object
- #license=(value) ⇒ Object
- #namespace ⇒ Object
- #set_context(&block) ⇒ Object
- #set_initial_breadcrumbs(&block) ⇒ Object
Methods included from ResourceConfiguration
#resource_controls_on_the_left?, #resource_controls_on_the_right?, #resource_controls_placement, #resource_controls_placement=
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/avo/configuration.rb', line 49 def initialize @root_path = "/avo" @app_name = ::Rails.application.class.to_s.split("::").first.underscore.humanize(keep_id_suffix: true) @timezone = "UTC" @per_page = 24 @per_page_steps = [12, 24, 48, 72] @via_per_page = 8 @locale = nil @currency = "USD" @default_view_type = :table @license_key = nil @current_user = proc {} @authenticate = proc {} @authorization_methods = { index: "index?", show: "show?", edit: "edit?", new: "new?", update: "update?", create: "create?", destroy: "destroy?" } @id_links_to_resource = false @full_width_container = false @full_width_index_view = false @cache_resources_on_index_view = Avo::PACKED @cache_resource_filters = false @context = proc {} @initial_breadcrumbs = proc { I18n.t("avo.home").humanize, avo.root_path } @display_breadcrumbs = true @hide_layout_when_printing = false @home_path = nil @search_debounce = 300 @view_component_path = "app/components" @display_license_request_timeout_error = true @current_user_resource_name = "user" @raise_error_on_missing_policy = false @disabled_features = [] @buttons_on_form_footers = false @main_menu = nil @profile_menu = nil @model_resource_mapping = {} @resource_default_view = Avo::ViewInquirer.new("show") @authorization_client = :pundit @field_wrapper_layout = :inline @resources = nil @resource_parent_controller = "Avo::ResourcesController" @mount_avo_engines = true @cache_store = computed_cache_store end |
Instance Attribute Details
#app_name ⇒ Object
144 145 146 |
# File 'lib/avo/configuration.rb', line 144 def app_name Avo::ExecutionContext.new(target: @app_name).handle end |
#authenticate ⇒ Object
Returns the value of attribute authenticate.
18 19 20 |
# File 'lib/avo/configuration.rb', line 18 def authenticate @authenticate end |
#authorization_client ⇒ Object
Returns the value of attribute authorization_client.
41 42 43 |
# File 'lib/avo/configuration.rb', line 41 def @authorization_client end |
#authorization_methods ⇒ Object
Returns the value of attribute authorization_methods.
17 18 19 |
# File 'lib/avo/configuration.rb', line 17 def @authorization_methods end |
#branding ⇒ Object
140 141 142 |
# File 'lib/avo/configuration.rb', line 140 def branding Avo::Configuration::Branding.new(**@branding || {}) end |
#buttons_on_form_footers ⇒ Object
Returns the value of attribute buttons_on_form_footers.
36 37 38 |
# File 'lib/avo/configuration.rb', line 36 def @buttons_on_form_footers end |
#cache_resource_filters ⇒ Object
Returns the value of attribute cache_resource_filters.
24 25 26 |
# File 'lib/avo/configuration.rb', line 24 def cache_resource_filters @cache_resource_filters end |
#cache_resources_on_index_view ⇒ Object
Returns the value of attribute cache_resources_on_index_view.
23 24 25 |
# File 'lib/avo/configuration.rb', line 23 def cache_resources_on_index_view @cache_resources_on_index_view end |
#cache_store ⇒ Object
170 171 172 173 174 175 |
# File 'lib/avo/configuration.rb', line 170 def cache_store Avo::ExecutionContext.new( target: @cache_store, production_rejected_cache_stores: %w[ActiveSupport::Cache::MemoryStore ActiveSupport::Cache::NullStore] ).handle end |
#context ⇒ Object
Returns the value of attribute context.
25 26 27 |
# File 'lib/avo/configuration.rb', line 25 def context @context end |
#currency ⇒ Object
Returns the value of attribute currency.
14 15 16 |
# File 'lib/avo/configuration.rb', line 14 def currency @currency end |
#current_user ⇒ Object
Returns the value of attribute current_user.
19 20 21 |
# File 'lib/avo/configuration.rb', line 19 def current_user @current_user end |
#current_user_resource_name ⇒ Object
Returns the value of attribute current_user_resource_name.
33 34 35 |
# File 'lib/avo/configuration.rb', line 33 def current_user_resource_name @current_user_resource_name end |
#default_view_type ⇒ Object
Returns the value of attribute default_view_type.
15 16 17 |
# File 'lib/avo/configuration.rb', line 15 def default_view_type @default_view_type end |
#disabled_features ⇒ Object
Returns the value of attribute disabled_features.
35 36 37 |
# File 'lib/avo/configuration.rb', line 35 def disabled_features @disabled_features end |
#display_breadcrumbs ⇒ Object
Returns the value of attribute display_breadcrumbs.
26 27 28 |
# File 'lib/avo/configuration.rb', line 26 def @display_breadcrumbs end |
#display_license_request_timeout_error ⇒ Object
Returns the value of attribute display_license_request_timeout_error.
32 33 34 |
# File 'lib/avo/configuration.rb', line 32 def display_license_request_timeout_error @display_license_request_timeout_error end |
#field_wrapper_layout ⇒ Object
Returns the value of attribute field_wrapper_layout.
42 43 44 |
# File 'lib/avo/configuration.rb', line 42 def field_wrapper_layout @field_wrapper_layout end |
#full_width_container ⇒ Object
Returns the value of attribute full_width_container.
21 22 23 |
# File 'lib/avo/configuration.rb', line 21 def full_width_container @full_width_container end |
#full_width_index_view ⇒ Object
Returns the value of attribute full_width_index_view.
22 23 24 |
# File 'lib/avo/configuration.rb', line 22 def full_width_index_view @full_width_index_view end |
#hide_layout_when_printing ⇒ Object
Returns the value of attribute hide_layout_when_printing.
27 28 29 |
# File 'lib/avo/configuration.rb', line 27 def hide_layout_when_printing @hide_layout_when_printing end |
#home_path ⇒ Object
Returns the value of attribute home_path.
29 30 31 |
# File 'lib/avo/configuration.rb', line 29 def home_path @home_path end |
#id_links_to_resource ⇒ Object
Returns the value of attribute id_links_to_resource.
20 21 22 |
# File 'lib/avo/configuration.rb', line 20 def id_links_to_resource @id_links_to_resource end |
#initial_breadcrumbs ⇒ Object
Returns the value of attribute initial_breadcrumbs.
28 29 30 |
# File 'lib/avo/configuration.rb', line 28 def @initial_breadcrumbs end |
#license_key ⇒ Object
Returns the value of attribute license_key.
16 17 18 |
# File 'lib/avo/configuration.rb', line 16 def license_key @license_key end |
#locale ⇒ Object
Returns the value of attribute locale.
13 14 15 |
# File 'lib/avo/configuration.rb', line 13 def locale @locale end |
#main_menu ⇒ Object
Returns the value of attribute main_menu.
37 38 39 |
# File 'lib/avo/configuration.rb', line 37 def @main_menu end |
#model_resource_mapping ⇒ Object
Returns the value of attribute model_resource_mapping.
39 40 41 |
# File 'lib/avo/configuration.rb', line 39 def model_resource_mapping @model_resource_mapping end |
#mount_avo_engines ⇒ Object
Returns the value of attribute mount_avo_engines.
47 48 49 |
# File 'lib/avo/configuration.rb', line 47 def mount_avo_engines @mount_avo_engines end |
#per_page ⇒ Object
Returns the value of attribute per_page.
10 11 12 |
# File 'lib/avo/configuration.rb', line 10 def per_page @per_page end |
#per_page_steps ⇒ Object
Returns the value of attribute per_page_steps.
11 12 13 |
# File 'lib/avo/configuration.rb', line 11 def per_page_steps @per_page_steps end |
#prefix_path ⇒ Object
Returns the value of attribute prefix_path.
45 46 47 |
# File 'lib/avo/configuration.rb', line 45 def prefix_path @prefix_path end |
#profile_menu ⇒ Object
Returns the value of attribute profile_menu.
38 39 40 |
# File 'lib/avo/configuration.rb', line 38 def @profile_menu end |
#raise_error_on_missing_policy ⇒ Object
Returns the value of attribute raise_error_on_missing_policy.
34 35 36 |
# File 'lib/avo/configuration.rb', line 34 def raise_error_on_missing_policy @raise_error_on_missing_policy end |
#resource_default_view ⇒ Object
Returns the value of attribute resource_default_view.
40 41 42 |
# File 'lib/avo/configuration.rb', line 40 def resource_default_view @resource_default_view end |
#resource_parent_controller ⇒ Object
Returns the value of attribute resource_parent_controller.
46 47 48 |
# File 'lib/avo/configuration.rb', line 46 def resource_parent_controller @resource_parent_controller end |
#resources ⇒ Object
Returns the value of attribute resources.
44 45 46 |
# File 'lib/avo/configuration.rb', line 44 def resources @resources end |
#root_path ⇒ Object
130 131 132 133 134 |
# File 'lib/avo/configuration.rb', line 130 def root_path return "" if @root_path === "/" @root_path end |
#search_debounce ⇒ Object
Returns the value of attribute search_debounce.
30 31 32 |
# File 'lib/avo/configuration.rb', line 30 def search_debounce @search_debounce end |
#sign_out_path_name ⇒ Object
Returns the value of attribute sign_out_path_name.
43 44 45 |
# File 'lib/avo/configuration.rb', line 43 def sign_out_path_name @sign_out_path_name end |
#timezone ⇒ Object
Returns the value of attribute timezone.
9 10 11 |
# File 'lib/avo/configuration.rb', line 9 def timezone @timezone end |
#via_per_page ⇒ Object
Returns the value of attribute via_per_page.
12 13 14 |
# File 'lib/avo/configuration.rb', line 12 def via_per_page @via_per_page end |
#view_component_path ⇒ Object
Returns the value of attribute view_component_path.
31 32 33 |
# File 'lib/avo/configuration.rb', line 31 def view_component_path @view_component_path end |
Instance Method Details
#authenticate_with(&block) ⇒ Object
110 111 112 |
# File 'lib/avo/configuration.rb', line 110 def authenticate_with(&block) @authenticate = block if block.present? end |
#computed_cache_store ⇒ Object
When not in production or test we’ll just use the MemoryStore which is good enough. When running in production we’ll use Rails.cache if it’s not ActiveSupport::Cache::MemoryStore or ActiveSupport::Cache::NullStore. If it’s one of rejected cache stores, we’ll use the FileStore. We decided against the MemoryStore in production because it will not be shared between multiple processes (when using Puma).
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/avo/configuration.rb', line 181 def computed_cache_store -> { if Rails.env.production? if Rails.cache.class.to_s.in?(production_rejected_cache_stores) ActiveSupport::Cache.lookup_store(:file_store, Rails.root.join("tmp", "cache")) else Rails.cache end elsif Rails.env.test? Rails.cache else ActiveSupport::Cache.lookup_store(:memory_store) end } end |
#current_user_method(&block) ⇒ Object
102 103 104 |
# File 'lib/avo/configuration.rb', line 102 def current_user_method(&block) @current_user = block if block.present? end |
#current_user_method=(method) ⇒ Object
106 107 108 |
# File 'lib/avo/configuration.rb', line 106 def current_user_method=(method) @current_user = method if method.present? end |
#feature_enabled?(feature) ⇒ Boolean
136 137 138 |
# File 'lib/avo/configuration.rb', line 136 def feature_enabled?(feature) !@disabled_features.map(&:to_sym).include?(feature.to_sym) end |
#license ⇒ Object
154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/avo/configuration.rb', line 154 def license gems = Gem::Specification.map {|gem| gem.name} @license ||= if gems.include?("avo-advanced") "advanced" elsif gems.include?("avo-pro") "pro" elsif gems.include?("avo") "community" end end |
#license=(value) ⇒ Object
148 149 150 151 152 |
# File 'lib/avo/configuration.rb', line 148 def license=(value) if Rails.env.development? puts "[Avo DEPRECATION WARNING]: The `config.license` configuration option is no longer supported and will be removed in future versions. Please discontinue its use and solely utilize the `license_key` instead." end end |
#namespace ⇒ Object
122 123 124 125 126 127 128 |
# File 'lib/avo/configuration.rb', line 122 def namespace if Avo.configuration.root_path.present? Avo.configuration.root_path.delete "/" else root_path.delete "/" end end |
#set_context(&block) ⇒ Object
114 115 116 |
# File 'lib/avo/configuration.rb', line 114 def set_context(&block) @context = block if block.present? end |
#set_initial_breadcrumbs(&block) ⇒ Object
118 119 120 |
# File 'lib/avo/configuration.rb', line 118 def (&block) @initial_breadcrumbs = block if block.present? end |