Class: Avo::Fields::BaseField
- Inherits:
-
Object
- Object
- Avo::Fields::BaseField
- Extended by:
- ActiveSupport::DescendantsTracker
- Includes:
- ActionView::Helpers::UrlHelper, Concerns::HasHelpers, Concerns::HasItemType, Concerns::IsResourceItem, Concerns::IsVisible, Concerns::VisibleInDifferentViews, Concerns::DomId, Concerns::HandlesFieldArgs, Concerns::HasDefault, Concerns::HasFieldName, Concerns::HasHTMLAttributes, Concerns::IsDisabled, Concerns::IsReadonly, Concerns::IsRequired, Concerns::UseViewComponents
- Defined in:
- lib/avo/fields/base_field.rb
Direct Known Subclasses
AreaField, AvatarField, BadgeField, BelongsToField, BooleanField, BooleanGroupField, CodeField, CountryField, EasyMdeField, ExternalImageField, FileField, FilesField, FrameBaseField, GravatarField, HeadingField, IdField, KeyValueField, LocationField, PreviewField, ProgressBarField, RadioField, SelectField, StarsField, StatusField, TagsField, TextField, TiptapField, TrixField
Instance Attribute Summary collapse
-
#action ⇒ Object
Returns the value of attribute action.
-
#autocomplete ⇒ Object
readonly
Returns the value of attribute autocomplete.
-
#block ⇒ Object
readonly
Returns the value of attribute block.
-
#computable ⇒ Object
readonly
Private options.
-
#computed ⇒ Object
readonly
if block is present.
-
#computed_value ⇒ Object
readonly
the value after computation.
-
#copyable ⇒ Object
readonly
if allowed to be copyable.
-
#default ⇒ Object
readonly
Returns the value of attribute default.
-
#for_attribute ⇒ Object
readonly
Returns the value of attribute for_attribute.
-
#for_presentation_only ⇒ Object
readonly
Returns the value of attribute for_presentation_only.
-
#format_display_using ⇒ Object
readonly
Returns the value of attribute format_display_using.
-
#format_edit_using ⇒ Object
readonly
Returns the value of attribute format_edit_using.
-
#format_form_using ⇒ Object
readonly
Returns the value of attribute format_form_using.
-
#format_index_using ⇒ Object
readonly
Returns the value of attribute format_index_using.
-
#format_new_using ⇒ Object
readonly
Returns the value of attribute format_new_using.
-
#format_show_using ⇒ Object
readonly
Returns the value of attribute format_show_using.
-
#format_using ⇒ Object
readonly
Returns the value of attribute format_using.
-
#help ⇒ Object
readonly
Returns the value of attribute help.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#label_help ⇒ Object
readonly
Returns the value of attribute label_help.
-
#null_values ⇒ Object
readonly
Returns the value of attribute null_values.
-
#nullable ⇒ Object
readonly
Returns the value of attribute nullable.
-
#panel_name ⇒ Object
Returns the value of attribute panel_name.
-
#readonly ⇒ Object
readonly
Returns the value of attribute readonly.
-
#record ⇒ Object
Hydrated payload.
-
#required ⇒ Object
readonly
Returns the value of attribute required.
-
#size ⇒ Object
readonly
Returns the value of attribute size.
-
#sortable ⇒ Object
readonly
Returns the value of attribute sortable.
-
#stacked ⇒ Object
readonly
Returns the value of attribute stacked.
-
#summarizable ⇒ Object
readonly
Returns the value of attribute summarizable.
-
#user ⇒ Object
Returns the value of attribute user.
-
#width ⇒ Object
Returns the value of attribute width.
Attributes included from Concerns::IsDisabled
Attributes included from Concerns::HasHTMLAttributes
Attributes included from Concerns::VisibleInDifferentViews
#show_on_edit, #show_on_index, #show_on_new, #show_on_preview, #show_on_show
Attributes included from Concerns::IsVisible
Attributes included from Concerns::IsResourceItem
Instance Method Summary collapse
- #apply_update_using(record, key, value, resource) ⇒ Object
-
#assign_value(record:, value:) ⇒ Object
Used by Avo to fill the record with the default value on :new and :edit views.
- #attribute_id ⇒ Object
- #custom? ⇒ Boolean
- #custom_name? ⇒ Boolean
-
#database_id ⇒ Object
Try to see if the field has a different database ID than it’s name.
- #default_name ⇒ Object
- #execute_context(target, **extra_args) ⇒ Object
-
#fill_field(record, key, value, params) ⇒ Object
Fills the record with the received value on create and update actions.
- #form_field_label ⇒ Object
- #has_attribute?(record, attribute) ⇒ Boolean
- #has_own_panel? ⇒ Boolean
- #hidden_in_reflection?(reflection = nil) ⇒ Boolean
-
#initialize(id, **args, &block) ⇒ BaseField
constructor
A new instance of BaseField.
- #meta ⇒ Object
-
#name ⇒ Object
Getting the name of the resource (user/users, post/posts) We’ll first check to see if the user passed a name Secondly we’ll try to find a translation key We’ll fallback to humanizing the id.
- #name_override ⇒ Object
- #options_for_filter ⇒ Object
- #parent ⇒ Object
- #placeholder ⇒ Object
- #plural_name ⇒ Object
- #record_errors ⇒ Object
- #resolve_attribute(value) ⇒ Object
- #table_header_class ⇒ Object
- #table_header_label ⇒ Object
- #to_permitted_param ⇒ Object
- #translated_name(default:) ⇒ Object
- #translated_plural_name(default:) ⇒ Object
- #translation_key ⇒ Object
- #type ⇒ Object
- #updatable ⇒ Object
- #value(property = nil) ⇒ Object
- #visible_in_reflection?(reflection = nil) ⇒ Boolean
- #width_class ⇒ Object
- #width_option ⇒ Object
Methods included from Concerns::DomId
Methods included from Concerns::UseViewComponents
#component_for_view, #view_component_name, #view_component_namespace
Methods included from Concerns::IsRequired
Methods included from Concerns::IsDisabled
Methods included from Concerns::IsReadonly
Methods included from Concerns::HasHTMLAttributes
Methods included from Concerns::HasDefault
Methods included from Concerns::HasHelpers
Methods included from Concerns::VisibleInDifferentViews
#except_on, #hide_on, #initialize_views, #only_on, #post_initialize, #show_on, #show_on_create, #show_on_update, #visible_in_view?
Methods included from Concerns::IsVisible
Methods included from Concerns::HasItemType
#is_card?, #is_collaboration?, #is_field?, #is_header?, #is_heading?, #is_panel?, #is_row?, #is_sidebar?, #is_tab?, #is_tab_group?, #is_tool?
Methods included from Concerns::IsResourceItem
Methods included from Concerns::Hydration
Constructor Details
#initialize(id, **args, &block) ⇒ BaseField
Returns a new instance of BaseField.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/avo/fields/base_field.rb', line 70 def initialize(id, **args, &block) @id = id @name = args[:name] @translation_key = args[:translation_key] @block = block @required = args.dig(:required) # Value if :required present on args, nil otherwise @readonly = args[:readonly] || false @disabled = args[:disabled] || false @sortable = args[:sortable] || false @summarizable = args[:summarizable] || false @nullable = args[:nullable] || false @null_values = args[:null_values] || [nil, ""] @format_using = args[:format_using] @format_display_using = args[:format_display_using] || args[:decorate] unless Rails.env.production? if args[:decorate].present? puts "[Avo DEPRECATION WARNING]: The `decorate` field configuration option is nolonger supported and will be removed in future versions. Please discontinue its use and solely utilize `format_display_using` instead." end end @format_index_using = args[:format_index_using] @format_show_using = args[:format_show_using] @format_edit_using = args[:format_edit_using] @format_new_using = args[:format_new_using] @format_form_using = args[:format_form_using] @update_using = args[:update_using] @decorate = args[:decorate] @placeholder = args[:placeholder] @autocomplete = args[:autocomplete] @help = args[:help] @label_help = args[:label_help] @default = args[:default] @visible = args[:visible] @html = args[:html] @view = Avo::ViewInquirer.new(args[:view]) @value = args[:value] @stacked = args[:stacked] @size = args[:size] || :md @for_presentation_only = args[:for_presentation_only] || false @resource = args[:resource] @action = args[:action] @components = args[:components] || {} @for_attribute = args[:for_attribute] @meta = args[:meta] @copyable = args[:copyable] || false @react_on = Array.wrap(args[:react_on]).map(&:to_s) @record = args[:record] @args = args @computable = true @computed = block.present? @computed_value = nil @width = args[:width] || 100 if width_option.present? && width_option != 100 @stacked = true end post_initialize if respond_to?(:post_initialize) end |
Instance Attribute Details
#action ⇒ Object
Returns the value of attribute action.
63 64 65 |
# File 'lib/avo/fields/base_field.rb', line 63 def action @action end |
#autocomplete ⇒ Object (readonly)
Returns the value of attribute autocomplete.
46 47 48 |
# File 'lib/avo/fields/base_field.rb', line 46 def autocomplete @autocomplete end |
#block ⇒ Object (readonly)
Returns the value of attribute block.
32 33 34 |
# File 'lib/avo/fields/base_field.rb', line 32 def block @block end |
#computable ⇒ Object (readonly)
Private options
56 57 58 |
# File 'lib/avo/fields/base_field.rb', line 56 def computable @computable end |
#computed ⇒ Object (readonly)
if block is present
57 58 59 |
# File 'lib/avo/fields/base_field.rb', line 57 def computed @computed end |
#computed_value ⇒ Object (readonly)
the value after computation
58 59 60 |
# File 'lib/avo/fields/base_field.rb', line 58 def computed_value @computed_value end |
#copyable ⇒ Object (readonly)
if allowed to be copyable
59 60 61 |
# File 'lib/avo/fields/base_field.rb', line 59 def copyable @copyable end |
#default ⇒ Object (readonly)
Returns the value of attribute default.
49 50 51 |
# File 'lib/avo/fields/base_field.rb', line 49 def default @default end |
#for_attribute ⇒ Object (readonly)
Returns the value of attribute for_attribute.
53 54 55 |
# File 'lib/avo/fields/base_field.rb', line 53 def for_attribute @for_attribute end |
#for_presentation_only ⇒ Object (readonly)
Returns the value of attribute for_presentation_only.
52 53 54 |
# File 'lib/avo/fields/base_field.rb', line 52 def for_presentation_only @for_presentation_only end |
#format_display_using ⇒ Object (readonly)
Returns the value of attribute format_display_using.
40 41 42 |
# File 'lib/avo/fields/base_field.rb', line 40 def format_display_using @format_display_using end |
#format_edit_using ⇒ Object (readonly)
Returns the value of attribute format_edit_using.
43 44 45 |
# File 'lib/avo/fields/base_field.rb', line 43 def format_edit_using @format_edit_using end |
#format_form_using ⇒ Object (readonly)
Returns the value of attribute format_form_using.
45 46 47 |
# File 'lib/avo/fields/base_field.rb', line 45 def format_form_using @format_form_using end |
#format_index_using ⇒ Object (readonly)
Returns the value of attribute format_index_using.
41 42 43 |
# File 'lib/avo/fields/base_field.rb', line 41 def format_index_using @format_index_using end |
#format_new_using ⇒ Object (readonly)
Returns the value of attribute format_new_using.
44 45 46 |
# File 'lib/avo/fields/base_field.rb', line 44 def format_new_using @format_new_using end |
#format_show_using ⇒ Object (readonly)
Returns the value of attribute format_show_using.
42 43 44 |
# File 'lib/avo/fields/base_field.rb', line 42 def format_show_using @format_show_using end |
#format_using ⇒ Object (readonly)
Returns the value of attribute format_using.
39 40 41 |
# File 'lib/avo/fields/base_field.rb', line 39 def format_using @format_using end |
#help ⇒ Object (readonly)
Returns the value of attribute help.
47 48 49 |
# File 'lib/avo/fields/base_field.rb', line 47 def help @help end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
31 32 33 |
# File 'lib/avo/fields/base_field.rb', line 31 def id @id end |
#label_help ⇒ Object (readonly)
Returns the value of attribute label_help.
48 49 50 |
# File 'lib/avo/fields/base_field.rb', line 48 def label_help @label_help end |
#null_values ⇒ Object (readonly)
Returns the value of attribute null_values.
38 39 40 |
# File 'lib/avo/fields/base_field.rb', line 38 def null_values @null_values end |
#nullable ⇒ Object (readonly)
Returns the value of attribute nullable.
37 38 39 |
# File 'lib/avo/fields/base_field.rb', line 37 def nullable @nullable end |
#panel_name ⇒ Object
Returns the value of attribute panel_name.
65 66 67 |
# File 'lib/avo/fields/base_field.rb', line 65 def panel_name @panel_name end |
#readonly ⇒ Object (readonly)
Returns the value of attribute readonly.
34 35 36 |
# File 'lib/avo/fields/base_field.rb', line 34 def readonly @readonly end |
#record ⇒ Object
Hydrated payload
62 63 64 |
# File 'lib/avo/fields/base_field.rb', line 62 def record @record end |
#required ⇒ Object (readonly)
Returns the value of attribute required.
33 34 35 |
# File 'lib/avo/fields/base_field.rb', line 33 def required @required end |
#size ⇒ Object (readonly)
Returns the value of attribute size.
51 52 53 |
# File 'lib/avo/fields/base_field.rb', line 51 def size @size end |
#sortable ⇒ Object (readonly)
Returns the value of attribute sortable.
35 36 37 |
# File 'lib/avo/fields/base_field.rb', line 35 def sortable @sortable end |
#stacked ⇒ Object (readonly)
Returns the value of attribute stacked.
50 51 52 |
# File 'lib/avo/fields/base_field.rb', line 50 def stacked @stacked end |
#summarizable ⇒ Object (readonly)
Returns the value of attribute summarizable.
36 37 38 |
# File 'lib/avo/fields/base_field.rb', line 36 def summarizable @summarizable end |
#user ⇒ Object
Returns the value of attribute user.
64 65 66 |
# File 'lib/avo/fields/base_field.rb', line 64 def user @user end |
#width ⇒ Object
Returns the value of attribute width.
66 67 68 |
# File 'lib/avo/fields/base_field.rb', line 66 def width @width end |
Instance Method Details
#apply_update_using(record, key, value, resource) ⇒ Object
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/avo/fields/base_field.rb', line 269 def apply_update_using(record, key, value, resource) return value if @update_using.nil? Avo::ExecutionContext.new( target: @update_using, record:, key:, value:, resource:, field: self, include: self.class.included_modules ).handle end |
#assign_value(record:, value:) ⇒ Object
Used by Avo to fill the record with the default value on :new and :edit views
337 338 339 340 341 342 343 |
# File 'lib/avo/fields/base_field.rb', line 337 def assign_value(record:, value:) id = (type == "belongs_to") ? foreign_key : database_id if record.send(id).nil? record.send(:"#{id}=", value) end end |
#attribute_id ⇒ Object
217 |
# File 'lib/avo/fields/base_field.rb', line 217 def attribute_id = (@attribute_id ||= @for_attribute || @id) |
#custom? ⇒ Boolean
314 315 316 317 318 |
# File 'lib/avo/fields/base_field.rb', line 314 def custom? !method(:initialize).source_location.first.include?("lib/avo/field") rescue true end |
#custom_name? ⇒ Boolean
205 206 207 |
# File 'lib/avo/fields/base_field.rb', line 205 def custom_name? !@name.nil? end |
#database_id ⇒ Object
Try to see if the field has a different database ID than it’s name
288 289 290 291 292 |
# File 'lib/avo/fields/base_field.rb', line 288 def database_id foreign_key rescue id end |
#default_name ⇒ Object
209 210 211 |
# File 'lib/avo/fields/base_field.rb', line 209 def default_name @id.to_s.humanize(keep_id_suffix: true) end |
#execute_context(target, **extra_args) ⇒ Object
247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/avo/fields/base_field.rb', line 247 def execute_context(target, **extra_args) Avo::ExecutionContext.new( target:, record: @record, resource: @resource, view: @view, field: self, include: self.class.included_modules, **extra_args ).handle end |
#fill_field(record, key, value, params) ⇒ Object
Fills the record with the received value on create and update actions.
260 261 262 263 264 265 266 267 |
# File 'lib/avo/fields/base_field.rb', line 260 def fill_field(record, key, value, params) key = @for_attribute.to_s if @for_attribute.present? return record unless has_attribute?(record, key) record.public_send(:"#{key}=", apply_update_using(record, key, value, resource)) record end |
#form_field_label ⇒ Object
345 346 347 |
# File 'lib/avo/fields/base_field.rb', line 345 def form_field_label id end |
#has_attribute?(record, attribute) ⇒ Boolean
283 284 285 |
# File 'lib/avo/fields/base_field.rb', line 283 def has_attribute?(record, attribute) record.methods.include? attribute.to_sym end |
#has_own_panel? ⇒ Boolean
294 295 296 |
# File 'lib/avo/fields/base_field.rb', line 294 def has_own_panel? false end |
#hidden_in_reflection?(reflection = nil) ⇒ Boolean
324 325 326 |
# File 'lib/avo/fields/base_field.rb', line 324 def hidden_in_reflection?(reflection = nil) !visible_in_reflection?(reflection) end |
#meta ⇒ Object
349 350 351 |
# File 'lib/avo/fields/base_field.rb', line 349 def Avo::ExecutionContext.new(target: @meta, record: record, resource: @resource, view: @view).handle end |
#name ⇒ Object
Getting the name of the resource (user/users, post/posts) We’ll first check to see if the user passed a name Secondly we’ll try to find a translation key We’ll fallback to humanizing the id
173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/avo/fields/base_field.rb', line 173 def name if custom_name? Avo::ExecutionContext.new(target: @name).handle elsif name_override.present? name_override elsif translation_key translated_name default: default_name else default_name end end |
#name_override ⇒ Object
185 |
# File 'lib/avo/fields/base_field.rb', line 185 def name_override = nil |
#options_for_filter ⇒ Object
328 329 330 |
# File 'lib/avo/fields/base_field.rb', line 328 def end |
#parent ⇒ Object
353 354 355 |
# File 'lib/avo/fields/base_field.rb', line 353 def parent @parent ||= fetch_parent end |
#placeholder ⇒ Object
213 214 215 |
# File 'lib/avo/fields/base_field.rb', line 213 def placeholder Avo::ExecutionContext.new(target: @placeholder || name, record: record, resource: @resource, view: @view).handle end |
#plural_name ⇒ Object
187 188 189 190 191 192 193 194 195 |
# File 'lib/avo/fields/base_field.rb', line 187 def plural_name default = name.pluralize if translation_key translated_plural_name default: default else default end end |
#record_errors ⇒ Object
306 307 308 |
# File 'lib/avo/fields/base_field.rb', line 306 def record_errors record.present? ? record.errors : {} end |
#resolve_attribute(value) ⇒ Object
298 299 300 |
# File 'lib/avo/fields/base_field.rb', line 298 def resolve_attribute(value) value end |
#table_header_class ⇒ Object
201 202 203 |
# File 'lib/avo/fields/base_field.rb', line 201 def table_header_class @table_header_class ||= "" end |
#table_header_label ⇒ Object
197 198 199 |
# File 'lib/avo/fields/base_field.rb', line 197 def table_header_label @table_header_label ||= name end |
#to_permitted_param ⇒ Object
302 303 304 |
# File 'lib/avo/fields/base_field.rb', line 302 def to_permitted_param id.to_sym end |
#translated_name(default:) ⇒ Object
142 143 144 |
# File 'lib/avo/fields/base_field.rb', line 142 def translated_name(default:) t(translation_key, count: 1, default: default).humanize end |
#translated_plural_name(default:) ⇒ Object
146 147 148 |
# File 'lib/avo/fields/base_field.rb', line 146 def translated_plural_name(default:) t(translation_key, count: 2, default: default).humanize end |
#translation_key ⇒ Object
138 139 140 |
# File 'lib/avo/fields/base_field.rb', line 138 def translation_key @translation_key || "avo.field_translations.#{@id}" end |
#type ⇒ Object
310 311 312 |
# File 'lib/avo/fields/base_field.rb', line 310 def type @type ||= self.class.name.demodulize.to_s.underscore.gsub("_field", "") end |
#updatable ⇒ Object
332 333 334 |
# File 'lib/avo/fields/base_field.rb', line 332 def updatable !is_disabled? && visible? end |
#value(property = nil) ⇒ Object
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/avo/fields/base_field.rb', line 219 def value(property = nil) return @value if @value.present? property ||= attribute_id # Get record value final_value = @record.send(property) if is_model?(@record) && @record.respond_to?(property) # On new views and actions modals we need to prefill the fields with the default value if value is nil if final_value.nil? && should_fill_with_default_value? && @default.present? final_value = computed_default_value end # Run computable callback block if present if computable && @block.present? final_value = execute_context(@block) end # Format value based on available formatter final_value = format_value(final_value) if @decorate.present? && @view.display? final_value = execute_context(@decorate, value: final_value) end final_value end |
#visible_in_reflection?(reflection = nil) ⇒ Boolean
320 321 322 |
# File 'lib/avo/fields/base_field.rb', line 320 def visible_in_reflection?(reflection = nil) true end |
#width_class ⇒ Object
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/avo/fields/base_field.rb', line 150 def width_class case width_option when 25 "w-1/4" when 33 "w-1/3" when 50 "w-1/2" when 66 "w-2/3" when 75 "w-3/4" when 100 "w-full" else "w-full" end end |
#width_option ⇒ Object
134 135 136 |
# File 'lib/avo/fields/base_field.rb', line 134 def width_option @width_option ||= execute_context(@width) end |