Class: Avo::Fields::BelongsToField
- Defined in:
- lib/avo/fields/belongs_to_field.rb
Overview
Requirements
-
list
-
ID
-
label
-
Type
-
foreign_key
-
foreign_key for poly type
-
foreign_key for poly id
-
is_disabled?
Defined Under Namespace
Classes: AutocompleteComponent, EditComponent, IndexComponent, ShowComponent
Instance Attribute Summary collapse
-
#allow_via_detaching ⇒ Object
readonly
Returns the value of attribute allow_via_detaching.
-
#attach_scope ⇒ Object
readonly
Returns the value of attribute attach_scope.
-
#polymorphic_as ⇒ Object
readonly
Returns the value of attribute polymorphic_as.
-
#polymorphic_help ⇒ Object
readonly
Returns the value of attribute polymorphic_help.
-
#relation_method ⇒ Object
readonly
Returns the value of attribute relation_method.
-
#target ⇒ Object
Returns the value of attribute target.
-
#types ⇒ Object
readonly
for Polymorphic associations.
Attributes inherited from BaseField
#action, #as_avatar, #as_description, #as_label, #block, #computable, #computed, #computed_value, #default, #format_using, #help, #id, #index_text_align, #model, #null_values, #nullable, #panel_name, #readonly, #required, #resource, #sortable, #updatable, #user, #view, #visible
Attributes included from Concerns::HasHTMLAttributes
Attributes included from FieldExtensions::VisibleInDifferentViews
#show_on_edit, #show_on_index, #show_on_new, #show_on_show
Instance Method Summary collapse
- #database_id ⇒ Object
- #database_value ⇒ Object
-
#field_label ⇒ Object
What the user sees in the text field.
-
#field_value ⇒ Object
The value.
- #fill_field(model, key, value, params) ⇒ Object
- #foreign_key ⇒ Object
- #get_model ⇒ Object
- #id_input_foreign_key ⇒ Object
-
#initialize(id, **args, &block) ⇒ BelongsToField
constructor
A new instance of BelongsToField.
- #is_polymorphic? ⇒ Boolean
- #label ⇒ Object
- #name ⇒ Object
- #options ⇒ Object
-
#reflection ⇒ Object
Get the model reflection instance.
- #reflection_for_key(key) ⇒ Object
- #relation_model_class ⇒ Object
- #searchable ⇒ Object
- #target_resource ⇒ Object
- #to_permitted_param ⇒ Object
- #type_input_foreign_key ⇒ Object
- #value ⇒ Object
- #values_for_type(model = nil) ⇒ Object
Methods inherited from BaseField
#component_for_view, #custom?, #custom_name?, #default_name, #has_own_panel?, #hidden_in_reflection?, #hydrate, #model_errors, #placeholder, #plural_name, #resolve_attribute, #translation_key, #type, #view_component_name, #visible?, #visible_in_reflection?
Methods included from FieldExtensions::HasFieldName
Methods included from Concerns::IsReadonly
Methods included from Concerns::IsRequired
Methods included from Concerns::HasHTMLAttributes
Methods included from FieldExtensions::VisibleInDifferentViews
#except_on, #hide_on, #only_on, #show_on, #show_on_create, #show_on_update, #visible_on?
Methods included from Concerns::IsResourceItem
#is_field?, #is_main_panel?, #is_panel?, #is_sidebar?, #is_tab?, #is_tab_group?, #is_tool?
Constructor Details
#initialize(id, **args, &block) ⇒ BelongsToField
Returns a new instance of BelongsToField.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/avo/fields/belongs_to_field.rb', line 70 def initialize(id, **args, &block) args[:placeholder] ||= I18n.t("avo.choose_an_option") super(id, **args, &block) @searchable = args[:searchable] == true @polymorphic_as = args[:polymorphic_as] @types = args[:types] @relation_method = id.to_s.parameterize.underscore @allow_via_detaching = args[:allow_via_detaching] == true @attach_scope = args[:attach_scope] @polymorphic_help = args[:polymorphic_help] @target = args[:target] end |
Instance Attribute Details
#allow_via_detaching ⇒ Object (readonly)
Returns the value of attribute allow_via_detaching.
66 67 68 |
# File 'lib/avo/fields/belongs_to_field.rb', line 66 def allow_via_detaching @allow_via_detaching end |
#attach_scope ⇒ Object (readonly)
Returns the value of attribute attach_scope.
67 68 69 |
# File 'lib/avo/fields/belongs_to_field.rb', line 67 def attach_scope @attach_scope end |
#polymorphic_as ⇒ Object (readonly)
Returns the value of attribute polymorphic_as.
63 64 65 |
# File 'lib/avo/fields/belongs_to_field.rb', line 63 def polymorphic_as @polymorphic_as end |
#polymorphic_help ⇒ Object (readonly)
Returns the value of attribute polymorphic_help.
68 69 70 |
# File 'lib/avo/fields/belongs_to_field.rb', line 68 def polymorphic_help @polymorphic_help end |
#relation_method ⇒ Object (readonly)
Returns the value of attribute relation_method.
64 65 66 |
# File 'lib/avo/fields/belongs_to_field.rb', line 64 def relation_method @relation_method end |
#target ⇒ Object
Returns the value of attribute target.
61 62 63 |
# File 'lib/avo/fields/belongs_to_field.rb', line 61 def target @target end |
#types ⇒ Object (readonly)
for Polymorphic associations
65 66 67 |
# File 'lib/avo/fields/belongs_to_field.rb', line 65 def types @types end |
Instance Method Details
#database_id ⇒ Object
216 217 218 219 220 221 222 223 |
# File 'lib/avo/fields/belongs_to_field.rb', line 216 def database_id # If the field is a polymorphic value, return the polymorphic_type as key and pre-fill the _id in fill_field. return "#{polymorphic_as}_type" if polymorphic_as.present? foreign_key rescue id end |
#database_value ⇒ Object
132 133 134 135 136 |
# File 'lib/avo/fields/belongs_to_field.rb', line 132 def database_value target_resource.id rescue nil end |
#field_label ⇒ Object
What the user sees in the text field
107 108 109 110 111 |
# File 'lib/avo/fields/belongs_to_field.rb', line 107 def field_label value.send(target_resource.class.title) rescue nil end |
#field_value ⇒ Object
The value
100 101 102 103 104 |
# File 'lib/avo/fields/belongs_to_field.rb', line 100 def field_value value.send(database_value) rescue nil end |
#fill_field(model, key, value, params) ⇒ Object
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/avo/fields/belongs_to_field.rb', line 197 def fill_field(model, key, value, params) return model unless model.methods.include? key.to_sym if polymorphic_as.present? model.send("#{polymorphic_as}_type=", params["#{polymorphic_as}_type"]) # If the type is blank, reset the id too. if params["#{polymorphic_as}_type"].blank? model.send("#{polymorphic_as}_id=", nil) else model.send("#{polymorphic_as}_id=", params["#{polymorphic_as}_id"]) end else model.send("#{key}=", value) end model end |
#foreign_key ⇒ Object
158 159 160 161 162 163 164 165 166 |
# File 'lib/avo/fields/belongs_to_field.rb', line 158 def foreign_key return polymorphic_as if polymorphic_as.present? if @model.present? get_model_class(@model).reflections[@relation_method].foreign_key elsif @resource.present? && @resource.model_class.reflections[@relation_method].present? @resource.model_class.reflections[@relation_method].foreign_key end end |
#get_model ⇒ Object
245 246 247 248 249 250 251 |
# File 'lib/avo/fields/belongs_to_field.rb', line 245 def get_model return @model if @model.present? @resource.model rescue nil end |
#id_input_foreign_key ⇒ Object
144 145 146 147 148 149 150 |
# File 'lib/avo/fields/belongs_to_field.rb', line 144 def id_input_foreign_key if is_polymorphic? "#{foreign_key}_id" else foreign_key end end |
#is_polymorphic? ⇒ Boolean
152 153 154 155 156 |
# File 'lib/avo/fields/belongs_to_field.rb', line 152 def is_polymorphic? polymorphic_as.present? rescue false end |
#label ⇒ Object
185 186 187 |
# File 'lib/avo/fields/belongs_to_field.rb', line 185 def label value.send(target_resource.class.title) end |
#name ⇒ Object
253 254 255 256 257 |
# File 'lib/avo/fields/belongs_to_field.rb', line 253 def name return polymorphic_as.to_s.humanize if polymorphic_as.present? && view == :index super end |
#options ⇒ Object
113 114 115 |
# File 'lib/avo/fields/belongs_to_field.rb', line 113 def values_for_type end |
#reflection ⇒ Object
Get the model reflection instance
175 176 177 178 179 |
# File 'lib/avo/fields/belongs_to_field.rb', line 175 def reflection reflection_for_key(id) rescue nil end |
#reflection_for_key(key) ⇒ Object
168 169 170 171 172 |
# File 'lib/avo/fields/belongs_to_field.rb', line 168 def reflection_for_key(key) get_model_class(get_model).reflections[key.to_s] rescue nil end |
#relation_model_class ⇒ Object
181 182 183 |
# File 'lib/avo/fields/belongs_to_field.rb', line 181 def relation_model_class @resource.model_class end |
#searchable ⇒ Object
85 86 87 |
# File 'lib/avo/fields/belongs_to_field.rb', line 85 def searchable @searchable && ::Avo::App.license.has_with_trial(:searchable_associations) end |
#target_resource ⇒ Object
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/avo/fields/belongs_to_field.rb', line 225 def target_resource if is_polymorphic? if value.present? return App.get_resource_by_model_name(value.class) else return nil end end reflection_key = polymorphic_as || id if @model._reflections[reflection_key.to_s].klass.present? App.get_resource_by_model_name @model._reflections[reflection_key.to_s].klass.to_s elsif @model._reflections[reflection_key.to_s].[:class_name].present? App.get_resource_by_model_name @model._reflections[reflection_key.to_s].[:class_name] else App.get_resource_by_name reflection_key.to_s end end |
#to_permitted_param ⇒ Object
189 190 191 192 193 194 195 |
# File 'lib/avo/fields/belongs_to_field.rb', line 189 def to_permitted_param if polymorphic_as.present? return ["#{polymorphic_as}_type".to_sym, "#{polymorphic_as}_id".to_sym] end foreign_key.to_sym end |
#type_input_foreign_key ⇒ Object
138 139 140 141 142 |
# File 'lib/avo/fields/belongs_to_field.rb', line 138 def type_input_foreign_key if is_polymorphic? "#{foreign_key}_type" end end |
#value ⇒ Object
89 90 91 92 93 94 95 96 97 |
# File 'lib/avo/fields/belongs_to_field.rb', line 89 def value if is_polymorphic? # Get the value from the pre-filled assoociation record super(polymorphic_as) else # Get the value from the pre-filled assoociation record super(relation_method) end end |
#values_for_type(model = nil) ⇒ Object
117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/avo/fields/belongs_to_field.rb', line 117 def values_for_type(model = nil) resource = target_resource resource = App.get_resource_by_model_name model if model.present? query = Avo::Services::AuthorizationService.apply_policy(user, resource.class.query_scope) if attach_scope.present? query = Avo::Hosts::AssociationScopeHost.new(block: attach_scope, query: query, parent: get_model).handle end query.all.map do |model| [model.send(resource.class.title), model.id] end end |