Class: Avo::Fields::SelectField

Inherits:
BaseField show all
Includes:
FieldExtensions::HasIncludeBlank
Defined in:
lib/avo/fields/select_field.rb

Defined Under Namespace

Classes: EditComponent, IndexComponent, ShowComponent

Instance Attribute Summary collapse

Attributes inherited from BaseField

#action, #as_avatar, #as_description, #as_label, #block, #computable, #computed, #computed_value, #default, #format_using, #help, #id, #index_text_align, #model, #null_values, #nullable, #panel_name, #readonly, #required, #resource, #sortable, #stacked, #updatable, #user, #view, #visible

Attributes included from Concerns::HasHTMLAttributes

#html

Attributes included from FieldExtensions::VisibleInDifferentViews

#show_on_edit, #show_on_index, #show_on_new, #show_on_show

Instance Method Summary collapse

Methods included from FieldExtensions::HasIncludeBlank

#include_blank

Methods inherited from BaseField

#component_for_view, #custom?, #custom_name?, #database_id, #default_name, #fill_field, #has_own_panel?, #hidden_in_reflection?, #hydrate, #model_errors, #name, #placeholder, #plural_name, #resolve_attribute, #to_permitted_param, #translation_key, #type, #value, #view_component_name, #visible?, #visible_in_reflection?

Methods included from FieldExtensions::HasFieldName

#field_name, #get_field_name

Methods included from Concerns::IsReadonly

#is_readonly?

Methods included from Concerns::IsRequired

#is_required?

Methods included from Concerns::HasHTMLAttributes

#get_html

Methods included from FieldExtensions::VisibleInDifferentViews

#except_on, #hide_on, #only_on, #show_on, #show_on_create, #show_on_update, #visible_on?

Methods included from Concerns::IsResourceItem

#is_field?, #is_main_panel?, #is_panel?, #is_sidebar?, #is_tab?, #is_tab_group?, #is_tool?

Constructor Details

#initialize(id, **args, &block) ⇒ SelectField

Returns a new instance of SelectField.



10
11
12
13
14
15
16
17
18
19
# File 'lib/avo/fields/select_field.rb', line 10

def initialize(id, **args, &block)
  args[:placeholder] ||= I18n.t("avo.choose_an_option")

  super(id, **args, &block)

  @options = args[:options] || args[:enum]
  @options = ActiveSupport::HashWithIndifferentAccess.new @options if @options.is_a? Hash
  @enum = args[:enum].present? ? args[:enum] : nil
  @display_value = args[:display_value].present? ? args[:display_value] : false
end

Instance Attribute Details

#display_valueObject (readonly)

Returns the value of attribute display_value.



8
9
10
# File 'lib/avo/fields/select_field.rb', line 8

def display_value
  @display_value
end

#enumObject (readonly)

Returns the value of attribute enum.



7
8
9
# File 'lib/avo/fields/select_field.rb', line 7

def enum
  @enum
end

#optionsObject (readonly)

Returns the value of attribute options.



6
7
8
# File 'lib/avo/fields/select_field.rb', line 6

def options
  @options
end

Instance Method Details

#labelObject



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/avo/fields/select_field.rb', line 43

def label
  if options.respond_to? :call
    computed_options = options.call model: model, resource: resource, view: view, field: self

    return value if display_value

    computed_options.invert.stringify_keys[value]
  elsif enum.present?
    if display_value
      options[value]
    else
      value
    end
  elsif display_value
    value
  else
    options.invert.stringify_keys[value]
  end
end

#options_for_selectObject



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/avo/fields/select_field.rb', line 21

def options_for_select
  if options.respond_to? :call
    computed_options = options.call model: model, resource: resource, view: view, field: self
    if display_value
      computed_options.map { |label, value| [value, value] }.to_h
    else
      computed_options
    end
  elsif enum.present?
    if display_value
      options.invert
    else
      # We need to use the label attribute as the option value because Rails casts it like that
      options.map { |label, value| [label, label] }.to_h
    end
  elsif display_value
    options.map { |label, value| [value, value] }.to_h
  else
    options
  end
end