Class: Avo::Resources::Base
- Inherits:
-
Object
- Object
- Avo::Resources::Base
show all
- Extended by:
- ActiveSupport::DescendantsTracker
- Includes:
- ActionView::Helpers::UrlHelper, Concerns::AbstractResource, Concerns::CanReplaceItems, Concerns::HasAvatar, Concerns::HasControls, Concerns::HasCover, Concerns::HasDescription, Concerns::HasDiscreetInformation, Concerns::HasFieldDiscovery, Concerns::HasHelpers, Concerns::HasItems, Concerns::HasResourceStimulusControllers, Concerns::Hydration, Concerns::ModelClassConstantized, Concerns::Pagination, Concerns::RowControlsConfiguration, Concerns::SafeCall
- Defined in:
- lib/avo/resources/base.rb
Constant Summary
collapse
- VIEW_METHODS_MAPPING =
{
index: [:index, :display],
show: [:show, :display],
edit: [:edit, :form],
update: [:edit, :form],
new: [:new, :form],
create: [:new, :form]
}
Concerns::HasFieldDiscovery::COLUMN_NAMES_TO_IGNORE
Instance Attribute Summary collapse
#items_holder
Class Method Summary
collapse
-
.authorization ⇒ Object
-
.class_name ⇒ Object
-
.controller_path ⇒ Object
Same as route_path — resolves to the correct namespaced controller inside isolate_namespace.
-
.demodulized_class_name ⇒ Object
Last segment only — used for display, translation keys, and initials.
-
.fetch_search(key, record: nil) ⇒ Object
-
.find_record(id, query: nil, params: nil) ⇒ Object
-
.find_scope ⇒ Object
This resolves the scope when finding records (not "where" queries).
-
.get_available_models ⇒ Object
-
.get_model_by_name(model_name) ⇒ Object
-
.initials ⇒ Object
-
.model_class(record_class: nil) ⇒ Object
Returns the model class being used for this resource.
-
.model_key ⇒ Object
This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish.
-
.name ⇒ Object
(also: singular_name)
-
.name_from_translation_key(count:, default:) ⇒ Object
Get the name from the translation_key and fallback to default It can raise I18n::InvalidPluralizationData when using only resource_translation without pluralization keys like: one, two or other key Example: --- en: avo: resource_translations: product: save: "Save product".
-
.navigation_label ⇒ Object
-
.plural_name ⇒ Object
-
.query_scope ⇒ Object
This resolves the scope when doing "where" queries (not find queries).
-
.route_key ⇒ Object
Underscore-joined Rails resource identifier: "accounts_invoices", "users".
-
.route_path ⇒ Object
Slash-separated URL slug: "accounts/invoices", "users".
-
.search_query ⇒ Object
-
.sentence_name ⇒ Object
The name as it should read inside a sentence, e.g.
-
.singular_route_key ⇒ Object
-
.translation_key ⇒ Object
-
.underscore_name ⇒ Object
-
.valid_association_name(record, association_name) ⇒ Object
-
.valid_attachment_name(record, association_name) ⇒ Object
Instance Method Summary
collapse
#safe_call
#controls_placement, #render_row_controls_on_the_left?, #render_row_controls_on_the_right?, #row_controls_classes, #row_controls_configurations
#discreet_information
#apply_pagination, #pagination_type
#helpers
#avatar, #initials
#cover
#description, #discreet_description
#add_stimulus_attributes_for, #get_stimulus_controllers, #stimulus_data_attributes
#render_edit_controls, #render_index_controls, #render_row_controls, #render_show_controls
#with_new_items
#fields, #get_field, #get_field_definitions, #get_fields, #get_preview_fields, #invalid_fields, #is_empty?, #items, #items_with_standalone_fields_wrapped_in_cards, #only_fields, #tab_groups, #visible_items
#discover_associations, #discover_columns, #model_db_columns
Constructor Details
#initialize(record: nil, view: nil, user: nil, params: nil) ⇒ Base
Returns a new instance of Base.
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
|
# File 'lib/avo/resources/base.rb', line 313
def initialize(record: nil, view: nil, user: nil, params: nil)
@view = Avo::ViewInquirer.new(view) if view.present?
@user = user if user.present?
@params = params.presence || {}
if record.present?
@record = record
hydrate_model_with_default_values if @view&.new?
end
unless self.class.model_class.present?
if model_class.present? && model_class.respond_to?(:base_class)
self.class.model_class = model_class.base_class
end
end
end
|
Instance Attribute Details
#record ⇒ Object
Returns the value of attribute record.
54
55
56
|
# File 'lib/avo/resources/base.rb', line 54
def record
@record
end
|
#reflection ⇒ Object
Returns the value of attribute reflection.
52
53
54
|
# File 'lib/avo/resources/base.rb', line 52
def reflection
@reflection
end
|
#user ⇒ Object
Returns the value of attribute user.
53
54
55
|
# File 'lib/avo/resources/base.rb', line 53
def user
@user
end
|
#view ⇒ Object
Returns the value of attribute view.
51
52
53
|
# File 'lib/avo/resources/base.rb', line 51
def view
@view
end
|
Class Method Details
.class_name ⇒ Object
181
182
183
|
# File 'lib/avo/resources/base.rb', line 181
def class_name
@class_name ||= to_s.delete_prefix("Avo::Resources::")
end
|
.controller_path ⇒ Object
Same as route_path — resolves to the correct namespaced controller inside isolate_namespace
208
209
210
|
# File 'lib/avo/resources/base.rb', line 208
def controller_path
route_path
end
|
.demodulized_class_name ⇒ Object
Last segment only — used for display, translation keys, and initials
186
187
188
|
# File 'lib/avo/resources/base.rb', line 186
def demodulized_class_name
class_name.demodulize
end
|
.fetch_search(key, record: nil) ⇒ Object
288
289
290
291
|
# File 'lib/avo/resources/base.rb', line 288
def fetch_search(key, record: nil)
Avo::ExecutionContext.new(target: search[key], resource: self, record: record).handle
end
|
.find_record(id, query: nil, params: nil) ⇒ Object
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
|
# File 'lib/avo/resources/base.rb', line 262
def find_record(id, query: nil, params: nil)
query ||= find_scope
if single_includes.present?
query = query.includes(*single_includes)
end
if single_attachments.present?
single_attachments.each do |attachment|
query = query.send(:"with_attached_#{attachment}")
end
end
Avo::ExecutionContext.new(
target: find_record_method,
query: query,
id: id,
params: params,
model_class:
).handle
end
|
.find_scope ⇒ Object
This resolves the scope when finding records (not "where" queries)
It's used to apply the authorization feature.
132
133
134
|
# File 'lib/avo/resources/base.rb', line 132
def find_scope
authorization.apply_policy model_class
end
|
.get_available_models ⇒ Object
148
149
150
|
# File 'lib/avo/resources/base.rb', line 148
def get_available_models
ApplicationRecord.descendants
end
|
.get_model_by_name(model_name) ⇒ Object
152
153
154
155
156
|
# File 'lib/avo/resources/base.rb', line 152
def get_model_by_name(model_name)
get_available_models.find do |m|
m.to_s == model_name.to_s
end
end
|
.initials ⇒ Object
222
223
224
|
# File 'lib/avo/resources/base.rb', line 222
def initials
name.to_s.split(" ").map(&:first).join("").first(2).upcase
end
|
.model_class(record_class: nil) ⇒ Object
Returns the model class being used for this resource.
The Resource instance has a model_class method too so it can support the STI use cases
where we figure out the model class from the record
162
163
164
165
166
167
168
169
170
171
|
# File 'lib/avo/resources/base.rb', line 162
def model_class(record_class: nil)
return constantized_model_class if @model_class.present?
return record_class if record_class.present?
class_name.safe_constantize
end
|
.model_key ⇒ Object
This is used as the model class ID
We use this instead of the route_key to maintain compatibility with uncountable models
With uncountable models route key appends an _index suffix (Fish->fish_index)
Example: User->users, MediaItem->media_items, Fish->fish
177
178
179
|
# File 'lib/avo/resources/base.rb', line 177
def model_key
@model_key ||= model_class.model_name.plural
end
|
.name ⇒ Object
Also known as:
singular_name
217
218
219
|
# File 'lib/avo/resources/base.rb', line 217
def name
name_from_translation_key(count: 1, default: demodulized_class_name.underscore.humanize)
end
|
.name_from_translation_key(count:, default:) ⇒ Object
Get the name from the translation_key and fallback to default
It can raise I18n::InvalidPluralizationData when using only resource_translation without pluralization keys like: one, two or other key
Example:
en:
avo:
resource_translations:
product:
save: "Save product"
239
240
241
242
243
|
# File 'lib/avo/resources/base.rb', line 239
def name_from_translation_key(count:, default:)
t(translation_key, count:, default:)
rescue I18n::InvalidPluralizationData
default
end
|
.navigation_label ⇒ Object
258
259
260
|
# File 'lib/avo/resources/base.rb', line 258
def navigation_label
plural_name
end
|
.plural_name ⇒ Object
226
227
228
|
# File 'lib/avo/resources/base.rb', line 226
def plural_name
name_from_translation_key(count: 2, default: name.pluralize)
end
|
.query_scope ⇒ Object
This resolves the scope when doing "where" queries (not find queries)
It's used to apply the authorization feature.
122
123
124
125
126
127
|
# File 'lib/avo/resources/base.rb', line 122
def query_scope
authorization.apply_policy Avo::ExecutionContext.new(
target: index_query,
query: model_class
).handle
end
|
.route_key ⇒ Object
Underscore-joined Rails resource identifier: "accounts_invoices", "users"
199
200
201
|
# File 'lib/avo/resources/base.rb', line 199
def route_key
route_path.tr("/", "_")
end
|
.route_path ⇒ Object
Slash-separated URL slug: "accounts/invoices", "users"
191
192
193
194
195
196
|
# File 'lib/avo/resources/base.rb', line 191
def route_path
parts = class_name.split("::")
parts.map!(&:underscore)
parts[-1] = parts[-1].pluralize
parts.join("/")
end
|
.search_query ⇒ Object
284
285
286
|
# File 'lib/avo/resources/base.rb', line 284
def search_query
search.dig(:query)
end
|
.sentence_name ⇒ Object
The name as it should read inside a sentence, e.g. "Create new payment method".
A resolved translation is used verbatim; only the generated fallback is lowercased.
247
248
249
250
251
252
|
# File 'lib/avo/resources/base.rb', line 247
def sentence_name
name_from_translation_key(
count: 1,
default: demodulized_class_name.underscore.humanize(capitalize: false)
)
end
|
.singular_route_key ⇒ Object
203
204
205
|
# File 'lib/avo/resources/base.rb', line 203
def singular_route_key
route_key.singularize
end
|
.translation_key ⇒ Object
212
213
214
|
# File 'lib/avo/resources/base.rb', line 212
def translation_key
custom_translation_key || "avo.resource_translations.#{class_name.underscore}"
end
|
.underscore_name ⇒ Object
254
255
256
|
# File 'lib/avo/resources/base.rb', line 254
def underscore_name
name.demodulize.underscore
end
|
.valid_association_name(record, association_name) ⇒ Object
140
141
142
|
# File 'lib/avo/resources/base.rb', line 140
def valid_association_name(record, association_name)
association_name if record.class.reflect_on_association(association_name).present?
end
|
.valid_attachment_name(record, association_name) ⇒ Object
144
145
146
|
# File 'lib/avo/resources/base.rb', line 144
def valid_attachment_name(record, association_name)
association_name if record.class.reflect_on_attachment(association_name).present?
end
|
Instance Method Details
#attachment_fields ⇒ Object
570
571
572
573
574
|
# File 'lib/avo/resources/base.rb', line 570
def attachment_fields
get_field_definitions.select do |field|
[Avo::Fields::FileField, Avo::Fields::FilesField].include? field.class
end
end
|
#authorization(user: nil) ⇒ Object
616
617
618
619
|
# File 'lib/avo/resources/base.rb', line 616
def authorization(user: nil)
current_user = user || Avo::Current.user
Avo::Services::AuthorizationService.new(current_user, record || model_class, policy_class: authorization_policy)
end
|
#available_view_types ⇒ Object
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
|
# File 'lib/avo/resources/base.rb', line 549
def available_view_types
@available_view_types ||= begin
if self.class.view_types.present?
return Array(
Avo::ExecutionContext.new(
target: self.class.view_types,
resource: self,
record: record
).handle
)
end
view_types = [:table]
view_types << :grid if self.class.grid_view.present?
view_types << :map if map_view.present?
view_types
end
end
|
#cache_hash(parent_record) ⇒ Object
643
644
645
646
647
648
649
650
651
|
# File 'lib/avo/resources/base.rb', line 643
def cache_hash(parent_record)
result = [record, file_hash]
if parent_record.present?
result << parent_record
end
result
end
|
#current_user ⇒ Object
28
29
30
|
# File 'lib/avo/resources/base.rb', line 28
def current_user
Avo::Current.user
end
|
#custom_components ⇒ Object
739
740
741
742
743
744
745
746
|
# File 'lib/avo/resources/base.rb', line 739
def custom_components
@custom_components ||= Avo::ExecutionContext.new(
target: components,
resource: self,
record: @record,
view: @view
).handle.with_indifferent_access
end
|
#default_panel_name ⇒ Object
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
|
# File 'lib/avo/resources/base.rb', line 485
def default_panel_name
return @params[:related_name].capitalize if @params.present? && @params[:related_name].present?
case @view.to_sym
when :show
record_title
when :edit
record_title
when :new
t("avo.create_new_item", item: self.class.sentence_name).upcase_first
end
end
|
#description_attributes ⇒ Object
723
724
725
726
727
728
729
|
# File 'lib/avo/resources/base.rb', line 723
def description_attributes
{
view: view,
resource: self,
record: record
}
end
|
#detect_fields ⇒ Object
331
332
333
334
335
336
337
338
339
340
341
342
|
# File 'lib/avo/resources/base.rb', line 331
def detect_fields
self.items_holder = Avo::Resources::Items::Holder.new(parent: self)
if temporary_items.present?
instance_eval(&temporary_items)
else
fetch_fields
end
self
end
|
#divider(**kwargs) ⇒ Object
418
419
420
|
# File 'lib/avo/resources/base.rb', line 418
def divider(**kwargs)
entity_loader(:action).use({class: Divider, **kwargs}.compact)
end
|
#entity_loader(entity) ⇒ Object
731
732
733
|
# File 'lib/avo/resources/base.rb', line 731
def entity_loader(entity)
instance_variable_get(:"@#{entity.to_s.pluralize}_loader")
end
|
#fetch_cards ⇒ Object
408
409
410
411
412
413
414
415
416
|
# File 'lib/avo/resources/base.rb', line 408
def fetch_cards
possible_methods_for_view = VIEW_METHODS_MAPPING[view.to_sym]
possible_methods_for_view&.each do |method_for_view|
return send(:"#{method_for_view}_cards") if respond_to?(:"#{method_for_view}_cards")
end
cards
end
|
#fetch_fields ⇒ Object
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
|
# File 'lib/avo/resources/base.rb', line 389
def fetch_fields
if view.preview?
[:fields, :index_fields, :show_fields, :display_fields].each do |fields_method|
send(fields_method) if respond_to?(fields_method)
end
return
end
possible_methods_for_view = VIEW_METHODS_MAPPING[view.to_sym]
possible_methods_for_view&.each do |method_for_view|
return send(:"#{method_for_view}_fields") if respond_to?(:"#{method_for_view}_fields")
end
fields
end
|
#fetch_record_icon ⇒ Object
534
535
536
537
538
539
540
541
542
543
544
545
546
547
|
# File 'lib/avo/resources/base.rb', line 534
def fetch_record_icon
return icon if @record.nil?
return @record.try(:icon) if icon.nil?
case icon
when Symbol
@record.send icon
when Proc
Avo::ExecutionContext.new(target: icon, resource: self, record: @record).handle
end
end
|
#fetch_record_title ⇒ Object
515
516
517
518
519
520
521
522
523
524
525
526
527
528
|
# File 'lib/avo/resources/base.rb', line 515
def fetch_record_title
return name if @record.nil?
return @record.try(:name) || @record.try(:title) || @record.try(:label) || @record.to_param if title.nil?
case title
when Symbol
@record.send title
when Proc
Avo::ExecutionContext.new(target: title, resource: self, record: @record).handle
end
end
|
#fields_by_database_id(resource: self) ⇒ Object
Map the received params to their actual fields
'resource' argument is used on avo-advanced, don't remove
578
579
580
581
582
583
584
585
586
587
|
# File 'lib/avo/resources/base.rb', line 578
def fields_by_database_id(resource: self)
resource.get_field_definitions
.reject do |field|
field.computed
end
.map do |field|
[field.database_id.to_s, field]
end
.to_h
end
|
#file_hash ⇒ Object
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
|
# File 'lib/avo/resources/base.rb', line 621
def file_hash
content_to_be_hashed = ""
file_base = self.class.class_name.underscore
resource_path = Rails.root.join("app", "avo", "resources", "#{file_base}.rb").to_s
if File.file? resource_path
content_to_be_hashed += File.read(resource_path)
end
policy_path = Rails.root.join("app", "policies", "#{file_base.gsub("_resource", "")}_policy.rb").to_s
if File.file? policy_path
content_to_be_hashed += File.read(policy_path)
end
Digest::MD5.hexdigest(content_to_be_hashed)
end
|
#file_name ⇒ Object
639
640
641
|
# File 'lib/avo/resources/base.rb', line 639
def file_name
@file_name ||= self.class.underscore_name.tr(" ", "_")
end
|
#fill_record(record, permitted_params, extra_params: [], fields: nil) ⇒ Object
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
|
# File 'lib/avo/resources/base.rb', line 589
def fill_record(record, permitted_params, extra_params: [], fields: nil)
permitted_params.each do |key, value|
field = if fields.present?
fields.find { |f| f.id == key.to_sym }
else
fields_by_database_id[key]
end
next unless field.present?
record = field.fill_field record, key, value, permitted_params
end
if .present?
= permitted_params.slice(*flatten_keys())
record.assign_attributes
end
safe_call(:fill_nested_records, record:, permitted_params:) || record
end
|
#find_action(action_id) ⇒ Object
467
468
469
470
471
472
473
|
# File 'lib/avo/resources/base.rb', line 467
def find_action(action_id)
actions = get_actions + Array(safe_call(:get_actions_from_custom_controls))
actions
.uniq { |action| action[:class].to_s }
.find { |action| action[:class].to_s == action_id.to_s }
end
|
707
708
709
|
# File 'lib/avo/resources/base.rb', line 707
def form_scope
model_class.base_class.to_s.underscore.downcase
end
|
#get_external_link ⇒ Object
752
753
754
755
756
757
758
759
760
761
|
# File 'lib/avo/resources/base.rb', line 752
def get_external_link
return if record.nil?
return if view&.new? || view&.create?
Avo::ExecutionContext.new(target: external_link, resource: self, record: record).handle
end
|
#get_items ⇒ Object
Renderable items for the resource view. Injects a header if none is
defined and, when the user hasn't taken control by declaring at least
one panel, wraps standalone field groups in a Panel + Card so they
render with the expected chrome at the top level.
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
|
# File 'lib/avo/resources/base.rb', line 348
def get_items
grouped_items = visible_items.slice_when do |prev, curr|
is_standalone?(prev) != is_standalone?(curr)
end.to_a.map do |group|
{elements: group, is_standalone: is_standalone?(group.first)}
end
if items.none? { |item| item. }
= Avo::Resources::Items::Header.new
hydrate_item
grouped_items.unshift({elements: [], is_standalone: false})
end
if items.none? { |item| item.is_panel? }
grouped_items.select { |group| group[:is_standalone] }.each do |group|
calculated_panel = Avo::Resources::Items::Panel.new
hydrate_item calculated_panel
card = Avo::Resources::Items::Card.new
hydrate_item card
card.items_holder.items = group[:elements]
calculated_panel.items_holder.items = [card]
group[:elements] = calculated_panel
end
end
grouped_items.flat_map { |group| group[:elements] }
end
|
#has_record_id? ⇒ Boolean
711
712
713
|
# File 'lib/avo/resources/base.rb', line 711
def has_record_id?
record.present? && record_id.present?
end
|
#hydrate ⇒ Object
475
476
477
478
479
480
481
482
483
|
# File 'lib/avo/resources/base.rb', line 475
def hydrate(...)
super
if @record.present?
hydrate_model_with_default_values if @view&.new?
end
self
end
|
#hydrate_model_with_default_values ⇒ Object
We will not overwrite any attributes that come pre-filled in the record.
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
|
# File 'lib/avo/resources/base.rb', line 654
def hydrate_model_with_default_values
default_values = get_fields
.select do |field|
!field.computed && !field.is_a?(Avo::Fields::HeadingField)
end
.map do |field|
value = field.value
if field.type == "belongs_to"
reflection = @record.class.reflect_on_association(@params[:via_relation]) if @params[:via_relation].present?
if field.polymorphic_as.present? && field.types.map(&:to_s).include?(@params[:via_relation_class]) && @params[:via_record_id].present?
via_resource = Avo.resource_manager.get_resource_by_model_class(@params[:via_relation_class])
value = via_resource.find_record(@params[:via_record_id]) if via_resource.present?
elsif reflection.present? && reflection.foreign_key.present? && field.id.to_s == @params[:via_relation].to_s && @params[:via_record_id].present?
resource = Avo.resource_manager.get_resource_by_model_class params[:via_relation_class]
record = resource.find_record @params[:via_record_id], params: params if resource.present?
id_param = reflection.options[:primary_key] || :id
value = record.send(id_param) if record.present?
end
end
[field, value]
end
.to_h
.select do |_, value|
value.present?
end
default_values.each do |field, value|
field.assign_value record: @record, value: value
end
end
|
#id_attribute ⇒ Object
715
716
717
|
# File 'lib/avo/resources/base.rb', line 715
def id_attribute
:id
end
|
#index_view_frame ⇒ Object
309
310
311
|
# File 'lib/avo/resources/base.rb', line 309
def index_view_frame
"#{model_key}_index"
end
|
#index_view_lazy_loading? ⇒ Boolean
305
306
307
|
# File 'lib/avo/resources/base.rb', line 305
def index_view_lazy_loading?
self.class.index_view_loading.to_s == "lazy"
end
|
#model_class ⇒ Object
Returns the model class being used for this resource.
We use the class method as a fallback but we pass it the record too so it can support the STI use cases
where we figure out the model class from that record.
505
506
507
508
509
|
# File 'lib/avo/resources/base.rb', line 505
def model_class
record_class = @record&.class
self.class.model_class record_class: record_class
end
|
#model_name ⇒ Object
691
692
693
|
# File 'lib/avo/resources/base.rb', line 691
def model_name
model_class.model_name
end
|
#record_icon ⇒ Object
530
531
532
|
# File 'lib/avo/resources/base.rb', line 530
def record_icon
fetch_record_icon.to_s
end
|
#record_id ⇒ Object
719
720
721
|
# File 'lib/avo/resources/base.rb', line 719
def record_id
record.send(id_attribute)
end
|
#record_param ⇒ Object
735
736
737
|
# File 'lib/avo/resources/base.rb', line 735
def record_param
@record_param ||= @record.persisted? ? @record.to_param : nil
end
|
#record_path ⇒ Object
699
700
701
|
# File 'lib/avo/resources/base.rb', line 699
def record_path
resource_path(record: record, resource: self)
end
|
#record_title ⇒ Object
511
512
513
|
# File 'lib/avo/resources/base.rb', line 511
def record_title
fetch_record_title.to_s
end
|
#records_path ⇒ Object
703
704
705
|
# File 'lib/avo/resources/base.rb', line 703
def records_path
resources_path(resource: self)
end
|
#resolve_component(original_component) ⇒ Object
748
749
750
|
# File 'lib/avo/resources/base.rb', line 748
def resolve_component(original_component)
custom_components.dig(original_component.to_s)&.to_s&.safe_constantize || original_component
end
|
#resource_type_array? ⇒ Boolean
763
|
# File 'lib/avo/resources/base.rb', line 763
def resource_type_array? = false
|
#singular_model_key ⇒ Object
695
696
697
|
# File 'lib/avo/resources/base.rb', line 695
def singular_model_key
model_class.model_name.singular
end
|
#sort_by_param ⇒ Object
765
766
767
768
769
770
771
772
773
|
# File 'lib/avo/resources/base.rb', line 765
def sort_by_param
available_columns = model_class.column_names
if available_columns.include?(default_sort_column.to_s)
default_sort_column
elsif available_columns.include?("created_at")
:created_at
end
end
|
#sorting_supported? ⇒ Boolean
775
|
# File 'lib/avo/resources/base.rb', line 775
def sorting_supported? = true
|