Class: Avo::Resources::Base
- Inherits:
-
Object
- Object
- Avo::Resources::Base
show all
- Extended by:
- ActiveSupport::DescendantsTracker
- Includes:
- ActionView::Helpers::UrlHelper, Concerns::AbstractResource, Concerns::CanReplaceItems, Concerns::HasAvatar, Concerns::HasControls, Concerns::HasCover, Concerns::HasDescription, Concerns::HasDiscreetInformation, Concerns::HasFieldDiscovery, Concerns::HasHelpers, Concerns::HasItems, Concerns::HasResourceStimulusControllers, Concerns::Hydration, Concerns::ModelClassConstantized, Concerns::Pagination, Concerns::RowControlsConfiguration, Concerns::SafeCall
- Defined in:
- lib/avo/resources/base.rb
Constant Summary
collapse
- VIEW_METHODS_MAPPING =
{
index: [:index, :display],
show: [:show, :display],
edit: [:edit, :form],
update: [:edit, :form],
new: [:new, :form],
create: [:new, :form]
}
Concerns::HasFieldDiscovery::COLUMN_NAMES_TO_IGNORE
Instance Attribute Summary collapse
#items_holder
Class Method Summary
collapse
-
.authorization ⇒ Object
-
.class_name ⇒ Object
-
.controller_path ⇒ Object
Same as route_path — resolves to the correct namespaced controller inside isolate_namespace.
-
.demodulized_class_name ⇒ Object
Last segment only — used for display, translation keys, and initials.
-
.fetch_search(key, record: nil) ⇒ Object
-
.find_record(id, query: nil, params: nil) ⇒ Object
-
.find_scope ⇒ Object
This resolves the scope when finding records (not “where” queries).
-
.get_available_models ⇒ Object
-
.get_model_by_name(model_name) ⇒ Object
-
.initials ⇒ Object
-
.model_class(record_class: nil) ⇒ Object
Returns the model class being used for this resource.
-
.model_key ⇒ Object
This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish.
-
.name ⇒ Object
(also: singular_name)
-
.name_from_translation_key(count:, default:) ⇒ Object
Get the name from the translation_key and fallback to default It can raise I18n::InvalidPluralizationData when using only resource_translation without pluralization keys like: one, two or other key Example: — en: avo: resource_translations: product: save: “Save product”.
-
.navigation_label ⇒ Object
-
.plural_name ⇒ Object
-
.query_scope ⇒ Object
This resolves the scope when doing “where” queries (not find queries).
-
.route_key ⇒ Object
Underscore-joined Rails resource identifier: “accounts_invoices”, “users”.
-
.route_path ⇒ Object
Slash-separated URL slug: “accounts/invoices”, “users”.
-
.search_query ⇒ Object
-
.singular_route_key ⇒ Object
-
.translation_key ⇒ Object
-
.underscore_name ⇒ Object
-
.valid_association_name(record, association_name) ⇒ Object
-
.valid_attachment_name(record, association_name) ⇒ Object
Instance Method Summary
collapse
#safe_call
#controls_placement, #render_row_controls_on_the_left?, #render_row_controls_on_the_right?, #row_controls_classes, #row_controls_configurations
#discreet_information
#apply_pagination, #pagination_type
#helpers
#avatar, #initials
#cover
#description, #discreet_description
#add_stimulus_attributes_for, #get_stimulus_controllers, #stimulus_data_attributes
#render_edit_controls, #render_index_controls, #render_row_controls, #render_show_controls
#with_new_items
#fields, #get_field, #get_field_definitions, #get_fields, #get_preview_fields, #invalid_fields, #is_empty?, #items, #items_with_standalone_fields_wrapped_in_cards, #only_fields, #tab_groups, #visible_items
#discover_associations, #discover_columns, #model_db_columns
Constructor Details
#initialize(record: nil, view: nil, user: nil, params: nil) ⇒ Base
Returns a new instance of Base.
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
|
# File 'lib/avo/resources/base.rb', line 292
def initialize(record: nil, view: nil, user: nil, params: nil)
@view = Avo::ViewInquirer.new(view) if view.present?
@user = user if user.present?
@params = params.presence || {}
if record.present?
@record = record
hydrate_model_with_default_values if @view&.new?
end
unless self.class.model_class.present?
if model_class.present? && model_class.respond_to?(:base_class)
self.class.model_class = model_class.base_class
end
end
end
|
Instance Attribute Details
#record ⇒ Object
Returns the value of attribute record.
53
54
55
|
# File 'lib/avo/resources/base.rb', line 53
def record
@record
end
|
#reflection ⇒ Object
Returns the value of attribute reflection.
51
52
53
|
# File 'lib/avo/resources/base.rb', line 51
def reflection
@reflection
end
|
#user ⇒ Object
Returns the value of attribute user.
52
53
54
|
# File 'lib/avo/resources/base.rb', line 52
def user
@user
end
|
#view ⇒ Object
Returns the value of attribute view.
50
51
52
|
# File 'lib/avo/resources/base.rb', line 50
def view
@view
end
|
Class Method Details
.class_name ⇒ Object
177
178
179
|
# File 'lib/avo/resources/base.rb', line 177
def class_name
@class_name ||= to_s.delete_prefix("Avo::Resources::")
end
|
.controller_path ⇒ Object
Same as route_path — resolves to the correct namespaced controller inside isolate_namespace
204
205
206
|
# File 'lib/avo/resources/base.rb', line 204
def controller_path
route_path
end
|
.demodulized_class_name ⇒ Object
Last segment only — used for display, translation keys, and initials
182
183
184
|
# File 'lib/avo/resources/base.rb', line 182
def demodulized_class_name
class_name.demodulize
end
|
.fetch_search(key, record: nil) ⇒ Object
275
276
277
278
|
# File 'lib/avo/resources/base.rb', line 275
def fetch_search(key, record: nil)
Avo::ExecutionContext.new(target: search[key], resource: self, record: record).handle
end
|
.find_record(id, query: nil, params: nil) ⇒ Object
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
|
# File 'lib/avo/resources/base.rb', line 249
def find_record(id, query: nil, params: nil)
query ||= find_scope
if single_includes.present?
query = query.includes(*single_includes)
end
if single_attachments.present?
single_attachments.each do |attachment|
query = query.send(:"with_attached_#{attachment}")
end
end
Avo::ExecutionContext.new(
target: find_record_method,
query: query,
id: id,
params: params,
model_class:
).handle
end
|
.find_scope ⇒ Object
This resolves the scope when finding records (not “where” queries)
It’s used to apply the authorization feature.
128
129
130
|
# File 'lib/avo/resources/base.rb', line 128
def find_scope
authorization.apply_policy model_class
end
|
.get_available_models ⇒ Object
144
145
146
|
# File 'lib/avo/resources/base.rb', line 144
def get_available_models
ApplicationRecord.descendants
end
|
.get_model_by_name(model_name) ⇒ Object
148
149
150
151
152
|
# File 'lib/avo/resources/base.rb', line 148
def get_model_by_name(model_name)
get_available_models.find do |m|
m.to_s == model_name.to_s
end
end
|
.initials ⇒ Object
218
219
220
|
# File 'lib/avo/resources/base.rb', line 218
def initials
name.to_s.split(" ").map(&:first).join("").first(2).upcase
end
|
.model_class(record_class: nil) ⇒ Object
Returns the model class being used for this resource.
The Resource instance has a model_class method too so it can support the STI use cases where we figure out the model class from the record
158
159
160
161
162
163
164
165
166
167
|
# File 'lib/avo/resources/base.rb', line 158
def model_class(record_class: nil)
return constantized_model_class if @model_class.present?
return record_class if record_class.present?
class_name.safe_constantize
end
|
.model_key ⇒ Object
This is used as the model class ID We use this instead of the route_key to maintain compatibility with uncountable models With uncountable models route key appends an _index suffix (Fish->fish_index) Example: User->users, MediaItem->media_items, Fish->fish
173
174
175
|
# File 'lib/avo/resources/base.rb', line 173
def model_key
@model_key ||= model_class.model_name.plural
end
|
.name ⇒ Object
Also known as:
singular_name
213
214
215
|
# File 'lib/avo/resources/base.rb', line 213
def name
name_from_translation_key(count: 1, default: demodulized_class_name.underscore.humanize)
end
|
.name_from_translation_key(count:, default:) ⇒ Object
Get the name from the translation_key and fallback to default It can raise I18n::InvalidPluralizationData when using only resource_translation without pluralization keys like: one, two or other key Example:
en:
avo:
resource_translations:
product:
save: "Save product"
235
236
237
238
239
|
# File 'lib/avo/resources/base.rb', line 235
def name_from_translation_key(count:, default:)
t(translation_key, count:, default:).humanize
rescue I18n::InvalidPluralizationData
default
end
|
.navigation_label ⇒ Object
245
246
247
|
# File 'lib/avo/resources/base.rb', line 245
def navigation_label
plural_name.humanize
end
|
.plural_name ⇒ Object
222
223
224
|
# File 'lib/avo/resources/base.rb', line 222
def plural_name
name_from_translation_key(count: 2, default: name.pluralize)
end
|
.query_scope ⇒ Object
This resolves the scope when doing “where” queries (not find queries)
It’s used to apply the authorization feature.
118
119
120
121
122
123
|
# File 'lib/avo/resources/base.rb', line 118
def query_scope
authorization.apply_policy Avo::ExecutionContext.new(
target: index_query,
query: model_class
).handle
end
|
.route_key ⇒ Object
Underscore-joined Rails resource identifier: “accounts_invoices”, “users”
195
196
197
|
# File 'lib/avo/resources/base.rb', line 195
def route_key
route_path.tr("/", "_")
end
|
.route_path ⇒ Object
Slash-separated URL slug: “accounts/invoices”, “users”
187
188
189
190
191
192
|
# File 'lib/avo/resources/base.rb', line 187
def route_path
parts = class_name.split("::")
parts.map!(&:underscore)
parts[-1] = parts[-1].pluralize
parts.join("/")
end
|
.search_query ⇒ Object
271
272
273
|
# File 'lib/avo/resources/base.rb', line 271
def search_query
search.dig(:query)
end
|
.singular_route_key ⇒ Object
199
200
201
|
# File 'lib/avo/resources/base.rb', line 199
def singular_route_key
route_key.singularize
end
|
.translation_key ⇒ Object
208
209
210
|
# File 'lib/avo/resources/base.rb', line 208
def translation_key
custom_translation_key || "avo.resource_translations.#{class_name.underscore}"
end
|
.underscore_name ⇒ Object
241
242
243
|
# File 'lib/avo/resources/base.rb', line 241
def underscore_name
name.demodulize.underscore
end
|
.valid_association_name(record, association_name) ⇒ Object
136
137
138
|
# File 'lib/avo/resources/base.rb', line 136
def valid_association_name(record, association_name)
association_name if record.class.reflect_on_association(association_name).present?
end
|
.valid_attachment_name(record, association_name) ⇒ Object
140
141
142
|
# File 'lib/avo/resources/base.rb', line 140
def valid_attachment_name(record, association_name)
association_name if record.class.reflect_on_attachment(association_name).present?
end
|
Instance Method Details
#attachment_fields ⇒ Object
546
547
548
549
550
|
# File 'lib/avo/resources/base.rb', line 546
def attachment_fields
get_field_definitions.select do |field|
[Avo::Fields::FileField, Avo::Fields::FilesField].include? field.class
end
end
|
#authorization(user: nil) ⇒ Object
592
593
594
595
|
# File 'lib/avo/resources/base.rb', line 592
def authorization(user: nil)
current_user = user || Avo::Current.user
Avo::Services::AuthorizationService.new(current_user, record || model_class, policy_class: authorization_policy)
end
|
#available_view_types ⇒ Object
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
|
# File 'lib/avo/resources/base.rb', line 525
def available_view_types
@available_view_types ||= begin
if self.class.view_types.present?
return Array(
Avo::ExecutionContext.new(
target: self.class.view_types,
resource: self,
record: record
).handle
)
end
view_types = [:table]
view_types << :grid if self.class.grid_view.present?
view_types << :map if map_view.present?
view_types
end
end
|
#cache_hash(parent_record) ⇒ Object
619
620
621
622
623
624
625
626
627
|
# File 'lib/avo/resources/base.rb', line 619
def cache_hash(parent_record)
result = [record, file_hash]
if parent_record.present?
result << parent_record
end
result
end
|
#current_user ⇒ Object
28
29
30
|
# File 'lib/avo/resources/base.rb', line 28
def current_user
Avo::Current.user
end
|
#custom_components ⇒ Object
715
716
717
718
719
720
721
722
|
# File 'lib/avo/resources/base.rb', line 715
def custom_components
@custom_components ||= Avo::ExecutionContext.new(
target: components,
resource: self,
record: @record,
view: @view
).handle.with_indifferent_access
end
|
#default_panel_name ⇒ Object
464
465
466
467
468
469
470
471
472
473
474
475
|
# File 'lib/avo/resources/base.rb', line 464
def default_panel_name
return @params[:related_name].capitalize if @params.present? && @params[:related_name].present?
case @view.to_sym
when :show
record_title
when :edit
record_title
when :new
t("avo.create_new_item", item: name.humanize(capitalize: false)).upcase_first
end
end
|
#description_attributes ⇒ Object
699
700
701
702
703
704
705
|
# File 'lib/avo/resources/base.rb', line 699
def description_attributes
{
view: view,
resource: self,
record: record
}
end
|
#detect_fields ⇒ Object
310
311
312
313
314
315
316
317
318
319
320
321
|
# File 'lib/avo/resources/base.rb', line 310
def detect_fields
self.items_holder = Avo::Resources::Items::Holder.new(parent: self)
if temporary_items.present?
instance_eval(&temporary_items)
else
fetch_fields
end
self
end
|
#divider(**kwargs) ⇒ Object
397
398
399
|
# File 'lib/avo/resources/base.rb', line 397
def divider(**kwargs)
entity_loader(:action).use({class: Divider, **kwargs}.compact)
end
|
#entity_loader(entity) ⇒ Object
707
708
709
|
# File 'lib/avo/resources/base.rb', line 707
def entity_loader(entity)
instance_variable_get(:"@#{entity.to_s.pluralize}_loader")
end
|
#fetch_cards ⇒ Object
387
388
389
390
391
392
393
394
395
|
# File 'lib/avo/resources/base.rb', line 387
def fetch_cards
possible_methods_for_view = VIEW_METHODS_MAPPING[view.to_sym]
possible_methods_for_view&.each do |method_for_view|
return send(:"#{method_for_view}_cards") if respond_to?(:"#{method_for_view}_cards")
end
cards
end
|
#fetch_fields ⇒ Object
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
|
# File 'lib/avo/resources/base.rb', line 368
def fetch_fields
if view.preview?
[:fields, :index_fields, :show_fields, :display_fields].each do |fields_method|
send(fields_method) if respond_to?(fields_method)
end
return
end
possible_methods_for_view = VIEW_METHODS_MAPPING[view.to_sym]
possible_methods_for_view&.each do |method_for_view|
return send(:"#{method_for_view}_fields") if respond_to?(:"#{method_for_view}_fields")
end
fields
end
|
#fetch_record_icon ⇒ Object
510
511
512
513
514
515
516
517
518
519
520
521
522
523
|
# File 'lib/avo/resources/base.rb', line 510
def fetch_record_icon
return icon if @record.nil?
return @record.try(:icon) if icon.nil?
case icon
when Symbol
@record.send icon
when Proc
Avo::ExecutionContext.new(target: icon, resource: self, record: @record).handle
end
end
|
#fetch_record_title ⇒ Object
491
492
493
494
495
496
497
498
499
500
501
502
503
504
|
# File 'lib/avo/resources/base.rb', line 491
def fetch_record_title
return name if @record.nil?
return @record.try(:name) || @record.try(:title) || @record.try(:label) || @record.to_param if title.nil?
case title
when Symbol
@record.send title
when Proc
Avo::ExecutionContext.new(target: title, resource: self, record: @record).handle
end
end
|
#fields_by_database_id(resource: self) ⇒ Object
Map the received params to their actual fields ‘resource’ argument is used on avo-advanced, don’t remove
554
555
556
557
558
559
560
561
562
563
|
# File 'lib/avo/resources/base.rb', line 554
def fields_by_database_id(resource: self)
resource.get_field_definitions
.reject do |field|
field.computed
end
.map do |field|
[field.database_id.to_s, field]
end
.to_h
end
|
#file_hash ⇒ Object
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
|
# File 'lib/avo/resources/base.rb', line 597
def file_hash
content_to_be_hashed = ""
file_base = self.class.class_name.underscore
resource_path = Rails.root.join("app", "avo", "resources", "#{file_base}.rb").to_s
if File.file? resource_path
content_to_be_hashed += File.read(resource_path)
end
policy_path = Rails.root.join("app", "policies", "#{file_base.gsub("_resource", "")}_policy.rb").to_s
if File.file? policy_path
content_to_be_hashed += File.read(policy_path)
end
Digest::MD5.hexdigest(content_to_be_hashed)
end
|
#file_name ⇒ Object
615
616
617
|
# File 'lib/avo/resources/base.rb', line 615
def file_name
@file_name ||= self.class.underscore_name.tr(" ", "_")
end
|
#fill_record(record, permitted_params, extra_params: [], fields: nil) ⇒ Object
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
|
# File 'lib/avo/resources/base.rb', line 565
def fill_record(record, permitted_params, extra_params: [], fields: nil)
permitted_params.each do |key, value|
field = if fields.present?
fields.find { |f| f.id == key.to_sym }
else
fields_by_database_id[key]
end
next unless field.present?
record = field.fill_field record, key, value, permitted_params
end
if .present?
= permitted_params.slice(*flatten_keys())
record.assign_attributes
end
safe_call(:fill_nested_records, record:, permitted_params:) || record
end
|
#find_action(action_id) ⇒ Object
446
447
448
449
450
451
452
|
# File 'lib/avo/resources/base.rb', line 446
def find_action(action_id)
actions = get_actions + Array(safe_call(:get_actions_from_custom_controls))
actions
.uniq { |action| action[:class].to_s }
.find { |action| action[:class].to_s == action_id.to_s }
end
|
683
684
685
|
# File 'lib/avo/resources/base.rb', line 683
def form_scope
model_class.base_class.to_s.underscore.downcase
end
|
#get_external_link ⇒ Object
728
729
730
731
732
|
# File 'lib/avo/resources/base.rb', line 728
def get_external_link
return unless record&.persisted?
Avo::ExecutionContext.new(target: external_link, resource: self, record: record).handle
end
|
#get_items ⇒ Object
Renderable items for the resource view. Injects a header if none is defined and, when the user hasn’t taken control by declaring at least one panel, wraps standalone field groups in a Panel + Card so they render with the expected chrome at the top level.
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
|
# File 'lib/avo/resources/base.rb', line 327
def get_items
grouped_items = visible_items.slice_when do |prev, curr|
is_standalone?(prev) != is_standalone?(curr)
end.to_a.map do |group|
{elements: group, is_standalone: is_standalone?(group.first)}
end
if items.none? { |item| item. }
= Avo::Resources::Items::Header.new
hydrate_item
grouped_items.unshift({elements: [], is_standalone: false})
end
if items.none? { |item| item.is_panel? }
grouped_items.select { |group| group[:is_standalone] }.each do |group|
calculated_panel = Avo::Resources::Items::Panel.new
hydrate_item calculated_panel
card = Avo::Resources::Items::Card.new
hydrate_item card
card.items_holder.items = group[:elements]
calculated_panel.items_holder.items = [card]
group[:elements] = calculated_panel
end
end
grouped_items.flat_map { |group| group[:elements] }
end
|
#has_record_id? ⇒ Boolean
687
688
689
|
# File 'lib/avo/resources/base.rb', line 687
def has_record_id?
record.present? && record_id.present?
end
|
#hydrate ⇒ Object
454
455
456
457
458
459
460
461
462
|
# File 'lib/avo/resources/base.rb', line 454
def hydrate(...)
super
if @record.present?
hydrate_model_with_default_values if @view&.new?
end
self
end
|
#hydrate_model_with_default_values ⇒ Object
We will not overwrite any attributes that come pre-filled in the record.
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
|
# File 'lib/avo/resources/base.rb', line 630
def hydrate_model_with_default_values
default_values = get_fields
.select do |field|
!field.computed && !field.is_a?(Avo::Fields::HeadingField)
end
.map do |field|
value = field.value
if field.type == "belongs_to"
reflection = @record.class.reflect_on_association(@params[:via_relation]) if @params[:via_relation].present?
if field.polymorphic_as.present? && field.types.map(&:to_s).include?(@params[:via_relation_class]) && @params[:via_record_id].present?
via_resource = Avo.resource_manager.get_resource_by_model_class(@params[:via_relation_class])
value = via_resource.find_record(@params[:via_record_id]) if via_resource.present?
elsif reflection.present? && reflection.foreign_key.present? && field.id.to_s == @params[:via_relation].to_s && @params[:via_record_id].present?
resource = Avo.resource_manager.get_resource_by_model_class params[:via_relation_class]
record = resource.find_record @params[:via_record_id], params: params if resource.present?
id_param = reflection.options[:primary_key] || :id
value = record.send(id_param) if record.present?
end
end
[field, value]
end
.to_h
.select do |_, value|
value.present?
end
default_values.each do |field, value|
field.assign_value record: @record, value: value
end
end
|
#id_attribute ⇒ Object
691
692
693
|
# File 'lib/avo/resources/base.rb', line 691
def id_attribute
:id
end
|
#model_class ⇒ Object
Returns the model class being used for this resource.
We use the class method as a fallback but we pass it the record too so it can support the STI use cases where we figure out the model class from that record.
481
482
483
484
485
|
# File 'lib/avo/resources/base.rb', line 481
def model_class
record_class = @record&.class
self.class.model_class record_class: record_class
end
|
#model_name ⇒ Object
667
668
669
|
# File 'lib/avo/resources/base.rb', line 667
def model_name
model_class.model_name
end
|
#record_icon ⇒ Object
506
507
508
|
# File 'lib/avo/resources/base.rb', line 506
def record_icon
fetch_record_icon.to_s
end
|
#record_id ⇒ Object
695
696
697
|
# File 'lib/avo/resources/base.rb', line 695
def record_id
record.send(id_attribute)
end
|
#record_param ⇒ Object
711
712
713
|
# File 'lib/avo/resources/base.rb', line 711
def record_param
@record_param ||= @record.persisted? ? @record.to_param : nil
end
|
#record_path ⇒ Object
675
676
677
|
# File 'lib/avo/resources/base.rb', line 675
def record_path
resource_path(record: record, resource: self)
end
|
#record_title ⇒ Object
487
488
489
|
# File 'lib/avo/resources/base.rb', line 487
def record_title
fetch_record_title.to_s
end
|
#records_path ⇒ Object
679
680
681
|
# File 'lib/avo/resources/base.rb', line 679
def records_path
resources_path(resource: self)
end
|
#resolve_component(original_component) ⇒ Object
724
725
726
|
# File 'lib/avo/resources/base.rb', line 724
def resolve_component(original_component)
custom_components.dig(original_component.to_s)&.to_s&.safe_constantize || original_component
end
|
#resource_type_array? ⇒ Boolean
734
|
# File 'lib/avo/resources/base.rb', line 734
def resource_type_array? = false
|
#singular_model_key ⇒ Object
671
672
673
|
# File 'lib/avo/resources/base.rb', line 671
def singular_model_key
model_class.model_name.singular
end
|
#sort_by_param ⇒ Object
736
737
738
739
740
741
742
743
744
|
# File 'lib/avo/resources/base.rb', line 736
def sort_by_param
available_columns = model_class.column_names
if available_columns.include?(default_sort_column.to_s)
default_sort_column
elsif available_columns.include?("created_at")
:created_at
end
end
|
#sorting_supported? ⇒ Boolean
746
|
# File 'lib/avo/resources/base.rb', line 746
def sorting_supported? = true
|