Class: Avo::Sidebar::GroupComponent
- Inherits:
-
BaseItemComponent
- Object
- BaseItemComponent
- Avo::Sidebar::GroupComponent
- Defined in:
- app/components/avo/sidebar/group_component.rb
Instance Method Summary collapse
-
#group_has_any_icon? ⇒ Boolean
True if any visible item in the group has an icon (so all items should reserve icon space for alignment).
Instance Method Details
#group_has_any_icon? ⇒ Boolean
True if any visible item in the group has an icon (so all items should reserve icon space for alignment).
5 6 7 |
# File 'app/components/avo/sidebar/group_component.rb', line 5 def group_has_any_icon? @items.any? { |child| child.try(:icon).present? } end |