Class: Avo::Views::ResourceIndexComponent
- Inherits:
-
ResourceComponent
- Object
- ResourceComponent
- Avo::Views::ResourceIndexComponent
show all
- Includes:
- ApplicationHelper, ResourcesHelper
- Defined in:
- app/components/avo/views/resource_index_component.rb
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#attach_path ⇒ Object
-
#authorized_to_search? ⇒ Boolean
-
#available_view_types ⇒ Object
-
#can_attach? ⇒ Boolean
-
#can_render_scopes? ⇒ Boolean
-
#can_see_the_create_button? ⇒ Boolean
The Create button is dependent on the new? policy method.
-
#create_path ⇒ Object
-
#description ⇒ Object
-
#initialize(resource: nil, resources: nil, records: [], pagy: nil, index_params: {}, filters: [], actions: [], reflection: nil, turbo_frame: "", parent_record: nil, parent_resource: nil, applied_filters: [], query: nil, scopes: nil) ⇒ ResourceIndexComponent
constructor
A new instance of ResourceIndexComponent.
-
#render_dynamic_filters_button ⇒ Object
-
#scopes_list ⇒ Object
-
#show_search_input ⇒ Object
-
#singular_resource_name ⇒ Object
-
#title ⇒ Object
-
#view_type ⇒ Object
#a_button, #a_link, #button_classes, #decode_filter_params, #empty_state, #encode_filter_params, #get_model_class, #input_classes, #mount_path, #number_to_social, #render_license_warning, #root_path_without_url, #svg, #white_panel_classes
#field_wrapper, #filter_wrapper, #index_field_wrapper, #item_select_all_input, #item_selector_init, #item_selector_input, #resource_grid, #resource_table
Constructor Details
#initialize(resource: nil, resources: nil, records: [], pagy: nil, index_params: {}, filters: [], actions: [], reflection: nil, turbo_frame: "", parent_record: nil, parent_resource: nil, applied_filters: [], query: nil, scopes: nil) ⇒ ResourceIndexComponent
Returns a new instance of ResourceIndexComponent.
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
|
# File 'app/components/avo/views/resource_index_component.rb', line 9
def initialize(
resource: nil,
resources: nil,
records: [],
pagy: nil,
index_params: {},
filters: [],
actions: [],
reflection: nil,
turbo_frame: "",
parent_record: nil,
parent_resource: nil,
applied_filters: [],
query: nil,
scopes: nil
)
@resource = resource
@resources = resources
@records = records
@pagy = pagy
@index_params = index_params
@filters = filters
@actions = actions
@reflection = reflection
@turbo_frame = turbo_frame
@parent_record = parent_record
@parent_resource = parent_resource
@applied_filters = applied_filters
@view = Avo::ViewInquirer.new("index")
@query = query
@scopes = scopes
end
|
Instance Attribute Details
#actions ⇒ Object
Returns the value of attribute actions.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def actions
@actions
end
|
#parent_record ⇒ Object
Returns the value of attribute parent_record.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def parent_record
@parent_record
end
|
#parent_resource ⇒ Object
Returns the value of attribute parent_resource.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def parent_resource
@parent_resource
end
|
#query ⇒ Object
Returns the value of attribute query.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def query
@query
end
|
#resource ⇒ Object
Returns the value of attribute resource.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def resource
@resource
end
|
#scopes ⇒ Object
Returns the value of attribute scopes.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def scopes
@scopes
end
|
#turbo_frame ⇒ Object
Returns the value of attribute turbo_frame.
7
8
9
|
# File 'app/components/avo/views/resource_index_component.rb', line 7
def turbo_frame
@turbo_frame
end
|
Instance Method Details
#attach_path ⇒ Object
100
101
102
103
104
|
# File 'app/components/avo/views/resource_index_component.rb', line 100
def attach_path
current_path = CGI.unescape(request.env["PATH_INFO"]).split("/").select(&:present?)
Avo.root_path(paths: [*current_path, "new"])
end
|
#authorized_to_search? ⇒ Boolean
135
136
137
138
139
140
141
|
# File 'app/components/avo/views/resource_index_component.rb', line 135
def authorized_to_search?
return true unless resource.authorization.respond_to?(:has_action_method?)
return true unless resource.authorization.has_action_method?("search")
resource.authorization.authorize_action("search", raise_exception: false)
end
|
#available_view_types ⇒ Object
56
57
58
|
# File 'app/components/avo/views/resource_index_component.rb', line 56
def available_view_types
@index_params[:available_view_types]
end
|
#can_attach? ⇒ Boolean
68
69
70
71
72
73
|
# File 'app/components/avo/views/resource_index_component.rb', line 68
def can_attach?
klass = @reflection
klass = @reflection.through_reflection if klass.is_a? ::ActiveRecord::Reflection::ThroughReflection
@reflection.present? && klass.is_a?(::ActiveRecord::Reflection::HasManyReflection) && !has_reflection_and_is_read_only && authorize_association_for(:attach)
end
|
#can_render_scopes? ⇒ Boolean
168
169
170
|
# File 'app/components/avo/views/resource_index_component.rb', line 168
def can_render_scopes?
defined?(Avo::Pro)
end
|
The Create button is dependent on the new? policy method. The create? should be called only when the user clicks the Save button so the developers gets access to the params from the form.
62
63
64
65
66
|
# File 'app/components/avo/views/resource_index_component.rb', line 62
def can_see_the_create_button?
return authorize_association_for(:create) if @reflection.present?
@resource.authorization.authorize_action(:new, raise_exception: false) && !has_reflection_and_is_read_only
end
|
#create_path ⇒ Object
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
|
# File 'app/components/avo/views/resource_index_component.rb', line 75
def create_path
args = {}
if @reflection.present?
args = {
via_relation_class: reflection_model_class,
via_record_id: @parent_record.to_param
}
if @reflection.is_a? ActiveRecord::Reflection::ThroughReflection
args[:via_relation] = params[:resource_name]
end
if @reflection.is_a? ActiveRecord::Reflection::HasManyReflection
args[:via_relation] = @reflection.name
end
if @reflection.inverse_of.present?
args[:via_relation] = @reflection.inverse_of.name
end
end
helpers.new_resource_path(resource: @resource, **args)
end
|
#description ⇒ Object
116
117
118
119
120
121
122
123
124
125
|
# File 'app/components/avo/views/resource_index_component.rb', line 116
def description
if @reflection.present?
return field.description if field.present? && field.description
return
end
@resource.description
end
|
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
|
# File 'app/components/avo/views/resource_index_component.rb', line 143
def render_dynamic_filters_button
return unless Avo.avo_dynamic_filters_installed?
return unless resource.has_filters?
return if Avo::DynamicFilters.configuration.always_expanded
a_button size: :sm,
color: :primary,
icon: "filter",
data: {
controller: "avo-filters",
action: "click->avo-filters#toggleFiltersArea",
} do
Avo::DynamicFilters.configuration.button_label
end
end
|
#scopes_list ⇒ Object
159
160
161
162
163
164
165
166
|
# File 'app/components/avo/views/resource_index_component.rb', line 159
def scopes_list
Avo::Pro::Scopes::ListComponent.new(
scopes: scopes,
resource: resource,
turbo_frame: turbo_frame,
parent_record: parent_record
)
end
|
127
128
129
130
131
132
133
|
# File 'app/components/avo/views/resource_index_component.rb', line 127
def show_search_input
return false unless authorized_to_search?
return false unless resource.class.search_query.present?
return false if field&.hide_search_input
true
end
|
#singular_resource_name ⇒ Object
106
107
108
109
110
111
112
113
114
|
# File 'app/components/avo/views/resource_index_component.rb', line 106
def singular_resource_name
if @reflection.present?
return name.singularize if field.present?
reflection_resource.name
else
@resource.singular_name || @resource.model_class.model_name.name.downcase
end
end
|
#title ⇒ Object
42
43
44
45
46
47
48
49
50
|
# File 'app/components/avo/views/resource_index_component.rb', line 42
def title
if @reflection.present?
return name if field.present?
reflection_resource.plural_name
else
@resource.plural_name
end
end
|
#view_type ⇒ Object
52
53
54
|
# File 'app/components/avo/views/resource_index_component.rb', line 52
def view_type
@index_params[:view_type]
end
|