Class: Avo::Views::ResourceIndexComponent

Inherits:
ResourceComponent
  • Object
show all
Includes:
ApplicationHelper, ResourcesHelper
Defined in:
app/components/avo/views/resource_index_component.rb

Instance Method Summary collapse

Methods included from ApplicationHelper

#a_button, #a_link, #button_classes, #empty_state, #get_model_class, #input_classes, #mount_path, #render_license_warning, #render_license_warnings, #root_path_without_url, #svg, #white_panel_classes

Methods included from ResourcesHelper

#field_wrapper, #filter_wrapper, #index_field_wrapper, #item_select_all_input, #item_selector_init, #item_selector_input, #resource_grid, #resource_table

Constructor Details

#initialize(resource: nil, resources: nil, models: [], pagy: nil, index_params: {}, filters: [], actions: [], reflection: nil, turbo_frame: "", parent_model: nil, parent_resource: nil, applied_filters: [], query: nil) ⇒ ResourceIndexComponent

Returns a new instance of ResourceIndexComponent.



7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'app/components/avo/views/resource_index_component.rb', line 7

def initialize(
  resource: nil,
  resources: nil,
  models: [],
  pagy: nil,
  index_params: {},
  filters: [],
  actions: [],
  reflection: nil,
  turbo_frame: "",
  parent_model: nil,
  parent_resource: nil,
  applied_filters: [],
  query: nil
)
  @resource = resource
  @resources = resources
  @models = models
  @pagy = pagy
  @index_params = index_params
  @filters = filters
  @actions = actions
  @reflection = reflection
  @turbo_frame = turbo_frame
  @parent_model = parent_model
  @parent_resource = parent_resource
  @applied_filters = applied_filters
  @view = :index
  @query = query
end

Instance Method Details

#attach_pathObject



100
101
102
103
104
# File 'app/components/avo/views/resource_index_component.rb', line 100

def attach_path
  current_path = CGI.unescape(request.env["PATH_INFO"]).split("/").select(&:present?)

  Avo::App.root_path(paths: [*current_path, "new"])
end

#authorized_to_search?Boolean

Returns:

  • (Boolean)


135
136
137
138
139
140
# File 'app/components/avo/views/resource_index_component.rb', line 135

def authorized_to_search?
  # Hide the search if the authorization prevents it
  return true unless @resource.authorization.has_action_method?("search")

  @resource.authorization.authorize_action("search", raise_exception: false)
end

#available_view_typesObject



52
53
54
# File 'app/components/avo/views/resource_index_component.rb', line 52

def available_view_types
  @index_params[:available_view_types]
end

#can_attach?Boolean

Returns:

  • (Boolean)


64
65
66
67
68
69
# File 'app/components/avo/views/resource_index_component.rb', line 64

def can_attach?
  klass = @reflection
  klass = @reflection.through_reflection if klass.is_a? ::ActiveRecord::Reflection::ThroughReflection

  @reflection.present? && klass.is_a?(::ActiveRecord::Reflection::HasManyReflection) && !has_reflection_and_is_read_only && authorize_association_for(:attach)
end

#can_see_the_create_button?Boolean

The Create button is dependent on the new? policy method. The create? should be called only when the user clicks the Save button so the developers gets access to the params from the form.

Returns:

  • (Boolean)


58
59
60
61
62
# File 'app/components/avo/views/resource_index_component.rb', line 58

def can_see_the_create_button?
  return authorize_association_for(:create) if @reflection.present?

  @resource.authorization.authorize_action(:new, raise_exception: false) && !has_reflection_and_is_read_only
end

#create_pathObject



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'app/components/avo/views/resource_index_component.rb', line 71

def create_path
  args = {}

  if @reflection.present?
    args = {
      via_relation_class: reflection_model_class,
      via_resource_id: @parent_model.to_param
    }

    if @reflection.is_a? ActiveRecord::Reflection::ThroughReflection
      args[:via_relation] = params[:resource_name]
    end

    if @reflection.is_a? ActiveRecord::Reflection::HasManyReflection
      args[:via_relation] = @reflection.name
    end

    if @reflection.parent_reflection.present? && @reflection.parent_reflection.inverse_of.present?
      args[:via_relation] = @reflection.parent_reflection.inverse_of.name
    end

    if @reflection.inverse_of.present?
      args[:via_relation] = @reflection.inverse_of.name
    end
  end

  helpers.new_resource_path(resource: @resource, **args)
end

#descriptionObject



116
117
118
119
120
121
122
123
124
125
# File 'app/components/avo/views/resource_index_component.rb', line 116

def description
  # If this is a has many association, the user can pass a description to be shown just for this association.
  if @reflection.present?
    return field.description if field.present? && field.description

    return
  end

  @resource.resource_description
end

#show_search_inputObject



127
128
129
130
131
132
133
# File 'app/components/avo/views/resource_index_component.rb', line 127

def show_search_input
  return false unless authorized_to_search?
  return false unless @resource.search_query.present?
  return false if field&.hide_search_input

  true
end

#singular_resource_nameObject



106
107
108
109
110
111
112
113
114
# File 'app/components/avo/views/resource_index_component.rb', line 106

def singular_resource_name
  if @reflection.present?
    return name.singularize if field.present?

    reflection_resource.name
  else
    @resource.singular_name || @resource.model_class.model_name.name.downcase
  end
end

#titleObject



38
39
40
41
42
43
44
45
46
# File 'app/components/avo/views/resource_index_component.rb', line 38

def title
  if @reflection.present?
    return name if field.present?

    reflection_resource.plural_name
  else
    @resource.plural_name
  end
end

#view_typeObject



48
49
50
# File 'app/components/avo/views/resource_index_component.rb', line 48

def view_type
  @index_params[:view_type]
end